@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2021, Intel Corporation
+* Copyright (c) 2020-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -27,6 +27,7 @@
 #ifndef __MOS_UTILITIES_COMMON_H__
 #define __MOS_UTILITIES_COMMON_H__
 
+#include <string>
 #include "mos_defs.h"
 
 #ifndef __MOS_USER_FEATURE_WA_
@@ -114,7 +115,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_FE_BE_TIMING,
     __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_OUTPUT_FILE,
     __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_BUFFER_SIZE,
-    __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_TIMER_REG,
     __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_ENABLE_MULTI_PROCESS,
     __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_REGISTER_1,
     __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_REGISTER_2,
@@ -126,6 +126,7 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_REGISTER_8,
     __MEDIA_USER_FEATURE_VALUE_DISABLE_KMD_WATCHDOG_ID,
     __MEDIA_USER_FEATURE_VALUE_SINGLE_TASK_PHASE_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_DECODE_SINGLE_TASK_PHASE_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_AUX_TABLE_16K_GRANULAR_ID,
     __MEDIA_USER_FEATURE_VALUE_ENABLE_SOFTPIN_ID,
     __MEDIA_USER_FEATURE_VALUE_MFE_MBENC_ENABLE_ID,
@@ -135,6 +136,8 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_FORCE_YFYS_ID,
     __MEDIA_USER_FEATURE_VALUE_DECODE_LOCK_DISABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_ENCODE_HW_WALKER_ID,
+    __MEDIA_USER_FEATURE_VALUE_ENCODE_HUC_FIRMWARE_LOAD_FAILED_ID,
+    __MEDIA_USER_FEATURE_VALUE_ENCODE_HUC_IMEM_LOAD_FALIED_ID,
     __MEDIA_USER_FEATURE_VALUE_ENCODE_SUPPRESS_RECON_PIC_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_ENCODE_ME_IN_USE_ID,
     __MEDIA_USER_FEATURE_VALUE_ENCODE_16xME_IN_USE_ID,
@@ -268,9 +271,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_SLICE_SHUTDOWN_REQUEST_STATE_ID,
     __MEDIA_USER_FEATURE_VALUE_SLICE_SHUTDOWN_RESOLUTION_THRESHOLD_ID,
     __MEDIA_USER_FEATURE_VALUE_SLICE_SHUTDOWN_TARGET_USAGE_THRESHOLD_ID,
-    __MEDIA_USER_FEATURE_VALUE_SLICE_COUNT_SET_SUPPORT_ID,
-    __MEDIA_USER_FEATURE_VALUE_DYNAMIC_SLICE_SHUTDOWN_ID,
-    __MEDIA_USER_FEATURE_VALUE_ENABLE_VDBOX_BALANCING_ID,
     __MEDIA_USER_FEATURE_VALUE_MPEG2_SLICE_STATE_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_MPEG2_ENCODE_BRC_DISTORTION_BUFFER_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_NUMBER_OF_CODEC_DEVICES_ON_VDBOX1_ID,
@@ -307,6 +307,7 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_DUMP_COMMAND_INFO_PATH_ID,
 #endif  // MOS_COMMAND_RESINFO_DUMP_SUPPORTED
 #if (_DEBUG || _RELEASE_INTERNAL)
+    __MEDIA_USER_FEATURE_VALUE_ENCODE_HUC_STATUS2_VALUE,
     __MEDIA_USER_FEATURE_VALUE_GROUP_ID_ID,
     __MEDIA_USER_FEATURE_VALUE_MEDIA_PREEMPTION_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_MDF_OVERRIDE_L3TCCNTRL_REG,
@@ -363,52 +364,11 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_DECODE_SFC_RGBFORMAT_OUTPUT_DEBUG_ID,
     __MEDIA_USER_FEATURE_VALUE_DECODE_SFC_LINEAR_OUTPUT_DEBUG_ID,
     __MEDIA_USER_FEATURE_VALUE_HEVC_VDENC_TCBRC_ARB_DISABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_LPLA_DS_DATA_ID,
 #endif  // (_DEBUG || _RELEASE_INTERNAL)
     __MEDIA_USER_FEATURE_VALUE_STATUS_REPORTING_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_SPLIT_SCREEN_DEMO_POSITION_ID,
     __MEDIA_USER_FEATURE_VALUE_SPLIT_SCREEN_DEMO_PARAMETERS_ID,
-#if MOS_MESSAGES_ENABLED
-    __MOS_USER_FEATURE_KEY_DISABLE_ASSERT_ID,
-    __MOS_USER_FEATURE_KEY_MESSAGE_HLT_ENABLED_ID,
-    __MOS_USER_FEATURE_KEY_MESSAGE_HLT_OUTPUT_DIRECTORY_ID,
-    __MOS_USER_FEATURE_KEY_MESSAGE_PRINT_ENABLED_ID,
-    __MOS_USER_FEATURE_KEY_MESSAGE_OS_TAG_ID,
-    __MOS_USER_FEATURE_KEY_BY_SUB_COMPONENT_OS_ID,
-    __MOS_USER_FEATURE_KEY_SUB_COMPONENT_OS_TAG_ID,
-    __MOS_USER_FEATURE_KEY_MESSAGE_HW_TAG_ID,
-    __MOS_USER_FEATURE_KEY_BY_SUB_COMPONENT_HW_ID,
-    //!
-    //! \brief 63____________________________________________________________________________3__________0
-    //!         |                                                                            |   All    |
-    //!         |                    Reserved                                                |Asrt|level|
-    //!         |____________________________________________________________________________|__________|
-    //!
-    __MOS_USER_FEATURE_KEY_SUB_COMPONENT_HW_TAG_ID,
-    __MOS_USER_FEATURE_KEY_MESSAGE_CODEC_TAG_ID,
-    __MOS_USER_FEATURE_KEY_BY_SUB_COMPONENT_CODEC_ID,
-    __MOS_USER_FEATURE_KEY_SUB_COMPONENT_CODEC_TAG_ID,
-    __MOS_USER_FEATURE_KEY_MESSAGE_VP_TAG_ID,
-    __MOS_USER_FEATURE_KEY_BY_SUB_COMPONENT_VP_ID,
-    __MOS_USER_FEATURE_KEY_SUB_COMPONENT_VP_TAG_ID,
-    __MOS_USER_FEATURE_KEY_MESSAGE_CP_TAG_ID,
-    __MOS_USER_FEATURE_KEY_BY_SUB_COMPONENT_CP_ID,
-    __MOS_USER_FEATURE_KEY_SUB_COMPONENT_CP_TAG_ID,
-    __MOS_USER_FEATURE_KEY_MESSAGE_DDI_TAG_ID,
-    __MOS_USER_FEATURE_KEY_BY_SUB_COMPONENT_DDI_ID,
-    __MOS_USER_FEATURE_KEY_SUB_COMPONENT_DDI_TAG_ID,
-    __MOS_USER_FEATURE_KEY_MESSAGE_CM_TAG_ID,
-    __MOS_USER_FEATURE_KEY_BY_SUB_COMPONENT_CM_ID,
-    __MOS_USER_FEATURE_KEY_SUB_COMPONENT_CM_TAG_ID,
-    __MOS_USER_FEATURE_KEY_MESSAGE_SCALABILITY_TAG_ID,
-    __MOS_USER_FEATURE_KEY_BY_SUB_COMPONENT_SCALABILITY_ID,
-    __MOS_USER_FEATURE_KEY_SUB_COMPONENT_SCALABILITY_TAG_ID,
-    __MOS_USER_FEATURE_KEY_MESSAGE_MMC_TAG_ID,
-    __MOS_USER_FEATURE_KEY_BY_SUB_COMPONENT_MMC_ID,
-    __MOS_USER_FEATURE_KEY_SUB_COMPONENT_MMC_TAG_ID,
-    __MOS_USER_FEATURE_KEY_MESSAGE_MCPY_TAG_ID,
-    __MOS_USER_FEATURE_KEY_BY_SUB_COMPONENT_MCPY_ID,
-    __MOS_USER_FEATURE_KEY_SUB_COMPONENT_MCPY_TAG_ID,
-#endif  // MOS_MESSAGES_ENABLED
     __MEDIA_USER_FEATURE_VALUE_HEVC_SF_2_DMA_SUBMITS_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_HEVCDATROWSTORECACHE_DISABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_HEVCDFROWSTORECACHE_DISABLE_ID,
@@ -416,8 +376,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_VP9_HVDROWSTORECACHE_DISABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VP9_DATROWSTORECACHE_DISABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VP9_DFROWSTORECACHE_DISABLE_ID,
-    __MEDIA_USER_FEATURE_VALUE_DDI_DUMP_DIRECTORY_ID,
-    __MEDIA_USER_FEATURE_VALUE_ENCODE_DDI_DUMP_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_MDF_CMD_DUMP_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_MDF_ETW_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_MDF_LOG_LEVEL_ID,
@@ -487,6 +445,7 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __VPHAL_ENABLE_SEGMENTATION_ID,
     __VPHAL_SEGMENTATION_MODE_ID,
     __VPHAL_SEGMENTATION_OUTPUT_TYPE_ID,
+    __VPHAL_VEBOX_HDR_MODE_ID,
 #if (_DEBUG || _RELEASE_INTERNAL)
     __VPHAL_COMP_8TAP_ADAPTIVE_ENABLE_ID,
     __VPHAL_RNDR_FORCE_VP_DECOMPRESSED_OUTPUT_ID,
@@ -535,7 +494,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_ENABLE_HCP_SCALABILITY_DECODE_ID,
     __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_ALWAYS_FRAME_SPLIT_ID,
     __MEDIA_USER_FEATURE_VALUE_SCALABILITY_OVERRIDE_SPLIT_WIDTH_IN_MINCB,
-    __MEDIA_USER_FEATURE_VALUE_SCALABILITY_FE_SEPARATE_SUBMISSION_ENABLED_ID,
     __MEDIA_USER_FEATURE_VALUE_SCALABILITY_FE_SEPARATE_SUBMISSION_IN_USE_ID,
     __MEDIA_USER_FEATURE_VALUE_HEVC_VME_BRC_LTR_DISABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_HEVC_VME_BRC_LTR_INTERVAL_ID,
@@ -576,13 +534,12 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
 #endif
     __MEDIA_USER_FEATURE_VALUE_PERF_UTILITY_TOOL_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_PERF_OUTPUT_DIRECTORY_ID,
-    __MEDIA_USER_FEATURE_VALUE_APO_MOS_PATH_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_APOGEIOS_HEVCD_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_APOGEIOS_AVCD_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_APOGEIOS_VP8D_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_APOGEIOS_VP9D_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_APOGEIOS_MPEG2D_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_APOGEIOS_JPEGD_ENABLE_ID,
-    __MEDIA_USER_FEATURE_VALUE_RESOURCE_ADDR_DUMP_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_RA_MODE_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_LOCAL_MEMORY_LEVEL_SWITCH_ID,
     __MEDIA_USER_FEATURE_VALUE_NULLHW_ENABLE_ID,
@@ -599,6 +556,11 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_OLP_IN_USE_ID,
     __MEDIA_USER_FEATURE_VALUE_SKIP_FRAME_IN_USE_ID,
     __MEDIA_USER_FEATURE_VALUE_HUC_LOAD_STATUS_ID,
+    __MEDIA_USER_FEATURE_VALUE_HUC_REPORT_CRITICAL_ERROR_ID,
+
+    __MEDIA_USER_FEATURE_VALUE_SFC_OUTPUT_CENTERING_DISABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_SFC_OUTPUT_DTR_DISABLE_ID,
+
     __MOS_USER_FEATURE_KEY_MAX_ID,
 } MOS_USER_FEATURE_VALUE_ID;
 
