@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018, Intel Corporation
+* Copyright (c) 2018-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -187,7 +187,7 @@
 }
 #define CM_CHK_HRESULT_GOTOFINISH_MOSERROR(stmt) \
 { \
-    eStatus = (MOS_STATUS)OsResultToMOS_Status(stmt); \
+    eStatus = (MOS_STATUS)MosUtilities::OsResultToMOSStatus(stmt); \
     _CHECK_AND_GOTO_FINISH((eStatus != MOS_STATUS_SUCCESS), eStatus, eStatus, "hr check failed [%d]", eStatus); \
 }
 #define CM_CHK_MOSSTATUS_GOTOFINISH_CMERROR(stmt) \
@@ -206,18 +206,33 @@ bool RequestSipBinary(PLATFORM platform,
                       uint32_t& resSize);
 
 /*===================== end EU Debugger related stuff =======================*/
-uint32_t GetLogFileLocation(const char *filename, char fileNamePrefix[]);
-int32_t  GetDumpCounter(uint32_t valueID);
-int32_t RecordDumpCounter(int32_t count, uint32_t ValueID);
+uint32_t GetLogFileLocation(const char *filename,
+                            char fileNamePrefix[],
+                            MOS_CONTEXT *mosContext);
 
-int32_t GetCommandBufferDumpCounter(uint32_t valueID);
-int32_t RecordCommandBufferDumpCounter(int32_t count, uint32_t ValueID);
+int32_t GetDumpCounter(uint32_t valueID, MOS_CONTEXT *mosContext);
 
-int32_t GetSurfaceStateDumpCounter(uint32_t valueID);
-int32_t RecordSurfaceStateDumpCounter(int32_t count, uint32_t ValueID);
+int32_t RecordDumpCounter(int32_t count,
+                          uint32_t ValueID,
+                          MOS_CONTEXT *mosContext);
 
-int32_t GetInterfaceDescriptorDataDumpCounter(uint32_t valueID);
-int32_t RecordInterfaceDescriptorDataDumpCounter(int32_t count, uint32_t ValueID);
+int32_t GetCommandBufferDumpCounter(uint32_t valueID, MOS_CONTEXT *mosContext);
+
+int32_t RecordCommandBufferDumpCounter(int32_t count,
+                                       uint32_t ValueID,
+                                       MOS_CONTEXT *mosContext);
+
+int32_t GetSurfaceStateDumpCounter(uint32_t valueID, MOS_CONTEXT *mosContext);
+
+int32_t RecordSurfaceStateDumpCounter(int32_t count,
+                                      uint32_t ValueID,
+                                      MOS_CONTEXT *mosContext);
+
+int32_t GetInterfaceDescriptorDataDumpCounter(uint32_t valueID, MOS_CONTEXT *mosContext);
+
+int32_t RecordInterfaceDescriptorDataDumpCounter(int32_t count,
+                                                 uint32_t ValueID,
+                                                 MOS_CONTEXT *mosContext);
 
 uint32_t GetCommandBufferHeaderDWords(PMOS_INTERFACE osInterface);
 
