@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2020, Intel Corporation
+* Copyright (c) 2011-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -97,7 +97,6 @@ CodechalHwInterface::CodechalHwInterface(
     mhw::HwcmdParser::InitInstance(osInterface);
 #endif
 
-    // Basic intialization
     // Basic intialization
     m_osInterface = osInterface;
 
@@ -560,7 +559,7 @@ MOS_STATUS CodechalHwInterface::GetVdencStateCommandsDataSize(
         commands += m_miInterface->GetMiFlushDwCmdSize();
         commands += m_miInterface->GetMiBatchBufferStartCmdSize();
     }
-    else if (standard == CODECHAL_RESERVED0)
+    else if (standard == CODECHAL_AV1)
     {
         commands += m_miInterface->GetMiFlushDwCmdSize();
         commands += m_miInterface->GetMiBatchBufferStartCmdSize();
@@ -736,6 +735,7 @@ MOS_STATUS CodechalHwInterface::AddVdencBrcImgBuffer(
 
     uint32_t mfxAvcImgStateSize = m_mfxInterface->GetAvcImgStateSize();
     uint32_t vdencAvcCostStateSize = m_vdencInterface->GetVdencAvcCostStateSize();
+    uint32_t vdencCmd3Size = m_vdencInterface->GetVdencCmd3Size();
     uint32_t vdencAvcImgStateSize = m_vdencInterface->GetVdencAvcImgStateSize();
 
     MOS_ZeroMemory(&lockFlags, sizeof(MOS_LOCK_PARAMS));
@@ -748,7 +748,7 @@ MOS_STATUS CodechalHwInterface::AddVdencBrcImgBuffer(
 
     MOS_ZeroMemory(&constructedCmdBuf, sizeof(MOS_COMMAND_BUFFER));
     constructedCmdBuf.pCmdBase = (uint32_t *)data;
-    constructedCmdBuf.iRemaining = mfxAvcImgStateSize + vdencAvcCostStateSize + vdencAvcImgStateSize;
+    constructedCmdBuf.iRemaining = mfxAvcImgStateSize + vdencAvcCostStateSize + vdencCmd3Size + vdencAvcImgStateSize;
 
     // Set MFX_IMAGE_STATE command
     constructedCmdBuf.pCmdPtr = (uint32_t *)data;
@@ -758,12 +758,16 @@ MOS_STATUS CodechalHwInterface::AddVdencBrcImgBuffer(
     // Set VDENC_COST_STATE command
     constructedCmdBuf.pCmdPtr = (uint32_t *)(data + mfxAvcImgStateSize);
     constructedCmdBuf.iOffset = mfxAvcImgStateSize;
-    m_vdencInterface->AddVdencAvcCostStateCmd(&constructedCmdBuf, nullptr, params);
+    MHW_MI_CHK_STATUS(m_vdencInterface->AddVdencAvcCostStateCmd(&constructedCmdBuf, nullptr, params));
 
-    // Set VDENC_IMAGE_STATE command
+    // Set VDENC_CMD3 command
     constructedCmdBuf.pCmdPtr = (uint32_t *)(data + mfxAvcImgStateSize + vdencAvcCostStateSize);
     constructedCmdBuf.iOffset = mfxAvcImgStateSize + vdencAvcCostStateSize;
+    MHW_MI_CHK_STATUS(m_vdencInterface->AddVdencCmd3Cmd(&constructedCmdBuf, nullptr, params));
 
+    // Set VDENC_IMAGE_STATE command
+    constructedCmdBuf.pCmdPtr = (uint32_t *)(data + mfxAvcImgStateSize + vdencAvcCostStateSize + vdencCmd3Size);
+    constructedCmdBuf.iOffset = mfxAvcImgStateSize + vdencAvcCostStateSize + vdencCmd3Size;
     MHW_MI_CHK_STATUS(m_vdencInterface->AddVdencImgStateCmd(&constructedCmdBuf, nullptr, params));
 
     // Add batch buffer end insertion flag
