@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018, Intel Corporation
+* Copyright (c) 2018-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -31,8 +31,62 @@
 #include "mos_os.h"
 #include "codec_def_decode_jpeg.h"
 
+#define HISTOGRAM_BINCOUNT 256
+
 struct CencDecodeShareBuf;
 
+//!
+//! \struct FilmGrainProcParams
+//! \brief Define the film grain processing parameters
+//!
+struct FilmGrainProcParams
+{
+    PMOS_SURFACE m_inputSurface;
+    PMOS_SURFACE m_outputSurface;
+};
+
+//!
+//! \struct CodecRectangle
+//! \brief Parameters to describe a surface region
+//!
+struct CodecRectangle
+{
+    uint32_t m_x;
+    uint32_t m_y;
+    uint32_t m_width;
+    uint32_t m_height;
+};
+
+//!
+//! \struct DecodeProcessingParams
+//! \brief Parameters needed for the processing of the decode render target.
+//!
+struct DecodeProcessingParams
+{
+    // Input
+    PMOS_SURFACE   m_inputSurface;
+    CodecRectangle m_inputSurfaceRegion;
+    uint32_t       m_inputColorStandard;
+    uint32_t       m_inputColorRange;
+    uint32_t       m_chromaSitingType;
+
+    // Output
+    PMOS_SURFACE   m_outputSurface;
+    CodecRectangle m_outputSurfaceRegion;
+    uint32_t       m_outputColorStandard;
+
+    PMOS_SURFACE   m_histogramSurface;
+
+    // Processing state
+    uint32_t       m_rotationState;
+    uint32_t       m_blendState;
+    uint32_t       m_mirrorState;
+    bool           m_isSourceSurfAllocated;
+    bool           m_isReferenceOnlyPattern;
+
+    CODECHAL_SCALING_MODE m_scalingMode;
+};
+
 //!
 //! \struct CodechalDecodeParams
 //! \brief  Parameters passed in via Execute() to perform decoding.
@@ -113,6 +167,12 @@ struct CodechalDecodeParams
     void                    *m_iqMatrixBuffer = nullptr;
     //! \brief [IT mode] MB level parameters to be used for decoding
     void                    *m_macroblockParams = nullptr;
+    //!\brief size of data contained in m_iqMatrixBuffer
+    uint32_t                m_iqMatrixSize = 0;
+    //! \brief reference parameters to be used for decoding
+    void                    *m_refParams = nullptr;
+    //! \brief tile info parameters to be used for decoding
+    void                    *m_tileParams = nullptr;
 
     //! \brief Reference count used for downsampling, If non-zero enables downsampling of the render target.
     uint32_t                m_refFrameCnt = 0;
@@ -120,6 +180,10 @@ struct CodechalDecodeParams
     //! \brief Parameters used for processing the decode render target, if invalid, decode render target processing will not be used.
     void                    *m_procParams = nullptr;
 #endif
+
+    //! \brief Parameters used for film grain process
+    FilmGrainProcParams     m_filmGrainProcParams;
+
     //! \brief [Predication] Resource for predication
     PMOS_RESOURCE           m_presPredication = nullptr;
     //! \brief [Predication] Offset for Predication resource
@@ -167,6 +231,8 @@ struct CodechalDecodeParams
     HANDLE                  m_gpuAppTaskEvent;
     //! \brief execution call index in multiple execution call mode
     uint32_t                m_executeCallIndex = 0;
+    //! \brief [Decode Histogram] Input buffer to hold decode histogram
+    MOS_SURFACE             m_histogramSurface = {};
 };
 
 typedef enum _CODECHAL_DUMMY_REFERENCE_STATUS
