@@ -115,6 +115,15 @@ protected:
         cmd.DW1.SurfaceId = params->ucSurfaceStateId;
         cmd.DW1.SurfacePitchMinus1 = params->psSurface->dwPitch - 1;
 
+        /* Handling of reconstructed surface is different for Y410 & AYUV formats */
+        if ((params->ucSurfaceStateId != CODECHAL_HCP_SRC_SURFACE_ID) &&
+            (params->psSurface->Format == Format_Y410))
+            cmd.DW1.SurfacePitchMinus1 = params->psSurface->dwPitch / 2 - 1;
+
+        if ((params->ucSurfaceStateId != CODECHAL_HCP_SRC_SURFACE_ID) &&
+            (params->psSurface->Format == Format_AYUV))
+            cmd.DW1.SurfacePitchMinus1 = params->psSurface->dwPitch / 4 - 1;
+
         cmd.DW2.YOffsetForUCbInPixel = params->psSurface->UPlaneOffset.iYOffset;
 
         MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
@@ -284,7 +293,7 @@ protected:
 
         auto hevcPicParams = params->pHevcPicParams;
 
-        cmd.DW1.Framewidthinmincbminus1 = hevcPicParams->PicWidthInMinCbsY - 1;
+        cmd.DW1.Framewidthinmincbminus1  = hevcPicParams->PicWidthInMinCbsY - 1;
         cmd.DW1.Frameheightinmincbminus1 = hevcPicParams->PicHeightInMinCbsY - 1;
 
         cmd.DW2.Mincusize = (hevcPicParams->log2_min_luma_coding_block_size_minus3) & 0x3;
@@ -303,32 +312,32 @@ protected:
         cmd.DW3.Colpicisi = 0;
         cmd.DW3.Curpicisi = 0;
 
-        cmd.DW4.SampleAdaptiveOffsetEnabledFlag = hevcPicParams->sample_adaptive_offset_enabled_flag;
-        cmd.DW4.PcmEnabledFlag = hevcPicParams->pcm_enabled_flag;
-        cmd.DW4.CuQpDeltaEnabledFlag = hevcPicParams->cu_qp_delta_enabled_flag;
-        cmd.DW4.DiffCuQpDeltaDepthOrNamedAsMaxDqpDepth = hevcPicParams->diff_cu_qp_delta_depth;
-        cmd.DW4.PcmLoopFilterDisableFlag = hevcPicParams->pcm_loop_filter_disabled_flag;
-        cmd.DW4.ConstrainedIntraPredFlag = hevcPicParams->constrained_intra_pred_flag;
-        cmd.DW4.Log2ParallelMergeLevelMinus2 = hevcPicParams->log2_parallel_merge_level_minus2;
-        cmd.DW4.SignDataHidingFlag = hevcPicParams->sign_data_hiding_enabled_flag;
-        cmd.DW4.LoopFilterAcrossTilesEnabledFlag = hevcPicParams->loop_filter_across_tiles_enabled_flag;
-        cmd.DW4.EntropyCodingSyncEnabledFlag = hevcPicParams->entropy_coding_sync_enabled_flag;
-        cmd.DW4.TilesEnabledFlag = hevcPicParams->tiles_enabled_flag;
-        cmd.DW4.WeightedPredFlag = hevcPicParams->weighted_pred_flag;
-        cmd.DW4.WeightedBipredFlag = hevcPicParams->weighted_bipred_flag;
-        cmd.DW4.Fieldpic = (hevcPicParams->RefFieldPicFlag >> 15) & 0x01;
-        cmd.DW4.Bottomfield = ((hevcPicParams->RefBottomFieldFlag >> 15) & 0x01) ? 0 : 1;
-        cmd.DW4.TransformSkipEnabledFlag = hevcPicParams->transform_skip_enabled_flag;
-        cmd.DW4.AmpEnabledFlag = hevcPicParams->amp_enabled_flag;
-        cmd.DW4.TransquantBypassEnableFlag = hevcPicParams->transquant_bypass_enabled_flag;
-        cmd.DW4.StrongIntraSmoothingEnableFlag = hevcPicParams->strong_intra_smoothing_enabled_flag;
+        cmd.DW4.SampleAdaptiveOffsetEnabledFlag         = hevcPicParams->sample_adaptive_offset_enabled_flag;
+        cmd.DW4.PcmEnabledFlag                          = hevcPicParams->pcm_enabled_flag;
+        cmd.DW4.CuQpDeltaEnabledFlag                    = hevcPicParams->cu_qp_delta_enabled_flag;
+        cmd.DW4.DiffCuQpDeltaDepthOrNamedAsMaxDqpDepth  = hevcPicParams->diff_cu_qp_delta_depth;
+        cmd.DW4.PcmLoopFilterDisableFlag                = hevcPicParams->pcm_loop_filter_disabled_flag;
+        cmd.DW4.ConstrainedIntraPredFlag                = hevcPicParams->constrained_intra_pred_flag;
+        cmd.DW4.Log2ParallelMergeLevelMinus2            = hevcPicParams->log2_parallel_merge_level_minus2;
+        cmd.DW4.SignDataHidingFlag                      = hevcPicParams->sign_data_hiding_enabled_flag;
+        cmd.DW4.LoopFilterAcrossTilesEnabledFlag        = hevcPicParams->loop_filter_across_tiles_enabled_flag;
+        cmd.DW4.EntropyCodingSyncEnabledFlag            = hevcPicParams->entropy_coding_sync_enabled_flag;
+        cmd.DW4.TilesEnabledFlag                        = hevcPicParams->tiles_enabled_flag;
+        cmd.DW4.WeightedPredFlag                        = hevcPicParams->weighted_pred_flag;
+        cmd.DW4.WeightedBipredFlag                      = hevcPicParams->weighted_bipred_flag;
+        cmd.DW4.Fieldpic                                = (hevcPicParams->RefFieldPicFlag >> 15) & 0x01;
+        cmd.DW4.Bottomfield                             = ((hevcPicParams->RefBottomFieldFlag >> 15) & 0x01) ? 0 : 1;
+        cmd.DW4.TransformSkipEnabledFlag                = hevcPicParams->transform_skip_enabled_flag;
+        cmd.DW4.AmpEnabledFlag                          = hevcPicParams->amp_enabled_flag;
+        cmd.DW4.TransquantBypassEnableFlag              = hevcPicParams->transquant_bypass_enabled_flag;
+        cmd.DW4.StrongIntraSmoothingEnableFlag          = hevcPicParams->strong_intra_smoothing_enabled_flag;
 
         cmd.DW5.PicCbQpOffset = hevcPicParams->pps_cb_qp_offset & 0x1f;
         cmd.DW5.PicCrQpOffset = hevcPicParams->pps_cr_qp_offset & 0x1f;
         cmd.DW5.MaxTransformHierarchyDepthIntraOrNamedAsTuMaxDepthIntra = hevcPicParams->max_transform_hierarchy_depth_intra & 0x7;
         cmd.DW5.MaxTransformHierarchyDepthInterOrNamedAsTuMaxDepthInter = hevcPicParams->max_transform_hierarchy_depth_inter & 0x7;
         cmd.DW5.PcmSampleBitDepthChromaMinus1 = hevcPicParams->pcm_sample_bit_depth_chroma_minus1;
-        cmd.DW5.PcmSampleBitDepthLumaMinus1 = hevcPicParams->pcm_sample_bit_depth_luma_minus1;
+        cmd.DW5.PcmSampleBitDepthLumaMinus1   = hevcPicParams->pcm_sample_bit_depth_luma_minus1;
 
         MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
@@ -471,7 +480,9 @@ protected:
 
         typename THcpCmds::HCP_REF_IDX_STATE_CMD cmd;
 
-        if (params->ucNumRefForList != 0)
+        // Need to add an empty HCP_REF_IDX_STATE_CMD for dummy reference on I-Frame
+        // ucNumRefForList could be 0 for encode
+        if (!params->bDummyReference)
         {
             MHW_ASSERT(params->CurrPic.FrameIdx != 0x7F);
 
@@ -918,6 +929,36 @@ protected:
 
         return eStatus;
     }
+
+    MOS_STATUS AddHcpDecodeProtectStateCmd(
+        PMOS_COMMAND_BUFFER              cmdBuffer,
+        PMHW_VDBOX_HEVC_SLICE_STATE      hevcSliceState)
+    {
+        MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+
+        MHW_FUNCTION_ENTER;
+
+        MHW_MI_CHK_NULL(hevcSliceState);
+
+        MHW_CP_SLICE_INFO_PARAMS sliceInfoParam;
+        sliceInfoParam.presDataBuffer = hevcSliceState->presDataBuffer;
+        sliceInfoParam.dwSliceIndex = hevcSliceState->dwSliceIndex;
+        sliceInfoParam.dwTotalBytesConsumed = 0;
+        sliceInfoParam.bLastPass = hevcSliceState->bLastSlice;
+        sliceInfoParam.dwDataStartOffset[0] = hevcSliceState->pHevcSliceParams->slice_data_offset + hevcSliceState->dwOffset;
+        sliceInfoParam.dwDataStartOffset[1] = hevcSliceState->pHevcSliceParams->slice_data_offset + hevcSliceState->dwOffset;
+        sliceInfoParam.dwDataLength[0] = hevcSliceState->pHevcSliceParams->slice_data_size;
+        sliceInfoParam.dwDataLength[1] = hevcSliceState->pHevcSliceParams->slice_data_size;
+
+        m_cpInterface->SetHcpProtectionState(
+            true,
+            cmdBuffer,
+            nullptr,
+            &sliceInfoParam
+        );
+
+        return eStatus;
+    }
 };
 
 #endif
