@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2020, Intel Corporation
+* Copyright (c) 2017-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -82,34 +82,34 @@ typedef struct _MHW_VDBOX_VDENC_CQPT_STATE_PARAMS
 
 typedef struct _MHW_VDBOX_VDENC_WEIGHT_OFFSET_PARAMS
 {
-    bool        bWeightedPredEnabled;
-    uint32_t    dwDenom;
-    uint8_t     ucList;
-    char        LumaWeights[2][CODEC_MAX_NUM_REF_FRAME_HEVC];
-    int16_t     LumaOffsets[2][CODEC_MAX_NUM_REF_FRAME_HEVC];
-    char        ChromaWeights[2][CODEC_MAX_NUM_REF_FRAME_HEVC][2];
-    int16_t     ChromaOffsets[2][CODEC_MAX_NUM_REF_FRAME_HEVC][2];
-    uint32_t    dwChromaDenom;
-    bool        isLowDelay = true;
+    bool        bWeightedPredEnabled    = false;
+    uint32_t    dwDenom                 = 0;
+    uint8_t     ucList                  = 0;
+    char        LumaWeights[2][CODEC_MAX_NUM_REF_FRAME_HEVC]        = {};
+    int16_t     LumaOffsets[2][CODEC_MAX_NUM_REF_FRAME_HEVC]        = {};
+    char        ChromaWeights[2][CODEC_MAX_NUM_REF_FRAME_HEVC][2]   = {};
+    int16_t     ChromaOffsets[2][CODEC_MAX_NUM_REF_FRAME_HEVC][2]   = {};
+    uint32_t    dwChromaDenom           = 0;
+    bool        isLowDelay              = true;
 } MHW_VDBOX_VDENC_WEIGHT_OFFSET_PARAMS, *PMHW_VDBOX_VDENC_WEIGHT_OFFSET_PARAMS;
 
 typedef struct _MHW_VDBOX_VDENC_CMD1_PARAMS
 {
-    uint32_t                                Mode;
-    PCODEC_HEVC_ENCODE_PICTURE_PARAMS       pHevcEncPicParams;
-    PCODEC_HEVC_ENCODE_SEQUENCE_PARAMS      pHevcEncSeqParams;
-    PCODEC_HEVC_ENCODE_SLICE_PARAMS         pHevcEncSlcParams;
-    PCODEC_VP9_ENCODE_PIC_PARAMS            pVp9EncPicParams = nullptr;
-    uint8_t                                *pucVdencMvCosts;
-    uint8_t                                *pucVdencRdMvCosts;
-    uint8_t                                *pucVdencHmeMvCosts;
-    uint8_t                                *pucVdencModeCosts;
-    void                                   *pInputParams;
-    uint16_t                                usSADQPLambda = 0;
-    uint16_t                                usRDQPLambda = 0;
-    uint8_t                                 frame_type;
-    uint8_t                                 qp;
-    bool                                    isLowDelay;
+    uint32_t                                Mode                = 0;
+    PCODEC_HEVC_ENCODE_PICTURE_PARAMS       pHevcEncPicParams   = nullptr;
+    PCODEC_HEVC_ENCODE_SEQUENCE_PARAMS      pHevcEncSeqParams   = nullptr;
+    PCODEC_HEVC_ENCODE_SLICE_PARAMS         pHevcEncSlcParams   = nullptr;
+    PCODEC_VP9_ENCODE_PIC_PARAMS            pVp9EncPicParams    = nullptr;
+    uint8_t                                *pucVdencMvCosts     = nullptr;
+    uint8_t                                *pucVdencRdMvCosts   = nullptr;
+    uint8_t                                *pucVdencHmeMvCosts  = nullptr;
+    uint8_t                                *pucVdencModeCosts   = nullptr;
+    void                                   *pInputParams        = nullptr;
+    uint16_t                                usSADQPLambda       = 0;
+    uint16_t                                usRDQPLambda        = 0;
+    uint8_t                                 frame_type          = 0;
+    uint8_t                                 qp                  = 0;
+    bool                                    isLowDelay          = false;
     bool                                    bHevcVisualQualityImprovement = false;  //!< VQI enable flag
 } MHW_VDBOX_VDENC_CMD1_PARAMS, *PMHW_VDBOX_VDENC_CMD1_PARAMS;
 
@@ -118,19 +118,21 @@ struct MHW_VDBOX_VDENC_CMD2_STATE
     uint32_t                                Mode = 0;
 
     // HEVC
-    PCODEC_HEVC_ENCODE_SEQUENCE_PARAMS      pHevcEncSeqParams = nullptr;
-    PCODEC_HEVC_ENCODE_PICTURE_PARAMS       pHevcEncPicParams = nullptr;
-    PCODEC_HEVC_ENCODE_SLICE_PARAMS         pHevcEncSlcParams = nullptr;
-    bool                                    bSAOEnable = false;
-    bool                                    bRoundingEnabled = false;
-    bool                                    bStreamInEnabled = false;
-    bool                                    bROIStreamInEnabled = false;
-    bool                                    bUseDefaultQpDeltas = false;
-    bool                                    bPanicEnabled = false;
-    bool                                    bPartialFrameUpdateEnable = false;
-    uint32_t                                roundInterValue = 0;
-    uint32_t                                roundIntraValue = 0;
-    uint8_t                                 bStreaminRoiMode = 0;
+    PCODEC_HEVC_ENCODE_SEQUENCE_PARAMS pHevcEncSeqParams         = nullptr;
+    PCODEC_HEVC_ENCODE_PICTURE_PARAMS  pHevcEncPicParams         = nullptr;
+    PCODEC_HEVC_ENCODE_SLICE_PARAMS    pHevcEncSlcParams         = nullptr;
+    bool                               bSAOEnable                = false;
+    bool                               bRoundingEnabled          = false;
+    bool                               bStreamInEnabled          = false;
+    bool                               bROIStreamInEnabled       = false;
+    bool                               bUseDefaultQpDeltas       = false;
+    bool                               bPanicEnabled             = false;
+    bool                               bPartialFrameUpdateEnable = false;
+    uint32_t                           roundInterValue           = 0;
+    uint32_t                           roundIntraValue           = 0;
+    uint8_t                            bStreaminRoiMode          = 0;
+    bool                               bEnableSubPelMode         = false;
+    uint8_t                            SubPelMode                = 0;
 
     // VP9
     PCODEC_VP9_ENCODE_PIC_PARAMS            pVp9EncPicParams = nullptr;
@@ -315,6 +317,14 @@ public:
     //!
     virtual uint32_t GetVdencAvcImgStateSize() = 0;
 
+    //!
+    //! \brief    get Vdenc slc state size
+    //!
+    //! \return   uint32_t
+    //!           Vdenc slc state size got
+    //!
+    virtual uint32_t GetVdencAvcSlcStateSize() = 0;
+
     //!
     //! \brief    get Vdenc cost state size
     //!
@@ -339,6 +349,14 @@ public:
     //!
     virtual uint32_t GetVdencCmd2Size() = 0;
 
+    //!
+    //! \brief    get cmd3
+    //!
+    //! \return   uint32_t
+    //!           cmd3 size got
+    //!
+    virtual uint32_t GetVdencCmd3Size() = 0;
+
     //!
     //! \brief    get Vdenc state commands data size
     //!
@@ -597,7 +615,7 @@ public:
 
     //!
     //! \brief    Adds CMD2 command in command buffer
-    //! \details  Client facing function to add VDENC HEVC VP9 IMG State command in command buffer
+    //! \details  Client facing function to add CMD2 command in command buffer
     //! \param    [in] cmdBuffer
     //!           Command buffer to which HW command is added
     //! \param    [in] batchBuffer
@@ -612,6 +630,26 @@ public:
         PMHW_BATCH_BUFFER                   batchBuffer,
         PMHW_VDBOX_VDENC_CMD2_STATE         params) = 0;
 
+    //!
+    //! \brief    Adds CMD3 command in command buffer
+    //! \details  Client facing function to add CMD3 command in command buffer
+    //! \param    [in] cmdBuffer
+    //!           Command buffer to which HW command is added
+    //! \param    [in] batchBuffer
+    //!           Batch buffer to add to VDBOX_BUFFER_START
+    //! \param    [in] params
+    //!           Params structure used to populate the HW command
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail type
+    //!
+    virtual MOS_STATUS AddVdencCmd3Cmd(
+        PMOS_COMMAND_BUFFER       cmdBuffer,
+        PMHW_BATCH_BUFFER         batchBuffer,
+        PMHW_VDBOX_AVC_IMG_PARAMS params)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
     virtual PMHW_VDBOX_PIPE_MODE_SELECT_PARAMS CreateMhwVdboxPipeModeSelectParams() = 0;
     virtual void ReleaseMhwVdboxPipeModeSelectParams(PMHW_VDBOX_PIPE_MODE_SELECT_PARAMS pipeModeSelectParams) = 0;
 };
