@@ -46,6 +46,7 @@ public:
     virtual ~VphalDevice() {}
 
     VphalState              *m_vphalState           = nullptr;  //!< VpHal State created for specific gen.
+    VpPipelineAdapterBase   *m_vpPipelineAdapter    = nullptr;
     vp::VpPipeline          *m_vpPipeline           = nullptr;  //!< vp pipeline created for specific gen, which is used for sfc service.
     vp::VpPlatformInterface *m_vpPlatformInterface  = nullptr;  //!< platform interface created for specific gen, which is used for sfc service.
 
@@ -66,6 +67,11 @@ public:
         PMOS_CONTEXT    osDriverContext,
         MOS_STATUS      *eStatus);
 
+    static VpPipelineAdapterBase *CreateFactoryNext(
+        PMOS_INTERFACE osInterface,
+        PMOS_CONTEXT   osDriverContext,
+        MOS_STATUS *   eStatus);
+
     //!
     //! \brief    Initializes platform specific state
     //! \param    [in] osInterface
@@ -84,6 +90,13 @@ public:
         bool            bInitVphalState,
         MOS_STATUS      *eStatus) = 0;
 
+    virtual MOS_STATUS CreateVpPlatformInterface(
+        PMOS_INTERFACE osInterface,
+        MOS_STATUS *   eStatus)
+    {
+        return MOS_STATUS_UNIMPLEMENTED;
+    }
+
     //!
     //! \brief    Destroys all created VpHal interfaces
     //! \details  If the HAL creation fails, this is used for cleanup
