@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2020, Intel Corporation
+* Copyright (c) 2018-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -92,7 +92,7 @@ struct NodeHeader
     MOS_STATUS stmtStatus = (MOS_STATUS)(_stmt);   \
     if (stmtStatus != MOS_STATUS_SUCCESS)          \
     {                                              \
-        MOS_UnlockMutex(m_mutex);                  \
+        MosUtilities::MosUnlockMutex(m_mutex);     \
         return stmtStatus;                         \
     }                                              \
 }
@@ -101,45 +101,11 @@ struct NodeHeader
 {                                                  \
     if ((_ptr) == nullptr)                         \
     {                                              \
-        MOS_UnlockMutex(m_mutex);                  \
+        MosUtilities::MosUnlockMutex(m_mutex);     \
         return MOS_STATUS_NULL_POINTER;            \
     }                                              \
 }
 
-MediaPerfProfiler::MediaPerfProfiler()
-{
-    MOS_ZeroMemory(&m_perfStoreBuffer, sizeof(m_perfStoreBuffer));
-    m_perfDataIndex = 0;
-    m_ref           = 0;
-    m_initialized   = false;
-
-    m_profilerEnabled = 0;
-
-    m_mutex = MOS_CreateMutex();
-
-    if (m_mutex)
-    {
-        // m_mutex is destroyed after MemNinja report, this will cause fake memory leak,
-        // the following 2 lines is to circumvent Memninja counter validation and log parser
-        MOS_AtomicDecrement(&MosUtilities::m_mosMemAllocCounter);
-        MOS_MEMNINJA_FREE_MESSAGE(m_mutex, __FUNCTION__, __FILE__, __LINE__);
-    }
-    else
-    {
-        MOS_OS_ASSERTMESSAGE("Create Mutex failed!");
-    }
-
-}
-
-MediaPerfProfiler::~MediaPerfProfiler()
-{
-    if (m_mutex != nullptr)
-    {
-        MOS_DestroyMutex(m_mutex);
-        m_mutex = nullptr;
-    }
-}
-
 MediaPerfProfiler* MediaPerfProfiler::Instance()
 {
     static MediaPerfProfiler instance;
@@ -164,7 +130,7 @@ void MediaPerfProfiler::Destroy(MediaPerfProfiler* profiler, void* context, MOS_
         return;
     }
 
-    MOS_LockMutex(profiler->m_mutex);
+    MosUtilities::MosLockMutex(profiler->m_mutex);
     profiler->m_ref--;
 
     osInterface->pfnWaitAllCmdCompletion(osInterface);
@@ -187,167 +153,54 @@ void MediaPerfProfiler::Destroy(MediaPerfProfiler* profiler, void* context, MOS_
             profiler->m_initialized = false;
         }
 
-        MOS_UnlockMutex(profiler->m_mutex);
+        MosUtilities::MosUnlockMutex(profiler->m_mutex);
     }
     else
     {
-        MOS_UnlockMutex(profiler->m_mutex);
-    }
-}
-
-MOS_STATUS MediaPerfProfiler::Initialize(void* context, MOS_INTERFACE *osInterface)
-{
-    MOS_STATUS status = MOS_STATUS_SUCCESS;
-    MOS_USER_FEATURE_VALUE_DATA userFeatureData;
-
-    CHK_NULL_RETURN(osInterface);
-    CHK_NULL_RETURN(m_mutex);
-
-    // Check whether profiler is enabled
-    MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-    MOS_UserFeature_ReadValue_ID(
-        nullptr,
-        __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_ENABLE_ID,
-        &userFeatureData,
-        osInterface->pOsContext);
-    m_profilerEnabled = userFeatureData.bData;
-
-    if (m_profilerEnabled == 0 || m_mutex == nullptr)
-    {
-        return MOS_STATUS_SUCCESS;
+        MosUtilities::MosUnlockMutex(profiler->m_mutex);
     }
 
-    MOS_LockMutex(m_mutex);
+    PERF_UTILITY_PRINT;
 
-    m_contextIndexMap[context] = 0;
-    m_ref++;
-
-    if (m_initialized == true)
+    //Destroy APO perf profiler here without writting bin file again. Destroy() in APO class is not called before media softlet build done.
+    if (profiler->m_profilerEnabled == 0 || profiler->m_mutex == nullptr)
     {
-        MOS_UnlockMutex(m_mutex);
-        return status;
+        return;
     }
 
-    m_enableProfilerDump = MosUtilities::MosIsProfilerDumpEnabled();
+    MediaPerfProfilerNext *profilerNext = MediaPerfProfilerNext::Instance();
 
-    // Read output file name
-    MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-    userFeatureData.StringData.pStringData = m_outputFileName;
-    status = MOS_UserFeature_ReadValue_ID(
-        NULL,
-        __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_OUTPUT_FILE,
-        &userFeatureData,
-        osInterface->pOsContext);
-
-    if (status != MOS_STATUS_SUCCESS)
+    if (!profilerNext || profilerNext->m_profilerEnabled == 0 || profilerNext->m_mutex == nullptr)
     {
-        MOS_UnlockMutex(m_mutex);
-        return status;
+        return;
     }
 
-    if (userFeatureData.StringData.uSize == MOS_MAX_PATH_LENGTH + 1)
+    MosUtilities::MosLockMutex(profilerNext->m_mutex);
+    profilerNext->m_ref--;
+
+    osInterface->pfnWaitAllCmdCompletion(osInterface);
+
+    profilerNext->m_contextIndexMap.erase(context);
+
+    if (profilerNext->m_ref == 0)
     {
-        userFeatureData.StringData.uSize = 0;
-    }
+        if (profilerNext->m_initialized == true)
+        {
 
-    if (userFeatureData.StringData.uSize > 0)
-    {
-        userFeatureData.StringData.pStringData[userFeatureData.StringData.uSize] = '\0';
-        userFeatureData.StringData.uSize++;
-    }
+            osInterface->pfnFreeResource(
+                osInterface,
+                &profilerNext->m_perfStoreBuffer);
 
-    // Read buffer size
-    MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-    MOS_UserFeature_ReadValue_ID(
-        nullptr,
-        __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_BUFFER_SIZE,
-        &userFeatureData,
-        osInterface->pOsContext);
-    m_bufferSize = userFeatureData.u32Data;
+            profilerNext->m_initialized = false;
+        }
 
-    m_timerBase = Mos_Specific_GetTsFrequency(osInterface);
-
-    // Read multi processes support
-    MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-    MOS_UserFeature_ReadValue_ID(
-        nullptr,
-        __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_ENABLE_MULTI_PROCESS,
-        &userFeatureData,
-        osInterface->pOsContext);
-    m_multiprocess = userFeatureData.u32Data;
-
-    // Read memory information register address
-    int8_t regIndex = 0;
-    for (regIndex = 0; regIndex < 8; regIndex++)
-    {
-        MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-        MOS_UserFeature_ReadValue_ID(                                   
-            nullptr,                                                    
-            __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_REGISTER_1 + regIndex,
-            &userFeatureData,
-            osInterface->pOsContext);                                          
-        m_registers[regIndex] = userFeatureData.u32Data;
-    }
-
-    MOS_ZeroMemory(&m_perfStoreBuffer, sizeof(MOS_RESOURCE));
-    
-    // Allocate the buffer which store the performance data
-    MOS_ALLOC_GFXRES_PARAMS allocParams;
-    MOS_ZeroMemory(&allocParams, sizeof(MOS_ALLOC_GFXRES_PARAMS));
-    allocParams.Type        = MOS_GFXRES_BUFFER;
-    allocParams.TileType    = MOS_TILE_LINEAR;
-    allocParams.Format      = Format_Buffer;
-    allocParams.dwBytes     = m_bufferSize;
-    allocParams.pBufName    = "PerfStoreBuffer";
-
-    status = osInterface->pfnAllocateResource(
-                                        osInterface,
-                                        &allocParams,
-                                        &m_perfStoreBuffer);
-
-    CHK_STATUS_UNLOCK_MUTEX_RETURN(status);
-
-    CHK_STATUS_UNLOCK_MUTEX_RETURN(
-        osInterface->pfnSkipResourceSync(&m_perfStoreBuffer));
-
-    PLATFORM platform = { IGFX_UNKNOWN };
-    osInterface->pfnGetPlatform(osInterface, &platform);
-
-    MOS_LOCK_PARAMS lockFlags;
-    MOS_ZeroMemory(&lockFlags, sizeof(MOS_LOCK_PARAMS));
-    lockFlags.WriteOnly   = 1;
-
-    NodeHeader* header = (NodeHeader*)osInterface->pfnLockResource(
-            osInterface,
-            &m_perfStoreBuffer,
-            &lockFlags);
-    
-    CHK_NULL_UNLOCK_MUTEX_RETURN(header);
-
-    // Append the header info
-    MOS_ZeroMemory(header, m_bufferSize);
-    header->eventType   = UMD_PERF_LOG;
-    header->genPlatform = (GFX_GET_CURRENT_RENDERCORE(platform) - 8) & 0x7;
-    header->genPlatform_ext = ((GFX_GET_CURRENT_RENDERCORE(platform) - 8) >> 3) & 0x3;
-    
-    if (IsPerfModeWidthMemInfo(m_registers))
-    {
-        header->perfMode    = UMD_PERF_MODE_WITH_MEMORY_INFO;
+        MosUtilities::MosUnlockMutex(profilerNext->m_mutex);
     }
     else
     {
-        header->perfMode    = UMD_PERF_MODE_TIMING_ONLY;
+        MosUtilities::MosUnlockMutex(profilerNext->m_mutex);
     }
 
-    osInterface->pfnUnlockResource(
-            osInterface,
-            &m_perfStoreBuffer);
-
-    m_initialized = true;
-
-    MOS_UnlockMutex(m_mutex);
-
-    return MOS_STATUS_SUCCESS;
 }
 
 MOS_STATUS MediaPerfProfiler::StoreData(
@@ -356,14 +209,23 @@ MOS_STATUS MediaPerfProfiler::StoreData(
     uint32_t offset,
     uint32_t value)
 {
-    MHW_MI_STORE_DATA_PARAMS storeDataParams;
-    MOS_ZeroMemory(&storeDataParams, sizeof(storeDataParams));
+    if (m_miItf)
+    {
+        CHK_STATUS_RETURN(MediaPerfProfilerNext::StoreData(m_miItf, cmdBuffer, offset, value));
+    }
+    else
+    {
+        MHW_MI_STORE_DATA_PARAMS storeDataParams;
+        MOS_ZeroMemory(&storeDataParams, sizeof(storeDataParams));
 
-    storeDataParams.pOsResource         = &m_perfStoreBuffer;
-    storeDataParams.dwResourceOffset    = offset;
-    storeDataParams.dwValue             = value;
+        storeDataParams.pOsResource         = &m_perfStoreBuffer;
+        storeDataParams.dwResourceOffset    = offset;
+        storeDataParams.dwValue             = value;
 
-    return miInterface->AddMiStoreDataImmCmd(cmdBuffer, &storeDataParams);
+        CHK_STATUS_RETURN(miInterface->AddMiStoreDataImmCmd(cmdBuffer, &storeDataParams));
+    }
+
+    return MOS_STATUS_SUCCESS;
 }
 
 MOS_STATUS MediaPerfProfiler::StoreRegister(
@@ -373,20 +235,29 @@ MOS_STATUS MediaPerfProfiler::StoreRegister(
     uint32_t offset,
     uint32_t reg)
 {
-    MHW_MI_STORE_REGISTER_MEM_PARAMS storeRegMemParams;
-    MOS_ZeroMemory(&storeRegMemParams, sizeof(storeRegMemParams));
-
-    storeRegMemParams.presStoreBuffer = &m_perfStoreBuffer;
-    storeRegMemParams.dwOffset        = offset;
-    storeRegMemParams.dwRegister      = reg;
-
-    MEDIA_FEATURE_TABLE* skuTable = osInterface->pfnGetSkuTable(osInterface);
-    if(skuTable && MEDIA_IS_SKU(skuTable, FtrMemoryRemapSupport))
+    if (m_miItf)
     {
-        storeRegMemParams.dwOption = CCS_HW_FRONT_END_MMIO_REMAP;
+        CHK_STATUS_RETURN(MediaPerfProfilerNext::StoreRegister(osInterface, m_miItf, cmdBuffer, offset, reg));
     }
+    else
+    {
+        MHW_MI_STORE_REGISTER_MEM_PARAMS storeRegMemParams;
+        MOS_ZeroMemory(&storeRegMemParams, sizeof(storeRegMemParams));
 
-    return miInterface->AddMiStoreRegisterMemCmd(cmdBuffer, &storeRegMemParams);
+        storeRegMemParams.presStoreBuffer = &m_perfStoreBuffer;
+        storeRegMemParams.dwOffset        = offset;
+        storeRegMemParams.dwRegister      = reg;
+
+        MEDIA_FEATURE_TABLE* skuTable = osInterface->pfnGetSkuTable(osInterface);
+        if(skuTable && MEDIA_IS_SKU(skuTable, FtrMemoryRemapSupport))
+        {
+            storeRegMemParams.dwOption = CCS_HW_FRONT_END_MMIO_REMAP;
+        }
+
+        CHK_STATUS_RETURN(miInterface->AddMiStoreRegisterMemCmd(cmdBuffer, &storeRegMemParams));
+    };
+
+    return MOS_STATUS_SUCCESS;
 }
 
 MOS_STATUS MediaPerfProfiler::StoreTSByPipeCtrl(
@@ -394,18 +265,25 @@ MOS_STATUS MediaPerfProfiler::StoreTSByPipeCtrl(
     PMOS_COMMAND_BUFFER cmdBuffer,
     uint32_t offset)
 {
-    MHW_PIPE_CONTROL_PARAMS PipeControlParams;
+    if (m_miItf)
+    {
+        CHK_STATUS_RETURN(MediaPerfProfilerNext::StoreTSByPipeCtrl(m_miItf, cmdBuffer, offset));
+    }
+    else
+    {
+        MHW_PIPE_CONTROL_PARAMS PipeControlParams;
 
-    MOS_ZeroMemory(&PipeControlParams, sizeof(PipeControlParams));
-    PipeControlParams.dwResourceOffset = offset;
-    PipeControlParams.dwPostSyncOp     = MHW_FLUSH_WRITE_TIMESTAMP_REG;
-    PipeControlParams.dwFlushMode      = MHW_FLUSH_READ_CACHE;
-    PipeControlParams.presDest         = &m_perfStoreBuffer;
+        MOS_ZeroMemory(&PipeControlParams, sizeof(PipeControlParams));
+        PipeControlParams.dwResourceOffset = offset;
+        PipeControlParams.dwPostSyncOp     = MHW_FLUSH_WRITE_TIMESTAMP_REG;
+        PipeControlParams.dwFlushMode      = MHW_FLUSH_READ_CACHE;
+        PipeControlParams.presDest         = &m_perfStoreBuffer;
 
-    CHK_STATUS_RETURN(miInterface->AddPipeControl(
-        cmdBuffer,
-        NULL,
-        &PipeControlParams));
+        CHK_STATUS_RETURN(miInterface->AddPipeControl(
+            cmdBuffer,
+            NULL,
+            &PipeControlParams));
+    }
 
     return MOS_STATUS_SUCCESS;
 }
@@ -415,21 +293,130 @@ MOS_STATUS MediaPerfProfiler::StoreTSByMiFlush(
     PMOS_COMMAND_BUFFER cmdBuffer,
     uint32_t offset)
 {
-    MHW_MI_FLUSH_DW_PARAMS FlushDwParams;
+    if (m_miItf)
+    {
+        CHK_STATUS_RETURN(MediaPerfProfilerNext::StoreTSByMiFlush(m_miItf, cmdBuffer, offset));
+    }
+    else
+    {
+        MHW_MI_FLUSH_DW_PARAMS FlushDwParams;
 
-    MOS_ZeroMemory(&FlushDwParams, sizeof(FlushDwParams));
-    FlushDwParams.postSyncOperation             = MHW_FLUSH_WRITE_TIMESTAMP_REG;
-    FlushDwParams.dwResourceOffset              = offset;
-    FlushDwParams.pOsResource                   = &m_perfStoreBuffer;
+        MOS_ZeroMemory(&FlushDwParams, sizeof(FlushDwParams));
+        FlushDwParams.postSyncOperation             = MHW_FLUSH_WRITE_TIMESTAMP_REG;
+        FlushDwParams.dwResourceOffset              = offset;
+        FlushDwParams.pOsResource                   = &m_perfStoreBuffer;
 
-    CHK_STATUS_RETURN(miInterface->AddMiFlushDwCmd(
-        cmdBuffer,
-        &FlushDwParams));
+        CHK_STATUS_RETURN(miInterface->AddMiFlushDwCmd(
+            cmdBuffer,
+            &FlushDwParams));
+    }
 
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS MediaPerfProfiler::AddPerfCollectStartCmd(void* context, 
+MOS_STATUS MediaPerfProfiler::StoreDataNext(
+    MhwMiInterface* miInterface,
+    PMOS_COMMAND_BUFFER cmdBuffer,
+    uint32_t offset,
+    uint32_t value)
+{
+    std::shared_ptr<mhw::mi::Itf> miItf = std::static_pointer_cast<mhw::mi::Itf>(miInterface->GetNewMiInterface());
+
+    if (miItf == nullptr)
+    {
+        return (StoreData(miInterface, cmdBuffer, offset, value));
+    }
+
+    auto &storeDataParams            = miItf->MHW_GETPAR_F(MI_STORE_DATA_IMM)();
+    storeDataParams                  = {};
+    storeDataParams.pOsResource      = &m_perfStoreBuffer;
+    storeDataParams.dwResourceOffset = offset;
+    storeDataParams.dwValue          = value;
+
+    CHK_STATUS_RETURN(miItf->MHW_ADDCMD_F(MI_STORE_DATA_IMM)(cmdBuffer));
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS MediaPerfProfiler::StoreRegisterNext(
+    MOS_INTERFACE* osInterface,
+    MhwMiInterface* miInterface,
+    PMOS_COMMAND_BUFFER cmdBuffer,
+    uint32_t offset,
+    uint32_t reg)
+{
+    std::shared_ptr<mhw::mi::Itf> miItf = std::static_pointer_cast<mhw::mi::Itf>(miInterface->GetNewMiInterface());
+
+    if (miItf == nullptr)
+    {
+        return (StoreRegister(osInterface, miInterface, cmdBuffer, offset, reg));
+    }
+
+    auto& storeRegMemParams           = miItf->MHW_GETPAR_F(MI_STORE_REGISTER_MEM)();
+    storeRegMemParams                 = {};
+    storeRegMemParams.presStoreBuffer = &m_perfStoreBuffer;
+    storeRegMemParams.dwOffset        = offset;
+    storeRegMemParams.dwRegister      = reg;
+
+    MEDIA_FEATURE_TABLE* skuTable = osInterface->pfnGetSkuTable(osInterface);
+    if (skuTable && MEDIA_IS_SKU(skuTable, FtrMemoryRemapSupport))
+    {
+        storeRegMemParams.dwOption = CCS_HW_FRONT_END_MMIO_REMAP;
+    }
+
+    CHK_STATUS_RETURN(miItf->MHW_ADDCMD_F(MI_STORE_REGISTER_MEM)(cmdBuffer));
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS MediaPerfProfiler::StoreTSByPipeCtrlNext(
+    MhwMiInterface* miInterface,
+    PMOS_COMMAND_BUFFER cmdBuffer,
+    uint32_t offset)
+{
+    std::shared_ptr<mhw::mi::Itf> miItf = std::static_pointer_cast<mhw::mi::Itf>(miInterface->GetNewMiInterface());
+
+    if (miItf == nullptr)
+    {
+        return (StoreTSByPipeCtrl(miInterface, cmdBuffer, offset));
+    }
+
+    auto& PipeControlParams            = miItf->MHW_GETPAR_F(PIPE_CONTROL)();
+    PipeControlParams                  = {};
+    PipeControlParams.dwResourceOffset = offset;
+    PipeControlParams.dwPostSyncOp     = MHW_FLUSH_WRITE_TIMESTAMP_REG;
+    PipeControlParams.dwFlushMode      = MHW_FLUSH_READ_CACHE;
+    PipeControlParams.presDest         = &m_perfStoreBuffer;
+
+    CHK_STATUS_RETURN(miItf->MHW_ADDCMD_F(PIPE_CONTROL)(cmdBuffer));
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS MediaPerfProfiler::StoreTSByMiFlushNext(
+    MhwMiInterface* miInterface,
+    PMOS_COMMAND_BUFFER cmdBuffer,
+    uint32_t offset)
+{
+    std::shared_ptr<mhw::mi::Itf> miItf = std::static_pointer_cast<mhw::mi::Itf>(miInterface->GetNewMiInterface());
+
+    if (miItf == nullptr)
+    {
+        return (StoreTSByMiFlush(miInterface, cmdBuffer, offset));
+    }
+
+    auto& FlushDwParams             = miItf->MHW_GETPAR_F(MI_FLUSH_DW)();
+    FlushDwParams                   = {};
+    FlushDwParams.postSyncOperation = MHW_FLUSH_WRITE_TIMESTAMP_REG;
+    FlushDwParams.dwResourceOffset  = offset;
+    FlushDwParams.pOsResource       = &m_perfStoreBuffer;
+
+    CHK_STATUS_RETURN(miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(cmdBuffer));
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS MediaPerfProfiler::AddPerfCollectStartCmd(void* context,
     MOS_INTERFACE *osInterface,
     MhwMiInterface *miInterface,
     MOS_COMMAND_BUFFER *cmdBuffer)
@@ -448,14 +435,21 @@ MOS_STATUS MediaPerfProfiler::AddPerfCollectStartCmd(void* context,
 
     uint32_t perfDataIndex = 0;
 
-    MOS_LockMutex(m_mutex);
+    MosUtilities::MosLockMutex(m_mutex);
 
     perfDataIndex = m_perfDataIndex;
     m_perfDataIndex++;
 
-    MOS_UnlockMutex(m_mutex);
+    MosUtilities::MosUnlockMutex(m_mutex);
+
+    if (BASE_OF_NODE(perfDataIndex) + sizeof(PerfEntry) > m_bufferSize)
+    {
+        MOS_OS_ASSERTMESSAGE("Reached maximum perf data buffer size, please increase it in Performance\\Perf Profiler Buffer Size");
+        return MOS_STATUS_NOT_ENOUGH_BUFFER;
+    }
 
     m_contextIndexMap[context] = perfDataIndex;
+    m_miItf = std::static_pointer_cast<mhw::mi::Itf>(miInterface->GetNewMiInterface());
 
     bool             rcsEngineUsed = false;
     MOS_GPU_CONTEXT  gpuContext;
@@ -465,30 +459,30 @@ MOS_STATUS MediaPerfProfiler::AddPerfCollectStartCmd(void* context,
 
     if (m_multiprocess)
     {
-        CHK_STATUS_RETURN(StoreData(
+        CHK_STATUS_RETURN(StoreDataNext(
             miInterface,
             cmdBuffer,
             BASE_OF_NODE(perfDataIndex) + OFFSET_OF(PerfEntry, processId),
-            MOS_GetPid()));
+            MosUtilities::MosGetPid()));
     }
 
-    CHK_STATUS_RETURN(StoreData(
+    CHK_STATUS_RETURN(StoreDataNext(
         miInterface,
-        cmdBuffer, 
+        cmdBuffer,
         BASE_OF_NODE(perfDataIndex) + OFFSET_OF(PerfEntry, perfTag),
         osInterface->pfnGetPerfTag(osInterface)));
 
-    CHK_STATUS_RETURN(StoreData(
+    CHK_STATUS_RETURN(StoreDataNext(
         miInterface,
-        cmdBuffer, 
+        cmdBuffer,
         BASE_OF_NODE(perfDataIndex) + OFFSET_OF(PerfEntry, engineTag),
         GpuContextToGpuNode(gpuContext)));
- 
+
     if (m_timerBase != 0)
     {
-        CHK_STATUS_RETURN(StoreData(
+        CHK_STATUS_RETURN(StoreDataNext(
             miInterface,
-            cmdBuffer, 
+            cmdBuffer,
             BASE_OF_NODE(perfDataIndex) + OFFSET_OF(PerfEntry, timeStampBase),
             m_timerBase));
     }
@@ -498,10 +492,10 @@ MOS_STATUS MediaPerfProfiler::AddPerfCollectStartCmd(void* context,
     {
         if (m_registers[regIndex] != 0)
         {
-            CHK_STATUS_RETURN(StoreRegister(
+            CHK_STATUS_RETURN(StoreRegisterNext(
                 osInterface,
                 miInterface,
-                cmdBuffer, 
+                cmdBuffer,
                 BASE_OF_NODE(perfDataIndex) + OFFSET_OF(PerfEntry, beginRegisterValue[regIndex]),
                 m_registers[regIndex]));
         }
@@ -513,32 +507,32 @@ MOS_STATUS MediaPerfProfiler::AddPerfCollectStartCmd(void* context,
 
     for (int i = 0; i < 2; i++)
     {
-        CHK_STATUS_RETURN(StoreData(
+        CHK_STATUS_RETURN(StoreDataNext(
             miInterface,
             cmdBuffer,
             BASE_OF_NODE(perfDataIndex) + OFFSET_OF(PerfEntry, beginCpuTime[i]),
             timeStamp[i]));
     }
- 
+
     // The address of timestamp must be 8 bytes aligned.
     uint32_t offset = BASE_OF_NODE(perfDataIndex) + OFFSET_OF(PerfEntry, beginTimeClockValue);
     offset = MOS_ALIGN_CEIL(offset, 8);
 
     if (rcsEngineUsed)
     {
-        CHK_STATUS_RETURN(StoreTSByPipeCtrl(
-            miInterface,
-            cmdBuffer, 
-            offset));
-    }
-    else
-    {
-        CHK_STATUS_RETURN(StoreTSByMiFlush(
+        CHK_STATUS_RETURN(StoreTSByPipeCtrlNext(
             miInterface,
             cmdBuffer,
             offset));
     }
-    
+    else
+    {
+        CHK_STATUS_RETURN(StoreTSByMiFlushNext(
+            miInterface,
+            cmdBuffer,
+            offset));
+    }
+
     return status;
 }
 
@@ -561,6 +555,7 @@ MOS_STATUS MediaPerfProfiler::AddPerfCollectEndCmd(void* context,
     MOS_GPU_CONTEXT  gpuContext;
     bool             rcsEngineUsed = false;
     uint32_t         perfDataIndex = 0;
+    m_miItf = std::static_pointer_cast<mhw::mi::Itf>(miInterface->GetNewMiInterface());
 
     gpuContext     = osInterface->pfnGetGpuContext(osInterface);
     rcsEngineUsed = MOS_RCS_ENGINE_USED(gpuContext);
@@ -572,10 +567,10 @@ MOS_STATUS MediaPerfProfiler::AddPerfCollectEndCmd(void* context,
     {
         if (m_registers[regIndex] != 0)
         {
-            CHK_STATUS_RETURN(StoreRegister(
+            CHK_STATUS_RETURN(StoreRegisterNext(
                 osInterface,
                 miInterface,
-                cmdBuffer, 
+                cmdBuffer,
                 BASE_OF_NODE(perfDataIndex) + OFFSET_OF(PerfEntry, endRegisterValue[regIndex]),
                 m_registers[regIndex]));
         }
@@ -587,14 +582,14 @@ MOS_STATUS MediaPerfProfiler::AddPerfCollectEndCmd(void* context,
 
     if (rcsEngineUsed)
     {
-        CHK_STATUS_RETURN(StoreTSByPipeCtrl(
+        CHK_STATUS_RETURN(StoreTSByPipeCtrlNext(
             miInterface,
             cmdBuffer,
             offset));
     }
     else
     {
-        CHK_STATUS_RETURN(StoreTSByMiFlush(
+        CHK_STATUS_RETURN(StoreTSByMiFlushNext(
             miInterface,
             cmdBuffer,
             offset));
@@ -608,13 +603,16 @@ MOS_STATUS MediaPerfProfiler::SavePerfData(MOS_INTERFACE *osInterface)
     MOS_STATUS status = MOS_STATUS_SUCCESS;
 
     CHK_NULL_RETURN(osInterface);
-    
-    if (m_perfDataIndex > 0)
+
+    MediaPerfProfilerNext *profilerNext = MediaPerfProfilerNext::Instance();
+    CHK_NULL_RETURN(profilerNext);
+
+    if (m_perfDataIndex > 0 || profilerNext->m_perfDataIndex > 0)
     {
         MOS_LOCK_PARAMS     LockFlagsNoOverWrite;
         MOS_ZeroMemory(&LockFlagsNoOverWrite, sizeof(MOS_LOCK_PARAMS));
 
-        LockFlagsNoOverWrite.WriteOnly   = 1;
+        LockFlagsNoOverWrite.WriteOnly = 1;
         LockFlagsNoOverWrite.NoOverWrite = 1;
 
         uint8_t* pData = (uint8_t*)osInterface->pfnLockResource(
@@ -623,90 +621,47 @@ MOS_STATUS MediaPerfProfiler::SavePerfData(MOS_INTERFACE *osInterface)
             &LockFlagsNoOverWrite);
 
         CHK_NULL_RETURN(pData);
-        
+
+        uint8_t* pDataNext = (uint8_t*)osInterface->pfnLockResource(
+            osInterface,
+            &profilerNext->m_perfStoreBuffer,
+            &LockFlagsNoOverWrite);
+
+        if (pDataNext)
+        {
+            //Append perf data written by APO perf Profiler into legacy one to avoid file overritting.
+            MosUtilities::MosSecureMemcpy(
+                pData+BASE_OF_NODE(m_perfDataIndex),
+                BASE_OF_NODE(profilerNext->m_perfDataIndex)-sizeof(NodeHeader),
+                pDataNext+sizeof(NodeHeader),
+                BASE_OF_NODE(profilerNext->m_perfDataIndex)-sizeof(NodeHeader));
+        }
+
         if (m_multiprocess)
         {
-            int32_t pid       = MOS_GetPid();
-            tm      localtime = {0};
-            MOS_GetLocalTime(&localtime);
+            int32_t pid = MosUtilities::MosGetPid();
+            tm      localtime = { 0 };
+            MosUtilities::MosGetLocalTime(&localtime);
             char outputFileName[MOS_MAX_PATH_LENGTH + 1];
 
             MOS_SecureStringPrint(outputFileName, MOS_MAX_PATH_LENGTH + 1, MOS_MAX_PATH_LENGTH + 1, "%s-pid%d-%04d%02d%02d%02d%02d%02d.bin",
                 m_outputFileName, pid, localtime.tm_year + 1900, localtime.tm_mon + 1, localtime.tm_mday, localtime.tm_hour, localtime.tm_min, localtime.tm_sec);
 
-            MOS_WriteFileFromPtr(outputFileName, pData, BASE_OF_NODE(m_perfDataIndex));
+            MosUtilities::MosWriteFileFromPtr(outputFileName, pData, BASE_OF_NODE(m_perfDataIndex)+BASE_OF_NODE(profilerNext->m_perfDataIndex)-sizeof(NodeHeader));
         }
         else
         {
-            MOS_WriteFileFromPtr(m_outputFileName, pData, BASE_OF_NODE(m_perfDataIndex));
+            MosUtilities::MosWriteFileFromPtr(m_outputFileName, pData, BASE_OF_NODE(m_perfDataIndex)+BASE_OF_NODE(profilerNext->m_perfDataIndex)-sizeof(NodeHeader));
         }
 
         osInterface->pfnUnlockResource(
             osInterface,
             &m_perfStoreBuffer);
+
+        osInterface->pfnUnlockResource(
+            osInterface,
+            &profilerNext->m_perfStoreBuffer);
     }
 
     return status;
 }
-
-PerfGPUNode MediaPerfProfiler::GpuContextToGpuNode(MOS_GPU_CONTEXT context)
-{
-    PerfGPUNode node = PERF_GPU_NODE_UNKNOW;
-
-    switch (context)
-    {
-        case MOS_GPU_CONTEXT_RENDER:
-        case MOS_GPU_CONTEXT_RENDER2:
-        case MOS_GPU_CONTEXT_RENDER3:
-        case MOS_GPU_CONTEXT_RENDER4:
-        case MOS_GPU_OVERLAY_CONTEXT:
-        case MOS_GPU_CONTEXT_RENDER_RA:
-            node = PERF_GPU_NODE_3D;
-            break;
-        case MOS_GPU_CONTEXT_COMPUTE:
-        case MOS_GPU_CONTEXT_CM_COMPUTE:
-        case MOS_GPU_CONTEXT_COMPUTE_RA:
-            node = PERF_GPU_NODE_3D;
-            break;
-        case MOS_GPU_CONTEXT_VIDEO:
-        case MOS_GPU_CONTEXT_VIDEO2:
-        case MOS_GPU_CONTEXT_VIDEO3:
-        case MOS_GPU_CONTEXT_VIDEO4:
-        case MOS_GPU_CONTEXT_VIDEO5:
-        case MOS_GPU_CONTEXT_VIDEO6:
-        case MOS_GPU_CONTEXT_VIDEO7:
-            node = PERF_GPU_NODE_VIDEO;
-            break;
-        case MOS_GPU_CONTEXT_VDBOX2_VIDEO:
-        case MOS_GPU_CONTEXT_VDBOX2_VIDEO2:
-        case MOS_GPU_CONTEXT_VDBOX2_VIDEO3:
-            node = PERF_GPU_NODE_VIDEO2;
-            break;
-        case MOS_GPU_CONTEXT_VEBOX:
-        case MOS_GPU_CONTEXT_VEBOX2:
-            node = PERF_GPU_NODE_VE;
-            break;
-        default:
-            node = PERF_GPU_NODE_UNKNOW;
-            break;
-    }
-
-    return node;
-}
-
-bool MediaPerfProfiler::IsPerfModeWidthMemInfo(uint32_t *regs)
-{
-    int8_t index = 0;
-    bool   ret   = false;
-
-    for (index = 0; index < 8; index++)
-    {
-        if (regs[index] != 0)
-        {
-            ret = true;
-            break;
-        }
-    }
-    
-    return ret;
-}
