@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2021, Intel Corporation
+* Copyright (c) 2009-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -34,6 +34,7 @@
 #include "mhw_sfc.h"
 #include "vp_pipeline_adapter_base.h"
 #include "vp_feature_report.h"
+#include "vphal_common_hdr.h"
 
 //*-----------------------------------------------------------------------------
 //| DEFINITIONS
@@ -276,6 +277,13 @@ enum VpKernelID
     baseKernelMaxNumID
 };
 
+enum VpKernelIDNext
+{
+    vpKernelIDNextBase  = 0x100,
+    kernelHdr3DLutCalc  = vpKernelIDNextBase,
+    vpKernelIDNextMax
+};
+
 //!
 //! \brief VPHAL SS/EU setting
 //!
@@ -287,6 +295,16 @@ struct VphalSseuSetting
     uint8_t   reserved;       // Place holder for frequency setting
 };
 
+//!
+//! \brief Gpu context entry
+//!
+struct VPHAL_GPU_CONTEXT_ENTRY
+{
+    MOS_GPU_CONTEXT    gpuCtxForMos          = MOS_GPU_CONTEXT_MAX;
+    GPU_CONTEXT_HANDLE gpuContextHandle      = MOS_GPU_CONTEXT_INVALID_HANDLE;
+    void*              pGpuContext           = nullptr;
+};
+
 //-----------------------------------------------------------------------------
 // VPHAL-DDI RENDERING INTERFACE
 //
@@ -317,6 +335,9 @@ using VphalFeatureReport = VpFeatureReport;
 class VphalState
 {
 public:
+    // Perf Optimize for ClearVideoView DDI
+    bool m_clearVideoViewMode = false;
+
     // factory function
     static VphalState* VphalStateFactory(
         PMOS_INTERFACE          pOsInterface,
@@ -472,7 +493,15 @@ public:
 
         if (m_veboxInterface != nullptr)
         {
-            MOS_STATUS eStatus = m_veboxInterface->DestroyHeap();
+            m_veboxItf = std::static_pointer_cast<mhw::vebox::Itf>(m_veboxInterface->GetNewVeboxInterface());
+            MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+
+            if (m_veboxItf)
+            {
+                eStatus = m_veboxItf->DestroyHeap();
+            }
+
+            eStatus = m_veboxInterface->DestroyHeap();
             MOS_Delete(m_veboxInterface);
             m_veboxInterface = nullptr;
             if (eStatus != MOS_STATUS_SUCCESS)
@@ -482,6 +511,7 @@ public:
         }
 
         m_veboxInterface = veboxInterface;
+        m_veboxItf = std::static_pointer_cast<mhw::vebox::Itf>(veboxInterface->GetNewVeboxInterface());
     }
 
     void SetMhwSfcInterface(MhwSfcInterface* sfcInterface)
@@ -518,6 +548,7 @@ protected:
     MhwCpInterface              *m_cpInterface;
     PMHW_SFC_INTERFACE          m_sfcInterface;
     VphalRenderer               *m_renderer;
+    std::shared_ptr<mhw::vebox::Itf> m_veboxItf = nullptr;
 
     // Render GPU context/node
     MOS_GPU_NODE                m_renderGpuNode;
@@ -526,6 +557,13 @@ protected:
     // StatusTable indicating if command is done by gpu or not
     VPHAL_STATUS_TABLE          m_statusTable = {};
 
+
+    // Same MOS_GPU_CONTEXT may be created in MediaContext with a different handle,
+    // which will cause the gpuContext created in VphalState missed to be destroyed during
+    // m_osInterface being destroyed. m_gpuContextCheckList is used to store gpu contexts
+    // which may encounter such case.
+    std::vector<VPHAL_GPU_CONTEXT_ENTRY> m_gpuContextCheckList;
+
     //!
     //! \brief    Create instance of VphalRenderer
     //! \details  Create instance of VphalRenderer
@@ -538,6 +576,27 @@ protected:
     {
         return false;
     }
+
+private:
+    //!
+    //! \brief    Put GPU context entry
+    //! \details  Put GPU context entry in the m_gpuContextCheckList
+    //! \param    MOS_GPU_CONTEXT mosGpuConext
+    //!           [in] Mos GPU context
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    MOS_STATUS AddGpuContextToCheckList(
+        MOS_GPU_CONTEXT mosGpuConext);
+
+    //!
+    //! \brief    Destroy GPU context entry with invalid handle
+    //! \details  Release these GPU context overwritten by MediaContext
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    MOS_STATUS DestroyGpuContextWithInvalidHandle();
+
 };
 
 #endif  // __VPHAL_H__
