@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2010-2017, Intel Corporation
+* Copyright (c) 2010-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -485,6 +485,14 @@ struct MEDIA_WALKER_KA2_STATIC_DATA
             uint32_t       PointerToInlineParameters   : 8;
         };
 
+        struct
+        {
+            uint32_t       ConstantBlendingAlphaLayer51 : 8;
+            uint32_t       ConstantBlendingAlphaLayer61 : 8;
+            uint32_t       ConstantBlendingAlphaLayer71 : 8;
+            uint32_t       OutputDepth                  : 8;
+        };
+
         // DNDI
         struct
         {
@@ -1476,6 +1484,14 @@ struct MEDIA_OBJECT_KA2_STATIC_DATA
             uint32_t       PointerToInlineParameters   : 8;
         };
 
+        struct
+        {
+            uint32_t       ConstantBlendingAlphaLayer51 : 8;
+            uint32_t       ConstantBlendingAlphaLayer61 : 8;
+            uint32_t       ConstantBlendingAlphaLayer71 : 8;
+            uint32_t       OutputDepth                  : 8;
+        };
+
         // DNDI
         struct
         {
@@ -1562,7 +1578,8 @@ struct MEDIA_OBJECT_KA2_STATIC_DATA
             uint32_t       RotationAngleofLayer6       : 3;
             uint32_t       RotationAngleofLayer7       : 3;
             uint32_t       ChromaSitingLocation        : 3;
-            uint32_t                                   : 5;
+            uint32_t       MonoXORCompositeMask        : 3;
+            uint32_t                                   : 2;
         } ObjKa2Gen9;
 
         uint32_t       Value;
@@ -2312,17 +2329,19 @@ typedef enum _VEBOX_EXECUTION_MODE
     VEBOX_EXEC_MODE_2_TO_0 = 3                                                  //!< No future frame so switch back to non-parallel serial legacy mode.
 } VEBOX_EXECUTION_MODE;
 
+#define MAX_VEBOX_EXECUTION_MODE 4
 //!
 //! \brief Controls Vebox execution mode
 //!
 typedef struct _VPHAL_VEBOX_EXEC_STATE
 {
-    bool                    bEnable;                                            //!< false, legacy serial execution. true, capable of parallel vebox/render execution
-    VEBOX_EXECUTION_MODE    Mode;                                               //!< Current mode of operation.
-    bool                    bDIOutputPair01;                                    //!< Used to alternate between ADI output pairs.
-    bool                    bSpeculativeCopy;                                   //!< true, update VEBOX state for frame N+1 using frame N state
-    bool                    bFrcActive;                                         //!< When FRC is active, stay in VEBOX_EXEC_MODE_0
-    bool                    bPostponedFMDCalc;                                  //!< When in mode2, need to calc fmd variance after composition
+    bool                    bEnable                             = false;                                   //!< false, legacy serial execution. true, capable of parallel vebox/render execution
+    VEBOX_EXECUTION_MODE    Mode                                = VEBOX_EXEC_MODE_0;                       //!< Current mode of operation.
+    bool                    bDIOutputPair01                     = false;                                   //!< Used to alternate between ADI output pairs.
+    bool                    bSpeculativeCopy                    = false;                                   //!< true, update VEBOX state for frame N+1 using frame N state
+    bool                    bFrcActive                          = false;                                   //!< When FRC is active, stay in VEBOX_EXEC_MODE_0
+    bool                    bPostponedFMDCalc                   = false;                                   //!< When in mode2, need to calc fmd variance after composition
+    uint32_t                ModeCount[MAX_VEBOX_EXECUTION_MODE] = {0};
 } VPHAL_VEBOX_EXEC_STATE, *PVPHAL_VEBOX_EXEC_STATE;
 
 #define RESET_VEBOX_SPECULATIVE_COPY(_a)              (_a->bSpeculativeCopy = false)
