@@ -339,6 +339,12 @@ public:
         PCVPHAL_RENDER_PARAMS  pcRenderParams,
         RenderpassData         *pRenderPassData);
 
+    void PrintCurbeData(MEDIA_OBJECT_KA2_STATIC_DATA *pWalkerStatic);
+
+    void PrintWalkerParas(PMHW_GPGPU_WALKER_PARAMS pWalkerParams);
+
+    void PrintSamplerParams(PMHW_SAMPLER_STATE_PARAM pSamplerParams);
+
     //!
     //! \brief    set Report data
     //! \details  set Report data for this render
@@ -1016,6 +1022,16 @@ private:
         PVPHAL_SURFACE                  pSource,
         PRENDERHAL_SURFACE_STATE_PARAMS pSurfaceParams);
 
+    //!
+    //! \brief    Decompress the Surface
+    //! \details  Decompress the interlaced Surface which is in the RC compression mode
+    //! \param    [in,out] pSource
+    //!           Pointer to Source Surface
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    MOS_STATUS DecompressInterlacedSurfInRCMode(PVPHAL_SURFACE pSource);
+
     //!
     //! \brief    Allocate Composite BatchBuffer
     //! \details  Allocate Composite BatchBuffer, search from existing BBs for a match. If
@@ -1169,6 +1185,8 @@ protected:
     VPHAL_SURFACE                   m_Intermediate  = {};         //!< Intermediate surface (multiple phase / constriction support)
     VPHAL_SURFACE                   m_Intermediate1 = {};         //!< Intermediate surface (multiple phase / constriction support)
     VPHAL_SURFACE                   m_Intermediate2 = {};         //!< Rotation output intermediate surface
+    
+    VPHAL_SURFACE                   m_AuxiliarySyncSurface = {};  //!< This Auxiliary surface is used to sync engine workload
 
     Kdll_State                      *m_pKernelDllState = nullptr; //!< Compositing Kernel DLL/Search state
     RENDERHAL_KERNEL_PARAM          m_KernelParams = {0};
