@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2012-2020, Intel Corporation
+* Copyright (c) 2012-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -120,6 +120,30 @@ MHW_ROTATION VpHal_GetMhwRotationParam(VPHAL_ROTATION Rotation)
     }
 }
 
+//!
+//! \brief    Get SFC Scaling mode parameter
+//! \details  Get MHW SFC Scaling mode parameter
+//! \param    [in] Scaling mode
+//!           VPHAL Scaling mode parameter
+//! \return   MHW_SCALING_MODE
+//!
+MHW_SCALING_MODE VpHal_GetMhwScalingModeParam(VPHAL_SCALING_MODE ScalingMode)
+{
+    switch (ScalingMode)
+    {
+    case VPHAL_SCALING_NEAREST:
+        return MHW_SCALING_NEAREST;                         // Nearest interpolation
+
+    case VPHAL_SCALING_BILINEAR:
+        return MHW_SCALING_BILINEAR;                        // Bilinear interpolation
+
+    case VPHAL_SCALING_AVS:
+    case VPHAL_SCALING_ADV_QUALITY:
+    default:
+        return MHW_SCALING_AVS;
+    }
+}
+
 bool VphalSfcState::IsFormatMMCSupported(
     MOS_FORMAT                  Format)
 {
@@ -466,8 +490,11 @@ VPHAL_OUTPUT_PIPE_MODE VphalSfcState::GetOutputPipe(
     }
 
     bColorFill = (pcRenderParams->pColorFillParams &&
-                  (!RECT1_CONTAINS_RECT2(pSrc->rcDst, pRenderTarget->rcDst))) ?
-                 true : false;
+                  (!pcRenderParams->pColorFillParams->bDisableColorfillinSFC) &&
+                  (pcRenderParams->pColorFillParams->bOnePixelBiasinSFC ?
+                   (!RECT1_CONTAINS_RECT2_ONEPIXELBIAS(pSrc->rcDst, pRenderTarget->rcDst)) :
+                   (!RECT1_CONTAINS_RECT2(pSrc->rcDst, pRenderTarget->rcDst)))) ?
+                  true : false;
 
     if (IsOutputCapable(bColorFill, pSrc, pRenderTarget))
     {
@@ -627,9 +654,13 @@ void VphalSfcState::SetRenderingFlags(
     m_renderData.bScaling   = ((fScaleX == 1.0F) && (fScaleY == 1.0F)) ?
                                  false : true;
 
-    m_renderData.bColorFill = (pColorFillParams && pSrc->InterlacedScalingType == ISCALING_NONE &&
-                                  (!RECT1_CONTAINS_RECT2(pSrc->rcDst, pRenderTarget->rcDst))) ?
-                                 true : false;
+    m_renderData.bColorFill = (pColorFillParams &&
+                               (!pColorFillParams->bDisableColorfillinSFC) &&
+                               pSrc->InterlacedScalingType == ISCALING_NONE &&
+                               (pColorFillParams->bOnePixelBiasinSFC ?
+                               (!RECT1_CONTAINS_RECT2_ONEPIXELBIAS(pSrc->rcDst, pRenderTarget->rcDst)) :
+                               (!RECT1_CONTAINS_RECT2(pSrc->rcDst, pRenderTarget->rcDst)))) ?
+                               true : false;
 
     m_renderData.bIEF       = (pSrc->pIEFParams              &&
                                   pSrc->pIEFParams->bEnabled    &&
@@ -803,12 +834,20 @@ MOS_STATUS VphalSfcState::AllocateResources()
     uint32_t                dwSize;
     bool                    bAllocated;
     PMHW_SFC_STATE_PARAMS   pSfcStateParams;
+    Mos_MemPool             memTypeSurfVideoMem = MOS_MEMPOOL_VIDEOMEMORY;
 
     eStatus         = MOS_STATUS_UNKNOWN;
     bAllocated      = false;
     pSfcStateParams = m_renderData.SfcStateParams;
 
     VPHAL_RENDER_CHK_NULL(pSfcStateParams);
+    VPHAL_RENDER_CHK_NULL(m_renderHal);
+    VPHAL_RENDER_CHK_NULL(m_renderHal->pSkuTable);
+
+    if (MEDIA_IS_SKU(m_renderHal->pSkuTable, FtrLimitedLMemBar))
+    {
+        memTypeSurfVideoMem = MOS_MEMPOOL_DEVICEMEMORY;
+    }
 
     // Allocate AVS Line Buffer surface----------------------------------------------
     dwWidth  = 1;
@@ -826,7 +865,11 @@ MOS_STATUS VphalSfcState::AllocateResources()
         1,
         false,
         MOS_MMC_DISABLED,
-        &bAllocated));
+        &bAllocated,
+        MOS_HW_RESOURCE_DEF_MAX,
+        MOS_TILE_UNSET_GMM,
+        memTypeSurfVideoMem,
+        MOS_MEMPOOL_DEVICEMEMORY == memTypeSurfVideoMem));
 
     // Allocate IEF Line Buffer surface----------------------------------------------
     dwWidth  = 1;
@@ -844,7 +887,11 @@ MOS_STATUS VphalSfcState::AllocateResources()
         1,
         false,
         MOS_MMC_DISABLED,
-        &bAllocated));
+        &bAllocated,
+        MOS_HW_RESOURCE_DEF_MAX,
+        MOS_TILE_UNSET_GMM,
+        memTypeSurfVideoMem,
+        MOS_MEMPOOL_DEVICEMEMORY == memTypeSurfVideoMem));
 
     // Allocate SFD Line Buffer surface----------------------------------------------
     if (NEED_SFD_LINE_BUFFER(pSfcStateParams->dwScaledRegionHeight))
@@ -862,7 +909,11 @@ MOS_STATUS VphalSfcState::AllocateResources()
             1,
             false,
             MOS_MMC_DISABLED,
-            &bAllocated));
+            &bAllocated,
+            MOS_HW_RESOURCE_DEF_MAX,
+            MOS_TILE_UNSET_GMM,
+            memTypeSurfVideoMem,
+            MOS_MEMPOOL_DEVICEMEMORY == memTypeSurfVideoMem));
     }
 
 finish:
@@ -877,7 +928,8 @@ finish:
 void VphalSfcState::GetOutputWidthHeightAlignUnit(
     MOS_FORMAT              outputFormat,
     uint16_t                &widthAlignUnit,
-    uint16_t                &heightAlignUnit)
+    uint16_t                &heightAlignUnit,
+    bool                    isInterlacedScaling)
 {
     widthAlignUnit  = 1;
     heightAlignUnit = 1;
@@ -1050,14 +1102,16 @@ MOS_STATUS VphalSfcState::SetSfcStateParams(
     GetOutputWidthHeightAlignUnit(
         pSfcStateParams->OutputFrameFormat,
         wOutputWidthAlignUnit,
-        wOutputHeightAlignUnit);
+        wOutputHeightAlignUnit,
+        pSrcSurface->bInterlacedScaling);
 
     // Apply alignment restriction to Region of the input frame.
     GetInputWidthHeightAlignUnit(
         m_renderData.SfcInputFormat,
         pSfcStateParams->OutputFrameFormat,
         wInputWidthAlignUnit,
-        wInputHeightAlignUnit);
+        wInputHeightAlignUnit,
+        pSrcSurface->bInterlacedScaling);
 
     if(pSrcSurface->bDirectionalScalar)
     {
@@ -1072,9 +1126,28 @@ MOS_STATUS VphalSfcState::SetSfcStateParams(
     // Region of the input frame which needs to be processed by SFC
     pSfcStateParams->dwSourceRegionVerticalOffset   = MOS_ALIGN_CEIL((uint32_t)pSrcSurface->rcSrc.top,  wInputHeightAlignUnit);
     pSfcStateParams->dwSourceRegionHorizontalOffset = MOS_ALIGN_CEIL((uint32_t)pSrcSurface->rcSrc.left, wInputWidthAlignUnit);
-    pSfcStateParams->dwSourceRegionHeight           = MOS_ALIGN_FLOOR(
-                                                        MOS_MIN((uint32_t)(dwVeboxBottom - pSrcSurface->rcSrc.top), pSfcStateParams->dwInputFrameHeight),
-                                                        wInputHeightAlignUnit);
+
+
+    if (pSrcSurface->bInterlacedScaling && 
+        (pSrcSurface->rcSrc.bottom - pSrcSurface->rcSrc.top) == (pSrcSurface->rcDst.bottom - pSrcSurface->rcDst.top))
+    {
+        pSfcStateParams->dwSourceRegionHeight = MOS_ALIGN_CEIL(
+            MOS_MIN((uint32_t)(dwVeboxBottom - pSrcSurface->rcSrc.top), pSfcStateParams->dwInputFrameHeight),
+            wInputHeightAlignUnit);
+
+        if (pSfcStateParams->dwSourceRegionHeight > pSfcStateParams->dwInputFrameHeight)
+        {
+            pSfcStateParams->dwSourceRegionHeight -= wInputHeightAlignUnit;
+            VPHAL_RENDER_ASSERTMESSAGE("Interlaced scaling case: surface height is %d, which is not 4 align. Use floor align.", pSfcStateParams->dwInputFrameHeight);
+        }
+    }
+    else
+    {
+        pSfcStateParams->dwSourceRegionHeight = MOS_ALIGN_FLOOR(
+            MOS_MIN((uint32_t)(dwVeboxBottom - pSrcSurface->rcSrc.top), pSfcStateParams->dwInputFrameHeight),
+            wInputHeightAlignUnit);
+    }
+
     pSfcStateParams->dwSourceRegionWidth            = MOS_ALIGN_FLOOR(
                                                         MOS_MIN((uint32_t)(dwVeboxRight  - pSrcSurface->rcSrc.left), pSfcStateParams->dwInputFrameWidth),
                                                         wInputWidthAlignUnit);
@@ -1083,6 +1156,8 @@ MOS_STATUS VphalSfcState::SetSfcStateParams(
     pSfcStateParams->dwScaledRegionHeight           = MOS_ALIGN_CEIL(MOS_UF_ROUND(m_renderData.fScaleY * pSfcStateParams->dwSourceRegionHeight), wOutputHeightAlignUnit);
     pSfcStateParams->dwScaledRegionWidth            = MOS_ALIGN_CEIL(MOS_UF_ROUND(m_renderData.fScaleX * pSfcStateParams->dwSourceRegionWidth), wOutputWidthAlignUnit);
 
+
+
     // Scaled region is pre-rotated. Adjust its width and height with those of the output frame
     if (m_renderData.SfcRotation == VPHAL_ROTATION_IDENTITY ||
         m_renderData.SfcRotation == VPHAL_ROTATION_180      ||
@@ -1111,10 +1186,15 @@ MOS_STATUS VphalSfcState::SetSfcStateParams(
     // in either direction. We must check for this before clamping the SF.
     if (IS_YUV_FORMAT(m_renderData.SfcInputFormat) &&
         (m_renderData.fScaleX > 1.0F               ||
-         m_renderData.fScaleY > 1.0F))
+        m_renderData.fScaleY > 1.0F))
     {
         pSfcStateParams->bBypassXAdaptiveFilter = false;
         pSfcStateParams->bBypassYAdaptiveFilter = false;
+
+        if (MEDIASTATE_SFC_AVS_FILTER_BILINEAR == pSfcStateParams->dwAVSFilterMode)
+        {
+            VPHAL_RENDER_NORMALMESSAGE("Legacy Check: bBypassXAdaptiveFilter/bBypassYAdaptiveFilter are set to false for bilinear scaling.");
+        }
     }
     else
     {
@@ -1187,7 +1267,7 @@ MOS_STATUS VphalSfcState::SetSfcStateParams(
             m_colorFillRTCspace    = dst_cspace;
         }
 
-        if (IS_YUV_FORMAT(pOutSurface->Format) || (pOutSurface->Format == Format_AYUV))
+        if (IS_YUV_FORMAT(pOutSurface->Format) || IS_ALPHA_YUV_FORMAT(pOutSurface->Format))
         {
             pSfcStateParams->fColorFillYRPixel = (float)m_colorFillColorDst.Y / 255.0F;
             pSfcStateParams->fColorFillUGPixel = (float)m_colorFillColorDst.U / 255.0F;
@@ -1196,7 +1276,10 @@ MOS_STATUS VphalSfcState::SetSfcStateParams(
         else
         {
             // Swap the channel here because HW only natively supports XBGR output
-            if ((pOutSurface->Format == Format_A8R8G8B8) || (pOutSurface->Format == Format_X8R8G8B8) || (pOutSurface->Format == Format_R10G10B10A2))
+            if ((pOutSurface->Format == Format_A8R8G8B8)    ||
+                (pOutSurface->Format == Format_X8R8G8B8)    ||
+                (pOutSurface->Format == Format_R10G10B10A2) ||
+                (pOutSurface->Format == Format_A16R16G16B16))
             {
                 pSfcStateParams->fColorFillYRPixel = (float)m_colorFillColorDst.B / 255.0F;
                 pSfcStateParams->fColorFillUGPixel = (float)m_colorFillColorDst.G / 255.0F;
@@ -1234,16 +1317,16 @@ MOS_STATUS VphalSfcState::SetSfcStateParams(
             }
             break;
 
-            case VPHAL_ALPHA_FILL_MODE_BACKGROUND:
-                pSfcStateParams->fAlphaPixel = m_renderData.bColorFill ?
-                    pSfcStateParams->fColorFillAPixel : 1.0F;
-                break;
+        case VPHAL_ALPHA_FILL_MODE_BACKGROUND:
+            pSfcStateParams->fAlphaPixel = m_renderData.bColorFill ?
+                pSfcStateParams->fColorFillAPixel : 1.0F;
+            break;
 
-            case VPHAL_ALPHA_FILL_MODE_SOURCE_STREAM:
-            case VPHAL_ALPHA_FILL_MODE_OPAQUE:
-            default:
-                pSfcStateParams->fAlphaPixel      = 1.0F;
-                pSfcStateParams->fColorFillAPixel = 1.0F;
+        case VPHAL_ALPHA_FILL_MODE_SOURCE_STREAM:
+        case VPHAL_ALPHA_FILL_MODE_OPAQUE:
+        default:
+            pSfcStateParams->fAlphaPixel      = 1.0F;
+            pSfcStateParams->fColorFillAPixel = 1.0F;
         }
     }
     else
@@ -1358,44 +1441,65 @@ MOS_STATUS VphalSfcState::SetSfcMmcStatus(
 MOS_STATUS VphalSfcState::SetAvsStateParams()
 {
     MOS_STATUS                  eStatus = MOS_STATUS_SUCCESS;
-    PMHW_SFC_AVS_STATE          pMhwAvsState;
+    PMHW_SFC_AVS_STATE          pMhwAvsState = nullptr;
+
+    MHW_SCALING_MODE            scalingMode  = MHW_SCALING_AVS;
+    bool                        bUse8x8Filter = false;
 
     VPHAL_RENDER_CHK_NULL(m_sfcInterface);
 
     pMhwAvsState    = &m_avsState.AvsStateParams;
+    MOS_ZeroMemory(pMhwAvsState, sizeof(MHW_SFC_AVS_STATE));
 
-    pMhwAvsState->dwInputHorizontalSiting = (m_renderData.SfcSrcChromaSiting  & MHW_CHROMA_SITING_HORZ_CENTER) ? SFC_AVS_INPUT_SITING_COEF_4_OVER_8 :
-                                            ((m_renderData.SfcSrcChromaSiting & MHW_CHROMA_SITING_HORZ_RIGHT)  ? SFC_AVS_INPUT_SITING_COEF_8_OVER_8 :
-                                            SFC_AVS_INPUT_SITING_COEF_0_OVER_8);
-
-    pMhwAvsState->dwInputVerticalSitting  = (m_renderData.SfcSrcChromaSiting  & MHW_CHROMA_SITING_VERT_CENTER) ? SFC_AVS_INPUT_SITING_COEF_4_OVER_8 :
-                                            ((m_renderData.SfcSrcChromaSiting & MHW_CHROMA_SITING_VERT_BOTTOM) ? SFC_AVS_INPUT_SITING_COEF_8_OVER_8 :
-                                            SFC_AVS_INPUT_SITING_COEF_0_OVER_8);
-
-    if (m_renderData.SfcSrcChromaSiting == MHW_CHROMA_SITING_NONE)
+    if (m_renderData.bScaling ||
+        m_renderData.bForcePolyPhaseCoefs)
     {
-        m_renderData.SfcSrcChromaSiting = MHW_CHROMA_SITING_HORZ_LEFT | MHW_CHROMA_SITING_VERT_TOP;
+        pMhwAvsState->dwInputHorizontalSiting = (m_renderData.SfcSrcChromaSiting & MHW_CHROMA_SITING_HORZ_CENTER) ? SFC_AVS_INPUT_SITING_COEF_4_OVER_8 : ((m_renderData.SfcSrcChromaSiting & MHW_CHROMA_SITING_HORZ_RIGHT) ? SFC_AVS_INPUT_SITING_COEF_8_OVER_8 : SFC_AVS_INPUT_SITING_COEF_0_OVER_8);
 
-        if (VpHal_GetSurfaceColorPack(m_renderData.SfcInputFormat) == VPHAL_COLORPACK_420)  // For 420, default is Left & Center, else default is Left & Top
+        pMhwAvsState->dwInputVerticalSitting = (m_renderData.SfcSrcChromaSiting & MHW_CHROMA_SITING_VERT_CENTER) ? SFC_AVS_INPUT_SITING_COEF_4_OVER_8 : ((m_renderData.SfcSrcChromaSiting & MHW_CHROMA_SITING_VERT_BOTTOM) ? SFC_AVS_INPUT_SITING_COEF_8_OVER_8 : SFC_AVS_INPUT_SITING_COEF_0_OVER_8);
+
+        if (m_renderData.SfcSrcChromaSiting == MHW_CHROMA_SITING_NONE)
         {
-            pMhwAvsState->dwInputVerticalSitting = SFC_AVS_INPUT_SITING_COEF_4_OVER_8;
+            m_renderData.SfcSrcChromaSiting = MHW_CHROMA_SITING_HORZ_LEFT | MHW_CHROMA_SITING_VERT_TOP;
+
+            if (VpHal_GetSurfaceColorPack(m_renderData.SfcInputFormat) == VPHAL_COLORPACK_420)  // For 420, default is Left & Center, else default is Left & Top
+            {
+                pMhwAvsState->dwInputVerticalSitting = SFC_AVS_INPUT_SITING_COEF_4_OVER_8;
+            }
         }
+
+        m_renderData.pAvsParams->bForcePolyPhaseCoefs = m_renderData.bForcePolyPhaseCoefs;
+
+        scalingMode = VpHal_GetMhwScalingModeParam(m_renderData.SfcScalingMode);
+        VPHAL_RENDER_CHK_STATUS(m_sfcInterface->SetSfcAVSScalingMode(scalingMode));
+
+        if (m_renderData.SfcStateParams)
+        {
+            pMhwAvsState->dwAVSFilterMode = m_renderData.SfcStateParams->dwAVSFilterMode;
+        }
+        else
+        {
+            pMhwAvsState->dwAVSFilterMode = MEDIASTATE_SFC_AVS_FILTER_8x8;
+        }
+
+        if (pMhwAvsState->dwAVSFilterMode == MEDIASTATE_SFC_AVS_FILTER_8x8)
+        {
+            bUse8x8Filter = true;
+        }
+
+        VPHAL_RENDER_CHK_STATUS(m_sfcInterface->SetSfcSamplerTable(
+            &m_avsState.LumaCoeffs,
+            &m_avsState.ChromaCoeffs,
+            m_renderData.pAvsParams,
+            m_renderData.SfcInputFormat,
+            m_renderData.fScaleX,
+            m_renderData.fScaleY,
+            m_renderData.SfcSrcChromaSiting,
+            bUse8x8Filter,
+            0,
+            0));
     }
 
-    m_renderData.pAvsParams->bForcePolyPhaseCoefs = m_renderData.bForcePolyPhaseCoefs;
-
-    VPHAL_RENDER_CHK_STATUS(m_sfcInterface->SetSfcSamplerTable(
-        &m_avsState.LumaCoeffs,
-        &m_avsState.ChromaCoeffs,
-        m_renderData.pAvsParams,
-        m_renderData.SfcInputFormat,
-        m_renderData.fScaleX,
-        m_renderData.fScaleY,
-        m_renderData.SfcSrcChromaSiting,
-        true,
-        0,
-        0));
-
 finish:
     return eStatus;
 }
@@ -1516,11 +1620,7 @@ MOS_STATUS VphalSfcState::SetupSfcState(
             pOutSurface));
 
     // Setup params related to SFC_AVS_STATE
-    if (m_renderData.bScaling ||
-        m_renderData.bForcePolyPhaseCoefs)
-    {
-        VPHAL_RENDER_CHK_STATUS(SetAvsStateParams());
-    }
+    VPHAL_RENDER_CHK_STATUS(SetAvsStateParams());
 
     // Setup params related to SFC_IEF_STATE
     if (m_renderData.bIEF ||
@@ -1595,13 +1695,14 @@ MOS_STATUS VphalSfcState::SendSfcCmd(
         m_renderData.SfcStateParams,
         &OutSurfaceParam));
 
+    // Send SFC_AVS_STATE command
+    VPHAL_RENDER_CHK_STATUS(pSfcInterface->AddSfcAvsState(
+        pCmdBuffer,
+        &m_avsState.AvsStateParams));
+
     if (m_renderData.bScaling ||
         m_renderData.bForcePolyPhaseCoefs)
     {
-        // Send SFC_AVS_STATE command
-        VPHAL_RENDER_CHK_STATUS(pSfcInterface->AddSfcAvsState(
-            pCmdBuffer,
-            &m_avsState.AvsStateParams));
 
         // Send SFC_AVS_LUMA_TABLE command
         VPHAL_RENDER_CHK_STATUS(pSfcInterface->AddSfcAvsLumaTable(
