@@ -390,7 +390,8 @@ protected:
         MOS_FORMAT              inputFormat,
         MOS_FORMAT              outputFormat,
         uint16_t                &widthAlignUnit,
-        uint16_t                &heightAlignUnit) = 0;
+        uint16_t                &heightAlignUnit,
+        bool                    isInterlacedScaling = false) = 0;
 
     //!
     //! \brief    Get width and height align unit of output format
