@@ -172,7 +172,11 @@ struct CODECHAL_VDENC_HEVC_HUC_BRC_UPDATE_DMEM_G11
     uint32_t    SkipFrameSize;
     uint32_t    SliceHeaderSize;
     int8_t      EnableMotionAdaptive;
-    uint8_t     RSVD[15];  // 64-byte alignment
+    uint8_t     FrameSizeBoostForSceneChange;// UPD_TCBRC_SCENARIO_U8
+    uint8_t     ROMCurrent;                  // ROM average of current frame
+    uint8_t     ROMZero;                     // ROM zero percentage
+    uint32_t    TargetFrameSize;             // TR_BRC
+    uint8_t     RSVD[8];                     // 64-byte alignment
 };
 C_ASSERT(192 == sizeof(CODECHAL_VDENC_HEVC_HUC_BRC_UPDATE_DMEM_G11));
 
@@ -370,6 +374,7 @@ public:
     bool                        m_enableVdBoxHWSemaphore = false;        //!< Enable VDBOX HW semaphore
     // scalability
     unsigned char                         m_numPipe            = 1;         //!< Number of pipes
+    unsigned char                         m_numPipePre         = 1;         //!< Number of pipes of previous frame
     unsigned char                         m_numPassesInOnePipe = 1;         //!< Number of PAK passes in one pipe
     CODECHAL_ENCODE_BUFFER                m_resPakSliceLevelStreamoutData;  //!< Surface for slice level stream out data from PAK
     CODECHAL_HEVC_VIRTUAL_ENGINE_OVERRIDE m_kmdVeOveride;                   //!< KMD override virtual engine index
