@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2020, Intel Corporation
+* Copyright (c) 2017-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -1240,7 +1240,7 @@ public:
         if (avcPicParams->CodingType != I_TYPE)
         {
             cmd.DW2.BidirectionalWeight              = 0x20;
-            cmd.DW4.SubPelMode                       = 3;
+            cmd.DW4.SubPelMode                       = (avcPicParams->bEnableSubPelMode) ? avcPicParams->SubPelMode : 3;
             cmd.DW4.BmeDisableForFbrMessage          = 1;
             cmd.DW4.InterSadMeasureAdjustment        = 2;
             cmd.DW5.CrePrefetchEnable                = 1;
@@ -1294,7 +1294,7 @@ public:
             cmd.DW5.MbSliceThresholdValue            = params->dwMbSlcThresholdValue;
         }
 
-        cmd.DW6.SliceMacroblockHeightMinusOne        = params->wSlcHeightInMb - 1;
+        cmd.DW6.SliceMacroblockHeightMinusOne        = params->wPicHeightInMb - 1;
 
         cmd.DW8.LumaIntraPartitionMask               = avcPicParams->transform_8x8_mode_flag ? 0 : TVdencCmds::VDENC_IMG_STATE_CMD::LUMA_INTRA_PARTITION_MASK_UNNAMED2;
 
