@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2019, Intel Corporation
+* Copyright (c) 2017-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -118,7 +118,7 @@ MOS_STATUS CodechalHevcSfcStateG12::AllocateResources()
             allocParams.Type = MOS_GFXRES_BUFFER;
             allocParams.TileType = MOS_TILE_LINEAR;
             allocParams.Format = Format_Buffer;
-            allocParams.dwBytes = MOS_ROUNDUP_DIVIDE(m_outputSurfaceRegion.Width, 10) * MHW_SFC_CACHELINE_SIZE;
+            allocParams.dwBytes = MOS_ROUNDUP_DIVIDE(m_outputSurfaceRegion.m_width, 10) * MHW_SFC_CACHELINE_SIZE;
             allocParams.pBufName = "SfcSfdLineBuffer";
 
             for (int i = 0; i < m_numPipe; i++)
@@ -158,7 +158,7 @@ MOS_STATUS CodechalHevcSfcStateG12::AllocateResources()
         allocParams.Type     = MOS_GFXRES_BUFFER;
         allocParams.TileType = MOS_TILE_LINEAR;
         allocParams.Format   = Format_Buffer;
-        allocParams.dwBytes  = MOS_ROUNDUP_DIVIDE(m_outputSurfaceRegion.Width, 10) * MHW_SFC_CACHELINE_SIZE * 2; //double for safe
+        allocParams.dwBytes  = MOS_ROUNDUP_DIVIDE(m_outputSurfaceRegion.m_width, 10) * MHW_SFC_CACHELINE_SIZE * 2; //double for safe
         allocParams.pBufName = "SfcSfdLineTileBuffer";
 
         CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnAllocateResource(
@@ -199,7 +199,7 @@ MOS_STATUS CodechalHevcSfcStateG12::AllocateResources()
 }
 
 MOS_STATUS CodechalHevcSfcStateG12::CheckAndInitialize(
-    PCODECHAL_DECODE_PROCESSING_PARAMS  decProcessingParams,
+    DecodeProcessingParams             *decProcessingParams,
     PCODEC_HEVC_PIC_PARAMS              hevcPicParams,
     PCODECHAL_DECODE_SCALABILITY_STATE  scalabilityState,
     PMOS_SURFACE                        histogramSurface)
@@ -221,10 +221,10 @@ MOS_STATUS CodechalHevcSfcStateG12::CheckAndInitialize(
             // Set the input region as the HCP output frame region
             m_inputFrameWidth                                = m_hevcPicParams->PicWidthInMinCbsY << (m_hevcPicParams->log2_min_luma_coding_block_size_minus3 + 3);
             m_inputFrameHeight                               = m_hevcPicParams->PicHeightInMinCbsY << (m_hevcPicParams->log2_min_luma_coding_block_size_minus3 + 3);
-            decProcessingParams->rcInputSurfaceRegion.X = 0;
-            decProcessingParams->rcInputSurfaceRegion.Y = 0;
-            decProcessingParams->rcInputSurfaceRegion.Width  = m_inputFrameWidth;
-            decProcessingParams->rcInputSurfaceRegion.Height = m_inputFrameHeight;
+            decProcessingParams->m_inputSurfaceRegion.m_x = 0;
+            decProcessingParams->m_inputSurfaceRegion.m_y = 0;
+            decProcessingParams->m_inputSurfaceRegion.m_width  = m_inputFrameWidth;
+            decProcessingParams->m_inputSurfaceRegion.m_height = m_inputFrameHeight;
 
             CODECHAL_HW_CHK_STATUS_RETURN(Initialize(decProcessingParams, MhwSfcInterfaceG12::SFC_PIPE_MODE_HCP));
 
