@@ -59,6 +59,27 @@ MOS_STATUS CodechalDecodeVc1G12::AllocateStandard(
 
     CODECHAL_DECODE_CHK_STATUS_RETURN(CodechalDecodeVc1::AllocateStandard(settings));
 
+#ifdef _MMC_SUPPORTED
+    // Disable Decode MMC for IGFX
+    if (!MEDIA_IS_SKU(m_hwInterface->GetSkuTable(), FtrFlatPhysCCS))
+    {
+        m_mmc->SetMmcDisabled();
+    }
+
+    // To WA invalid aux data caused HW issue when MMC on
+    if (m_mmc->IsMmcEnabled() && (MEDIA_IS_WA(m_waTable, Wa_1408785368) || MEDIA_IS_WA(m_waTable, Wa_22010493002)))
+    {
+        //Add HUC STATE Commands
+        MHW_VDBOX_STATE_CMDSIZE_PARAMS stateCmdSizeParams;
+
+        m_hwInterface->GetHucStateCommandSize(
+            CODECHAL_DECODE_MODE_VC1VLD,
+            &m_HucStateCmdBufferSizeNeeded,
+            &m_HucPatchListSizeNeeded,
+            &stateCmdSizeParams);
+    }
+#endif
+
     if ( MOS_VE_SUPPORTED(m_osInterface))
     {
         static_cast<MhwVdboxMfxInterfaceG12*>(m_mfxInterface)->DisableScalabilitySupport();
@@ -118,16 +139,6 @@ MOS_STATUS CodechalDecodeVc1G12::SetFrameStates()
     }
 
 #ifdef _MMC_SUPPORTED
-    // To WA invalid aux data caused HW issue when MMC on
-    if (m_mmc && m_mmc->IsMmcEnabled() && (MEDIA_IS_WA(m_waTable, Wa_1408785368) || MEDIA_IS_WA(m_waTable, Wa_22010493002)) &&
-        !Mos_ResourceIsNull(&m_destSurface.OsResource) &&
-        m_destSurface.OsResource.bConvertedFromDDIResource)
-    {
-        CODECHAL_DECODE_VERBOSEMESSAGE("Clear CCS by VE resolve before frame %d submission", m_frameNum);
-        CODECHAL_DECODE_CHK_STATUS_RETURN(static_cast<CodecHalMmcStateG12 *>(m_mmc)->ClearAuxSurf(
-            this, m_miInterface, &m_destSurface.OsResource, m_veState));
-    }
-
     bool isBPicture = m_mfxInterface->IsVc1BPicture(
                         m_vc1PicParams->CurrPic,
                         m_vc1PicParams->picture_fields.is_first_field,
@@ -161,6 +172,26 @@ MOS_STATUS CodechalDecodeVc1G12::DecodeStateLevel()
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
     CODECHAL_DECODE_FUNCTION_ENTER;
+#ifdef _MMC_SUPPORTED
+    // To make sure aux table is clear when MMC off(IGFX)
+    // Can not clear aux table for DGFX because of stolen memory
+    if (!m_mmc->IsMmcEnabled() && !Mos_ResourceIsNull(&m_destSurface.OsResource) && m_destSurface.OsResource.bConvertedFromDDIResource)
+    {
+        if (m_secureDecoder && m_secureDecoder->IsAuxDataInvalid(&m_destSurface.OsResource))
+        {
+            // Not use CODECHAL_DECODE_CHK_STATUS_RETURN() here to avoid adding local variable
+            // Error can still be caught by CODECHAL_DECODE_CHK_STATUS_RETURN() in InitAuxSurface
+            CODECHAL_DECODE_VERBOSEMESSAGE("Clear CCS for secure decode before frame %d submission", m_frameNum);
+            CODECHAL_DECODE_CHK_STATUS_RETURN(m_secureDecoder->InitAuxSurface(&m_destSurface.OsResource, false, true));
+        }
+        else
+        {
+            CODECHAL_DECODE_VERBOSEMESSAGE("Clear CCS by Huc Copy before frame %d submission", m_frameNum);
+            CODECHAL_DECODE_CHK_STATUS_RETURN(static_cast<CodecHalMmcStateG12 *>(m_mmc)->ClearAuxSurf(
+                this, m_miInterface, &m_destSurface.OsResource, m_veState));
+        }
+    }
+#endif
 
     PCODEC_REF_LIST     *vc1RefList;
     vc1RefList = &(m_vc1RefList[0]);
@@ -512,6 +543,16 @@ MOS_STATUS CodechalDecodeVc1G12::DecodePrimitiveLevelVLD()
     if (!CodecHal_PictureIsField(m_vc1PicParams->CurrPic) &&
         m_vc1PicParams->picture_fields.picture_type == vc1SkippedFrame)
     {
+        if (!bSkipFrameReported)
+        {
+            MOS_USER_FEATURE_VALUE_WRITE_DATA userFeatureWriteData;
+            MOS_ZeroMemory(&userFeatureWriteData, sizeof(userFeatureWriteData));
+            userFeatureWriteData.Value.i32Data = true;
+            userFeatureWriteData.ValueID       = __MEDIA_USER_FEATURE_VALUE_SKIP_FRAME_IN_USE_ID;
+            MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1, m_osInterface->pOsContext);
+            bSkipFrameReported = true;
+        }
+
         CODECHAL_DECODE_CHK_STATUS_RETURN(HandleSkipFrame());
         goto submit;
     }
@@ -751,6 +792,13 @@ submit:
         CODECHAL_DECODE_CHK_STATUS_RETURN(EndStatusReport(decodeStatusReport, &cmdBuffer));
     }
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+    uint32_t curIdx         = (GetDecodeStatusBuf()->m_currIndex + CODECHAL_DECODE_STATUS_NUM - 1) % CODECHAL_DECODE_STATUS_NUM;
+    uint32_t frameCrcOffset = curIdx * sizeof(CodechalDecodeStatus) + GetDecodeStatusBuf()->m_decFrameCrcOffset + sizeof(uint32_t) * 2;
+    std::vector<MOS_RESOURCE> vSemaResource{GetDecodeStatusBuf()->m_statusBuffer};
+    m_debugInterface->DetectCorruptionHw(m_hwInterface, &m_frameCountTypeBuf, curIdx, frameCrcOffset, vSemaResource, &cmdBuffer, m_frameNum);
+#endif
+
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_miInterface->AddMiBatchBufferEnd(&cmdBuffer, nullptr));
 
     m_osInterface->pfnReturnCommandBuffer(m_osInterface, &cmdBuffer, 0);
@@ -812,6 +860,16 @@ submit:
 
     if (m_olpNeeded)
     {
+        if (!bOlpReported)
+        {
+            MOS_USER_FEATURE_VALUE_WRITE_DATA userFeatureWriteData;
+            MOS_ZeroMemory(&userFeatureWriteData, sizeof(userFeatureWriteData));
+            userFeatureWriteData.Value.i32Data = m_olpNeeded;
+            userFeatureWriteData.ValueID       = __MEDIA_USER_FEATURE_VALUE_OLP_IN_USE_ID;
+            MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1, m_osInterface->pOsContext);
+            bOlpReported = true;
+        }
+
         CODECHAL_DECODE_CHK_STATUS_RETURN(PerformVc1Olp());
     }
     else
@@ -1298,17 +1356,6 @@ MOS_STATUS CodechalDecodeVc1G12::PerformVc1Olp()
 
     CODECHAL_DECODE_FUNCTION_ENTER;
 
-#ifdef _MMC_SUPPORTED
-    // To Clear invalid aux data of output surface when MMC on
-    if (m_mmc && m_mmc->IsMmcEnabled() &&
-        !Mos_ResourceIsNull(&m_deblockSurface.OsResource) &&
-        m_deblockSurface.OsResource.bConvertedFromDDIResource)
-    {
-        CODECHAL_DECODE_VERBOSEMESSAGE("Clear invalid aux data of output surface before frame %d submission", m_frameNum);
-        CODECHAL_DECODE_CHK_STATUS_RETURN(static_cast<CodecHalMmcStateG12 *>(m_mmc)->ClearAuxSurf(
-            this, m_miInterface, &m_deblockSurface.OsResource, m_veState));
-    }
-#endif
     MhwRenderInterface *renderEngineInterface = m_hwInterface->GetRenderInterface();
     PMHW_KERNEL_STATE         kernelState           = &m_olpKernelState;
     PMHW_STATE_HEAP_INTERFACE stateHeapInterface = renderEngineInterface->m_stateHeapInterface;
@@ -1339,13 +1386,6 @@ MOS_STATUS CodechalDecodeVc1G12::PerformVc1Olp()
 
     CodecHalGetResourceInfo(m_osInterface, &m_deblockSurface);  // DstSurface
 
-#ifdef _MMC_SUPPORTED
-    if (m_mmc && !m_mmc->IsMmcEnabled())
-    {
-        CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->DisableSurfaceMmcState(&m_deblockSurface));
-    }
-#endif
-
     CODECHAL_DECODE_CHK_STATUS_RETURN(stateHeapInterface->pfnRequestSshSpaceForCmdBuf(
         stateHeapInterface,
         kernelState->KernelParams.iBTCount));
@@ -1410,6 +1450,8 @@ MOS_STATUS CodechalDecodeVc1G12::PerformVc1Olp()
     surfaceParamsSrc.dwHeightToUse[MHW_U_PLANE] = surfaceParamsSrc.psSurface->dwHeight / 2;
     surfaceParamsSrc.dwYOffset[MHW_U_PLANE] =
         (m_destSurface.UPlaneOffset.iYOffset % MOS_YTILE_H_ALIGNMENT);
+    surfaceParamsSrc.dwCacheabilityControl  =
+        m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_PRE_DEBLOCKING_CODEC].Value;
 
 #ifdef _MMC_SUPPORTED
     if (m_mmc)
@@ -1428,6 +1470,8 @@ MOS_STATUS CodechalDecodeVc1G12::PerformVc1Olp()
     surfaceParamsDst.psSurface->dwDepth = 1;    // depth needs to be 0 for codec 2D surface
     surfaceParamsDst.dwBindingTableOffset[MHW_Y_PLANE] = CODECHAL_DECODE_VC1_OLP_DST_Y;
     surfaceParamsDst.dwBindingTableOffset[MHW_U_PLANE] = CODECHAL_DECODE_VC1_OLP_DST_UV;
+    surfaceParamsDst.dwCacheabilityControl =
+        m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_POST_DEBLOCKING_CODEC].Value;
 
 #ifdef _MMC_SUPPORTED
     if (m_mmc)
@@ -1460,6 +1504,11 @@ MOS_STATUS CodechalDecodeVc1G12::PerformVc1Olp()
     stateBaseAddrParams.dwDynamicStateSize = kernelState->m_dshRegion.GetHeapSize();
     stateBaseAddrParams.presInstructionBuffer = ish;
     stateBaseAddrParams.dwInstructionBufferSize = kernelState->m_ishRegion.GetHeapSize();
+    stateBaseAddrParams.mocs4GeneralState = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_UNCACHED].Gen12.Index;
+    stateBaseAddrParams.mocs4DynamicState = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_UNCACHED].Gen12.Index;
+    stateBaseAddrParams.mocs4SurfaceState       = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_UNCACHED].Gen12.Index;
+    stateBaseAddrParams.mocs4IndirectObjectBuffer = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_UNCACHED].Gen12.Index;
+    stateBaseAddrParams.mocs4StatelessDataport = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_UNCACHED].Gen12.Index;
     CODECHAL_DECODE_CHK_STATUS_RETURN(renderEngineInterface->AddStateBaseAddrCmd(&cmdBuffer, &stateBaseAddrParams));
 
     MHW_VFE_PARAMS_G12 vfeParams= {};
@@ -1609,3 +1658,17 @@ CodechalDecodeVc1G12::~CodechalDecodeVc1G12()
         m_veState = nullptr;
     }
 }
+
+void CodechalDecodeVc1G12::CalcRequestedSpace(
+    uint32_t &requestedSize,
+    uint32_t &additionalSizeNeeded,
+    uint32_t &requestedPatchListSize)
+{
+    CODECHAL_DECODE_FUNCTION_ENTER;
+
+    requestedSize = m_commandBufferSizeNeeded + m_HucStateCmdBufferSizeNeeded +
+                    (m_standardDecodeSizeNeeded * (m_decodeParams.m_numSlices + 1));
+    requestedPatchListSize = m_commandPatchListSizeNeeded + m_HucPatchListSizeNeeded +
+                             (m_standardDecodePatchListSizeNeeded * (m_decodeParams.m_numSlices + 1));
+    additionalSizeNeeded = COMMAND_BUFFER_RESERVED_SPACE;
+}
