@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2019, Intel Corporation
+* Copyright (c) 2017-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -25,7 +25,7 @@
 //!
 
 #include "codechal_encode_jpeg_g12.h"
-#include "codechal_mmc_g12.h"
+#include "codechal_mmc_encode_jpeg_g12.h"
 #include "mos_util_user_interface.h"
 
 CodechalEncodeJpegStateG12::CodechalEncodeJpegStateG12(
@@ -36,7 +36,6 @@ CodechalEncodeJpegStateG12::CodechalEncodeJpegStateG12(
         m_sinlgePipeVeState(nullptr)
 {
     CODECHAL_ENCODE_FUNCTION_ENTER;
-    InitMmcState();
 
     CODECHAL_ENCODE_CHK_NULL_NO_STATUS_RETURN(m_osInterface);
     Mos_SetVirtualEngineSupported(m_osInterface, true);
@@ -73,7 +72,7 @@ MOS_STATUS CodechalEncodeJpegStateG12::InitMmcState()
 {
     CODECHAL_ENCODE_FUNCTION_ENTER;
 #ifdef _MMC_SUPPORTED
-    m_mmcState = MOS_New(CodecHalMmcStateG12, m_hwInterface);
+    m_mmcState = MOS_New(CodechalMmcEncodeJpegG12, m_hwInterface, this);
     CODECHAL_ENCODE_CHK_NULL_RETURN(m_mmcState);
 #endif
     return MOS_STATUS_SUCCESS;
@@ -115,7 +114,7 @@ MOS_STATUS CodechalEncodeJpegStateG12::UserFeatureKeyReport()
 #if (_DEBUG || _RELEASE_INTERNAL)
 
     // VE2.0 Reporting
-    CodecHalEncode_WriteKey(__MEDIA_USER_FEATURE_VALUE_ENABLE_ENCODE_VE_CTXSCHEDULING_ID, MOS_VE_CTXBASEDSCHEDULING_SUPPORTED(m_osInterface));
+    CodecHalEncode_WriteKey(__MEDIA_USER_FEATURE_VALUE_ENABLE_ENCODE_VE_CTXSCHEDULING_ID, MOS_VE_CTXBASEDSCHEDULING_SUPPORTED(m_osInterface), m_osInterface->pOsContext);
 
 #endif // _DEBUG || _RELEASE_INTERNAL
     return eStatus;
@@ -150,6 +149,7 @@ MOS_STATUS CodechalEncodeJpegStateG12::Initialize(CodechalSetting  *settings)
     CODECHAL_ENCODE_CHK_NULL_RETURN(m_miInterface);
     CODECHAL_ENCODE_CHK_NULL_RETURN(settings);
 
+    CODECHAL_ENCODE_CHK_STATUS_RETURN(InitMmcState());
     CODECHAL_ENCODE_CHK_STATUS_RETURN(CodechalEncoderState::Initialize(settings));
 
     // Picture Level Commands
