@@ -69,7 +69,7 @@ MOS_STATUS MhwMiInterfaceG12::AddPipeControl(
     }
 
     mhw_mi_g12_X::PIPE_CONTROL_CMD     cmd;
-    cmd.DW1.PipeControlFlushEnable     = true;
+    cmd.DW1.PipeControlFlushEnable     = params->bKernelFenceEnabled ? false : true;
     cmd.DW1.CommandStreamerStallEnable = !params->bDisableCSStall;
     cmd.DW4_5.Value[0]                 = params->dwDataDW1;
     cmd.DW4_5.Value[1]                 = params->dwDataDW2;
@@ -171,7 +171,8 @@ MOS_STATUS MhwMiInterfaceG12::AddPipeControl(
     if (cmd.DW1.CommandStreamerStallEnable &&
         (cmd.DW1.DcFlushEnable == 0 && cmd.DW1.NotifyEnable == 0 && cmd.DW1.PostSyncOperation == 0 &&
             cmd.DW1.DepthStallEnable == 0 && cmd.DW1.StallAtPixelScoreboard == 0 && cmd.DW1.DepthCacheFlushEnable == 0 &&
-            cmd.DW1.RenderTargetCacheFlushEnable == 0))
+            cmd.DW1.RenderTargetCacheFlushEnable == 0) &&
+            !params->bKernelFenceEnabled)
     {
         cmd.DW1.CommandStreamerStallEnable = 0;
     }
@@ -204,7 +205,7 @@ MOS_STATUS MhwMiInterfaceG12::AddMiBatchBufferStartCmd(
 
     MHW_MI_CHK_NULL(cmdBuffer);
     MHW_MI_CHK_NULL(batchBuffer);
-
+    MHW_MI_CHK_NULL(m_osInterface);
     bool vcsEngineUsed =
         MOS_VCS_ENGINE_USED(m_osInterface->pfnGetGpuContext(m_osInterface));
 
@@ -310,7 +311,7 @@ MOS_STATUS MhwMiInterfaceG12::AddMiStoreRegisterMemCmd(
     MHW_MI_CHK_NULL(cmdBuffer);
     MHW_MI_CHK_NULL(cmdBuffer->pCmdPtr);
     MHW_MI_CHK_NULL(params);
-
+    MHW_MI_CHK_NULL(m_osInterface);
     mhw_mi_g12_X::MI_STORE_REGISTER_MEM_CMD *cmd =
         (mhw_mi_g12_X::MI_STORE_REGISTER_MEM_CMD*)cmdBuffer->pCmdPtr;
 
@@ -516,7 +517,7 @@ MOS_STATUS MhwMiInterfaceG12::SetWatchdogTimerThreshold(uint32_t frameWidth, uin
     MEDIA_WA_TABLE *waTable = nullptr;
 
     MHW_FUNCTION_ENTER;
-
+    MHW_MI_CHK_NULL(m_osInterface);
     if (m_osInterface->bMediaReset == false ||
         m_osInterface->umdMediaResetEnable == false)
     {
@@ -566,22 +567,8 @@ MOS_STATUS MhwMiInterfaceG12::SetWatchdogTimerThreshold(uint32_t frameWidth, uin
         }
     }
 
-    MOS_USER_FEATURE_VALUE_DATA userFeatureData;
-    MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-#if (_DEBUG || _RELEASE_INTERNAL)
-    // User feature config of watchdog timer threshold
-    MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-    MOS_UserFeature_ReadValue_ID(
-        nullptr,
-        __MEDIA_USER_FEATURE_VALUE_MEDIA_RESET_TH_ID,
-        &userFeatureData,
-        m_osInterface->pOsContext);
-    if (userFeatureData.u32Data != 0)
-    {
-        MediaResetParam.watchdogCountThreshold = userFeatureData.u32Data;
-    }
-#endif
-
+    GetWatchdogThreshold(m_osInterface);
+    
     return MOS_STATUS_SUCCESS;
 }
 
@@ -641,7 +628,7 @@ MOS_STATUS MhwMiInterfaceG12::AddWatchdogTimerStartCmd(
     MOS_GPU_CONTEXT gpuContext;
 
     MHW_FUNCTION_ENTER;
-
+    MHW_MI_CHK_NULL(m_osInterface);
     if (m_osInterface->bMediaReset == false ||
         m_osInterface->umdMediaResetEnable == false)
     {
@@ -686,7 +673,7 @@ MOS_STATUS MhwMiInterfaceG12::AddWatchdogTimerStopCmd(
     MOS_GPU_CONTEXT gpuContext;
 
     MHW_FUNCTION_ENTER;
-
+    MHW_MI_CHK_NULL(m_osInterface);
     if (m_osInterface->bMediaReset == false ||
         m_osInterface->umdMediaResetEnable == false)
     {
@@ -744,7 +731,7 @@ MOS_STATUS MhwMiInterfaceG12::SkipMiBatchBufferEndBb(
     MHW_FUNCTION_ENTER;
 
     MHW_MI_CHK_STATUS(MhwMiInterfaceGeneric<mhw_mi_g12_X>::SkipMiBatchBufferEndBb(batchBuffer));
-
+    MHW_MI_CHK_NULL(m_osInterface);
     auto waTable = m_osInterface->pfnGetWaTable(m_osInterface);
     MHW_MI_CHK_NULL(waTable);
 
@@ -826,4 +813,4 @@ MOS_STATUS MhwMiInterfaceG12::AddMiFlushDwCmd(
     MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
     return MOS_STATUS_SUCCESS;
-}
+}
\ No newline at end of file
