@@ -139,6 +139,23 @@ MOS_STATUS MhwMiInterfaceG8::AddMediaStateFlush(
 
     MHW_MI_CHK_STATUS(MhwMiInterfaceGeneric<mhw_mi_g8_X>::AddMediaStateFlush(cmdBuffer, batchBuffer, params));
 
+    mhw_mi_g8_X::MEDIA_STATE_FLUSH_CMD AddMediaStateFlushcmd;
+
+    if (params != nullptr)
+    {
+        AddMediaStateFlushcmd.DW1.FlushToGo = params->bFlushToGo;
+        AddMediaStateFlushcmd.DW1.InterfaceDescriptorOffset = params->ui8InterfaceDescriptorOffset;
+    }
+
+    MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, &AddMediaStateFlushcmd, AddMediaStateFlushcmd.byteSize));
+
+#if (_DEBUG || _RELEASE_INTERNAL)
+    if (batchBuffer)
+    {
+        batchBuffer->iLastCurrent = batchBuffer->iCurrent;
+    }
+#endif
+
     auto waTable = m_osInterface->pfnGetWaTable(m_osInterface);
     MHW_MI_CHK_NULL(waTable);
     MHW_MI_CHK_NULL(cmd);
@@ -165,3 +182,93 @@ void MhwMiInterfaceG8::InitMmioRegisters()
     mmioRegisters->generalPurposeRegister12LoOffset           = GP_REGISTER12_LO_OFFSET_G8;
     mmioRegisters->generalPurposeRegister12HiOffset           = GP_REGISTER12_HI_OFFSET_G8;
 }
+
+MOS_STATUS MhwMiInterfaceG8::SkipMiBatchBufferEndBb(
+    PMHW_BATCH_BUFFER               batchBuffer)
+{
+    MHW_FUNCTION_ENTER;
+
+    MHW_MI_CHK_STATUS(MhwMiInterfaceGeneric<mhw_mi_g8_X>::SkipMiBatchBufferEndBb(batchBuffer));
+
+    auto waTable = m_osInterface->pfnGetWaTable(m_osInterface);
+    MHW_MI_CHK_NULL(waTable);
+
+    // This WA does not apply for video or other engines, render requirement only
+    bool isRender =
+        MOS_RCS_ENGINE_USED(m_osInterface->pfnGetGpuContext(m_osInterface));
+
+    if (isRender && (MEDIA_IS_WA(waTable, WaMSFWithNoWatermarkTSGHang) ||
+                        MEDIA_IS_WA(waTable, WaAddMediaStateFlushCmd)))
+    {
+        mhw_mi_g8_X::MEDIA_STATE_FLUSH_CMD FlushCmd;
+        MHW_MI_CHK_STATUS(Mhw_AddCommandBB(
+            batchBuffer,
+            nullptr,
+            FlushCmd.byteSize));
+    }
+
+    mhw_mi_g8_X::MI_BATCH_BUFFER_END_CMD cmd;
+    MHW_MI_CHK_STATUS(Mhw_AddCommandBB(
+        batchBuffer,
+        nullptr,
+        cmd.byteSize));
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS MhwMiInterfaceG8::AddMiFlushDwCmd(
+    PMOS_COMMAND_BUFFER     cmdBuffer,
+    PMHW_MI_FLUSH_DW_PARAMS params)
+{
+    MHW_FUNCTION_ENTER;
+
+    MHW_MI_CHK_STATUS(MhwMiInterfaceGeneric<mhw_mi_g8_X>::AddMiFlushDwCmd(cmdBuffer, params));
+
+    mhw_mi_g8_X::MI_FLUSH_DW_CMD cmd;
+
+    // set the protection bit based on CP status
+    MHW_MI_CHK_STATUS(m_cpInterface->SetProtectionSettingsForMiFlushDw(m_osInterface, &cmd));
+
+    cmd.DW0.VideoPipelineCacheInvalidate = params->bVideoPipelineCacheInvalidate;
+    cmd.DW0.PostSyncOperation            = cmd.POST_SYNC_OPERATION_NOWRITE;
+    cmd.DW3_4.Value[0]                   = params->dwDataDW1;
+
+    if (params->pOsResource)
+    {
+        cmd.DW0.PostSyncOperation        = cmd.POST_SYNC_OPERATION_WRITEIMMEDIATEDATA;
+        cmd.DW1_2.DestinationAddressType = UseGlobalGtt.m_vcs;
+
+        MHW_RESOURCE_PARAMS resourceParams;
+        MOS_ZeroMemory(&resourceParams, sizeof(resourceParams));
+        resourceParams.presResource    = params->pOsResource;
+        resourceParams.dwOffset        = params->dwResourceOffset;
+        resourceParams.pdwCmd          = cmd.DW1_2.Value;
+        resourceParams.dwLocationInCmd = 1;
+        resourceParams.dwLsbNum        = MHW_COMMON_MI_FLUSH_DW_SHIFT;
+        resourceParams.HwCommandType   = MOS_MI_FLUSH_DW;
+        resourceParams.bIsWritable     = true;
+
+        MHW_MI_CHK_STATUS(AddResourceToCmd(
+            m_osInterface,
+            cmdBuffer,
+            &resourceParams));
+    }
+
+    if (params->postSyncOperation)
+    {
+        cmd.DW0.PostSyncOperation = params->postSyncOperation;
+    }
+
+    if (params->dwDataDW2 || params->bQWordEnable)
+    {
+        cmd.DW3_4.Value[1] = params->dwDataDW2;
+    }
+    else
+    {
+        cmd.DW0.DwordLength--;
+    }
+
+    MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+
+    return MOS_STATUS_SUCCESS;
+}
