@@ -408,6 +408,23 @@ finish:
     return eStatus;
 }
 
+//!
+//! \brief    Check for DN only case
+//! \details  Check for DN only case
+//! \return   bool
+//!           Return true if DN only case, otherwise not
+//!
+bool VPHAL_VEBOX_STATE_G8_BASE::IsDNOnly()
+{
+    PVPHAL_VEBOX_RENDER_DATA pRenderData = GetLastExecRenderData();
+
+    return pRenderData->bDenoise &&
+        (!pRenderData->bDeinterlace) &&
+        (!IsQueryVarianceEnabled()) &&
+        (!IsIECPEnabled());
+}
+
+
 MOS_STATUS VPHAL_VEBOX_STATE_G8_BASE::GetFFDISurfParams(
     MOS_FORMAT          &Format,
     MOS_TILE_TYPE       &TileType,
@@ -508,7 +525,7 @@ MOS_STATUS VPHAL_VEBOX_STATE_G8_BASE::AllocateResources()
         VPHAL_CSPACE        ColorSpace;
         VPHAL_SAMPLE_TYPE   SampleType;
 
-        GetFFDISurfParams(format, TileType, ColorSpace, SampleType);
+        VPHAL_RENDER_CHK_STATUS(GetFFDISurfParams(format, TileType, ColorSpace, SampleType));
 
         for (i = 0; i < pVeboxState->iNumFFDISurfaces; i++)
         {
@@ -536,6 +553,8 @@ MOS_STATUS VPHAL_VEBOX_STATE_G8_BASE::AllocateResources()
 
             // Set Colorspace of FFDI
             pVeboxState->FFDISurfaces[i]->ColorSpace = ColorSpace;
+            // Copy ScalingMode, it's used in setting SFC state
+            pVeboxState->FFDISurfaces[i]->ScalingMode = pVeboxState->m_currentSurface->ScalingMode;
         }
     }
     else
@@ -601,6 +620,8 @@ MOS_STATUS VPHAL_VEBOX_STATE_G8_BASE::AllocateResources()
             // Copy FrameID and parameters, as DN output will be used as next blt's current
             pVeboxState->FFDNSurfaces[i]->FrameID            = pVeboxState->m_currentSurface->FrameID;
             pVeboxState->FFDNSurfaces[i]->pDenoiseParams     = pVeboxState->m_currentSurface->pDenoiseParams;
+            // Copy ScalingMode, it's used in setting SFC state
+            pVeboxState->FFDNSurfaces[i]->ScalingMode        = pVeboxState->m_currentSurface->ScalingMode;
         }
     }
     else
@@ -1211,12 +1232,16 @@ void VPHAL_VEBOX_STATE_G8_BASE::SetupSurfaceStates(
     {
         pVeboxSurfaceStateCmdParams->pSurfOutput =
             pVeboxState->FFDNSurfaces[pRenderData->iCurDNOut];
+        pVeboxSurfaceStateCmdParams->pSurfDNOutput =
+            pVeboxState->FFDNSurfaces[pRenderData->iCurDNOut];
     }
     else
     {
         VPHAL_RENDER_ASSERTMESSAGE("Unable to determine Vebox Output Surface.");
     }
 
+    pVeboxSurfaceStateCmdParams->pSurfDNOutput =
+        pVeboxState->FFDNSurfaces[pRenderData->iCurDNOut];
     pVeboxSurfaceStateCmdParams->bDIEnable = bDiVarianceEnable;
 }
 
