@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2020, Intel Corporation
+* Copyright (c) 2017-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -144,7 +144,7 @@ MOS_STATUS MhwVdboxVdencInterfaceG9Kbl::AddVdencImgStateCmd(
     if (avcPicParams->CodingType != I_TYPE)
     {
         cmd.DW2.BidirectionalWeight       = 0x20;
-        cmd.DW4.SubPelMode                = 3;
+        cmd.DW4.SubPelMode                = (avcPicParams->bEnableSubPelMode) ? avcPicParams->SubPelMode : 3;
         cmd.DW4.BmeDisableForFbrMessage   = 1;
         cmd.DW4.InterSadMeasureAdjustment = 2;
         cmd.DW5.CrePrefetchEnable         = 1;
@@ -299,9 +299,9 @@ MOS_STATUS MhwVdboxVdencInterfaceG9Kbl::AddVdencImgStateCmd(
 
         for (uint8_t i = 0; i < avcPicParams->NumROI; i++)
         {
-            int8_t dQpRoi = avcPicParams->ROI[i].PriorityLevelOrDQp;
+            int8_t dQpRoi = avcPicParams->ROIDistinctDeltaQp[i];
 
-            // clip delta qp roi to VDEnc supported range 
+            // clip delta qp roi to VDEnc supported range
             priorityLevelOrDQp[i] = (char)CodecHal_Clip3(
                 ENCODE_VDENC_AVC_MIN_ROI_DELTA_QP_G9, ENCODE_VDENC_AVC_MAX_ROI_DELTA_QP_G9, dQpRoi);
         }
