@@ -233,7 +233,8 @@ VAStatus DdiEncodeVp9::EncodeInCodecHal(uint32_t numSlices)
         seqParams->RateControlMethod = RATECONTROL_CQL;
     }
 
-    seqParams->TargetUsage = vp9TargetUsage;
+    if (m_encodeCtx->bNewSeq)
+        seqParams->TargetUsage = vp9TargetUsage;
 
     /* If the segmentation is not enabled, the SegData will be reset */
     if (vp9PicParam->PicFlags.fields.segmentation_enabled == 0)
@@ -651,6 +652,12 @@ VAStatus DdiEncodeVp9::ParsePicParams(DDI_MEDIA_CONTEXT *mediaCtx, void *ptr)
     DDI_CODEC_RENDER_TARGET_TABLE *rtTbl = &(m_encodeCtx->RTtbl);
 
     auto recon = DdiMedia_GetSurfaceFromVASurfaceID(mediaCtx, picParam->reconstructed_frame);
+    if(m_encodeCtx->vaProfile == VAProfileVP9Profile1
+       ||m_encodeCtx->vaProfile == VAProfileVP9Profile2
+       ||m_encodeCtx->vaProfile == VAProfileVP9Profile3)
+    {
+        recon = DdiMedia_ReplaceSurfaceWithVariant(recon, m_encodeCtx->vaEntrypoint);
+    }
     DDI_CHK_RET(RegisterRTSurfaces(rtTbl, recon),"RegisterRTSurfaces failed!");
 
     SetupCodecPicture(mediaCtx, rtTbl, &vp9PicParam->CurrReconstructedPic,
