@@ -485,6 +485,9 @@ struct DDI_MEDIA_CONTEXT
     // Media copy data structure
     void               *pMediaCopyState;
 
+    // Perf tag
+    PERF_DATA          *perfData;
+
     // Media reset enable flag
     bool                bMediaResetEnable;
 
@@ -536,8 +539,6 @@ struct DDI_MEDIA_CONTEXT
 
     GMM_CLIENT_CONTEXT  *pGmmClientContext;
 
-    GmmExportEntries   GmmFuncs;
-
     // Aux Table Manager
     AuxTableMgr         *m_auxTableMgr;
 
@@ -559,6 +560,7 @@ struct DDI_MEDIA_CONTEXT
     DdiMediaFunctions     *m_compList[CompCount] = {nullptr};
     MediaInterfacesHwInfo *m_hwInfo = nullptr;
     MediaLibvaCapsNext    *m_capsNext = nullptr;
+    bool                  m_apoDdiEnabled = false;
 #endif
 };
 
