@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2020, Intel Corporation
+* Copyright (c) 2018-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -94,16 +94,16 @@ MOS_STATUS GpuContextSpecific::Init(OsContext *osContext,
 
     if (m_cmdBufPoolMutex == nullptr)
     {
-        m_cmdBufPoolMutex = MOS_CreateMutex();
+        m_cmdBufPoolMutex = MosUtilities::MosCreateMutex();
     }
 
     MOS_OS_CHK_NULL_RETURN(m_cmdBufPoolMutex);
 
-    MOS_LockMutex(m_cmdBufPoolMutex);
+    MosUtilities::MosLockMutex(m_cmdBufPoolMutex);
 
     m_cmdBufPool.clear();
 
-    MOS_UnlockMutex(m_cmdBufPoolMutex);
+    MosUtilities::MosUnlockMutex(m_cmdBufPoolMutex);
 
     m_commandBufferSize = COMMAND_BUFFER_SIZE;
 
@@ -173,7 +173,7 @@ MOS_STATUS GpuContextSpecific::Init(OsContext *osContext,
 
         m_i915ExecFlag = I915_EXEC_DEFAULT;
 
-        if (mos_query_engines_count(osInterface->pOsContext->bufmgr, &nengine))
+        if (mos_query_engines_count(osInterface->pOsContext->bufmgr, &nengine) || (nengine == 0))
         {
             MOS_OS_ASSERTMESSAGE("Failed to query engines count.\n");
             return MOS_STATUS_UNKNOWN;
@@ -277,54 +277,75 @@ MOS_STATUS GpuContextSpecific::Init(OsContext *osContext,
 
             if (nengine >= 2)
             {
-                //master queue
-                m_i915Context[1] = mos_gem_context_create_shared(osInterface->pOsContext->bufmgr,
-                                                                 osInterface->pOsContext->intel_context,
-                                                                 I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE);
-                if (m_i915Context[1] == nullptr)
+                if(!osInterface->bGucSubmission)
                 {
-                    MOS_OS_ASSERTMESSAGE("Failed to create master context.\n");
-                    MOS_SafeFreeMemory(engine_map);
-                    return MOS_STATUS_UNKNOWN;
-                }
-                m_i915Context[1]->pOsContext = osInterface->pOsContext;
-
-                if (mos_set_context_param_load_balance(m_i915Context[1], engine_map, 1))
-                {
-                    MOS_OS_ASSERTMESSAGE("Failed to set master context bond extension.\n");
-                    MOS_SafeFreeMemory(engine_map);
-                    return MOS_STATUS_UNKNOWN;
-                }
-
-                //slave queue
-                for (int i=1; i<nengine; i++)
-                {
-                    m_i915Context[i+1] = mos_gem_context_create_shared(osInterface->pOsContext->bufmgr,
+                    //master queue
+                    m_i915Context[1] = mos_gem_context_create_shared(osInterface->pOsContext->bufmgr,
                                                                      osInterface->pOsContext->intel_context,
                                                                      I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE);
-                    if (m_i915Context[i+1] == nullptr)
+                    if (m_i915Context[1] == nullptr)
                     {
-                        MOS_OS_ASSERTMESSAGE("Failed to create slave context.\n");
+                        MOS_OS_ASSERTMESSAGE("Failed to create master context.\n");
                         MOS_SafeFreeMemory(engine_map);
                         return MOS_STATUS_UNKNOWN;
                     }
-                    m_i915Context[i+1]->pOsContext = osInterface->pOsContext;
+                    m_i915Context[1]->pOsContext = osInterface->pOsContext;
 
-                    if (mos_set_context_param_bond(m_i915Context[i+1], engine_map[0], &engine_map[i], 1) != S_SUCCESS)
+                    if (mos_set_context_param_load_balance(m_i915Context[1], engine_map, 1))
                     {
-                        int err = errno;
-                        if (err == ENODEV)
+                        MOS_OS_ASSERTMESSAGE("Failed to set master context bond extension.\n");
+                        MOS_SafeFreeMemory(engine_map);
+                        return MOS_STATUS_UNKNOWN;
+                    }
+
+                    //slave queue
+                    for (int i=1; i<nengine; i++)
+                    {
+                        m_i915Context[i+1] = mos_gem_context_create_shared(osInterface->pOsContext->bufmgr,
+                                                                         osInterface->pOsContext->intel_context,
+                                                                         I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE);
+                        if (m_i915Context[i+1] == nullptr)
                         {
-                            mos_gem_context_destroy(m_i915Context[i+1]);
-                            m_i915Context[i+1] = nullptr;
-                            break;
-                        }
-                        else
-                        {
-                            MOS_OS_ASSERTMESSAGE("Failed to set slave context bond extension. errno=%d\n",err);
+                            MOS_OS_ASSERTMESSAGE("Failed to create slave context.\n");
                             MOS_SafeFreeMemory(engine_map);
                             return MOS_STATUS_UNKNOWN;
                         }
+                        m_i915Context[i+1]->pOsContext = osInterface->pOsContext;
+
+                        if (mos_set_context_param_bond(m_i915Context[i+1], engine_map[0], &engine_map[i], 1) != S_SUCCESS)
+                        {
+                            int err = errno;
+                            if (err == ENODEV)
+                            {
+                                mos_gem_context_destroy(m_i915Context[i+1]);
+                                m_i915Context[i+1] = nullptr;
+                                break;
+                            }
+                            else
+                            {
+                                MOS_OS_ASSERTMESSAGE("Failed to set slave context bond extension. errno=%d\n",err);
+                                MOS_SafeFreeMemory(engine_map);
+                                return MOS_STATUS_UNKNOWN;
+                            }
+                        }
+                    }
+                }
+                else
+                {
+                    //create context with different width
+                    for(int i = 1; i < nengine; i++)
+                    {
+                        unsigned int ctxWidth = i + 1;
+                        m_i915Context[i] = mos_gem_context_create_shared(osInterface->pOsContext->bufmgr,
+                                                                     osInterface->pOsContext->intel_context,
+                                                                     0); // I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE not allowed for parallel submission
+                        if (mos_set_context_param_parallel(m_i915Context[i], engine_map, ctxWidth) != S_SUCCESS)
+                        {
+                            MOS_OS_ASSERTMESSAGE("Failed to set parallel extension since discontinuous logical engine.\n");
+                            mos_gem_context_destroy(m_i915Context[i]);
+                            m_i915Context[i] = nullptr;
+                            break;
+                        }
                     }
                 }
             }
@@ -380,7 +401,7 @@ void GpuContextSpecific::Clear()
     }
     MOS_FreeMemAndSetNull(m_statusBufferMosResource);
 
-    MOS_LockMutex(m_cmdBufPoolMutex);
+    MosUtilities::MosLockMutex(m_cmdBufPoolMutex);
 
     if (m_cmdBufMgr)
     {
@@ -396,8 +417,8 @@ void GpuContextSpecific::Clear()
 
     m_cmdBufPool.clear();
 
-    MOS_UnlockMutex(m_cmdBufPoolMutex);
-    MOS_DestroyMutex(m_cmdBufPoolMutex);
+    MosUtilities::MosUnlockMutex(m_cmdBufPoolMutex);
+    MosUtilities::MosDestroyMutex(m_cmdBufPoolMutex);
     m_cmdBufPoolMutex = nullptr;
     MOS_SafeFreeMemory(m_commandBuffer);
     MOS_SafeFreeMemory(m_allocationList);
@@ -531,20 +552,20 @@ MOS_STATUS GpuContextSpecific::GetCommandBuffer(
 
     if (needToAlloc)
     {
-        MOS_LockMutex(m_cmdBufPoolMutex);
+        MosUtilities::MosLockMutex(m_cmdBufPoolMutex);
         if (m_cmdBufPool.size() < MAX_CMD_BUF_NUM)
         {
             cmdBuf = m_cmdBufMgr->PickupOneCmdBuf(m_commandBufferSize);
             if (cmdBuf == nullptr)
             {
                 MOS_OS_ASSERTMESSAGE("Invalid (nullptr) Pointer.");
-                MOS_UnlockMutex(m_cmdBufPoolMutex);
+                MosUtilities::MosUnlockMutex(m_cmdBufPoolMutex);
                 return MOS_STATUS_NULL_POINTER;
             }
             if ((eStatus = cmdBuf->BindToGpuContext(this)) != MOS_STATUS_SUCCESS)
             {
                 MOS_OS_ASSERTMESSAGE("Invalid status of BindToGpuContext.");
-                MOS_UnlockMutex(m_cmdBufPoolMutex);
+                MosUtilities::MosUnlockMutex(m_cmdBufPoolMutex);
                 return eStatus;
             }
             m_cmdBufPool.push_back(cmdBuf);
@@ -556,7 +577,7 @@ MOS_STATUS GpuContextSpecific::GetCommandBuffer(
             if (cmdBufSpecificOld == nullptr)
             {
                 MOS_OS_ASSERTMESSAGE("Invalid (nullptr) Pointer.");
-                MOS_UnlockMutex(m_cmdBufPoolMutex);
+                MosUtilities::MosUnlockMutex(m_cmdBufPoolMutex);
                 return MOS_STATUS_NULL_POINTER;
             }
             cmdBufSpecificOld->waitReady();
@@ -568,13 +589,13 @@ MOS_STATUS GpuContextSpecific::GetCommandBuffer(
             if (cmdBuf == nullptr)
             {
                 MOS_OS_ASSERTMESSAGE("Invalid (nullptr) Pointer.");
-                MOS_UnlockMutex(m_cmdBufPoolMutex);
+                MosUtilities::MosUnlockMutex(m_cmdBufPoolMutex);
                 return MOS_STATUS_NULL_POINTER;
             }
             if ((eStatus = cmdBuf->BindToGpuContext(this)) != MOS_STATUS_SUCCESS)
             {
                 MOS_OS_ASSERTMESSAGE("Invalid status of BindToGpuContext.");
-                MOS_UnlockMutex(m_cmdBufPoolMutex);
+                MosUtilities::MosUnlockMutex(m_cmdBufPoolMutex);
                 return eStatus;
             }
             m_cmdBufPool[m_nextFetchIndex] = cmdBuf;
@@ -582,10 +603,10 @@ MOS_STATUS GpuContextSpecific::GetCommandBuffer(
         else
         {
             MOS_OS_ASSERTMESSAGE("Command buffer bool size exceed max.");
-            MOS_UnlockMutex(m_cmdBufPoolMutex);
+            MosUtilities::MosUnlockMutex(m_cmdBufPoolMutex);
             return MOS_STATUS_UNKNOWN;
         }
-        MOS_UnlockMutex(m_cmdBufPoolMutex);
+        MosUtilities::MosUnlockMutex(m_cmdBufPoolMutex);
 
         // util now, we got new command buffer from CmdBufMgr, next step to fill in the input command buffer
         MOS_OS_CHK_STATUS_RETURN(cmdBuf->GetResource()->ConvertToMosResource(&comamndBuffer->OsResource));
@@ -1200,7 +1221,7 @@ MOS_STATUS GpuContextSpecific::SubmitCommandBuffer(
         {
             if (cmdBuffer->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_MASK)
             {
-                if (scalaEnabled)
+                if (scalaEnabled && !osInterface->bGucSubmission)
                 {
                     uint32_t secondaryIndex = 0;
                     it = m_secondaryCmdBufs.begin();
@@ -1225,6 +1246,13 @@ MOS_STATUS GpuContextSpecific::SubmitCommandBuffer(
                         it++;
                     }
                 }
+                else if(scalaEnabled && osInterface->bGucSubmission)
+                {
+                    ret = ParallelSubmitCommands(m_secondaryCmdBufs,
+                                         osContext,
+                                         execFlag,
+                                         DR4);
+                }
                 else
                 {
                     ret = SubmitPipeCommands(cmdBuffer,
@@ -1418,6 +1446,93 @@ int32_t GpuContextSpecific::SubmitPipeCommands(
     return ret;
 }
 
+int32_t GpuContextSpecific::ParallelSubmitCommands(
+    std::map<uint32_t, PMOS_COMMAND_BUFFER> secondaryCmdBufs,
+    PMOS_CONTEXT osContext,
+    uint32_t execFlag,
+    int32_t dr4)
+{
+    int32_t      ret        = 0;
+    int          fence      = -1;
+    unsigned int fenceFlag  = 0;
+    auto         it         = m_secondaryCmdBufs.begin();
+    MOS_LINUX_BO *cmdBos[MAX_PARALLEN_CMD_BO_NUM];
+    int          numBos     = 0; // exclude FE bo
+
+    MOS_LINUX_CONTEXT *queue = m_i915Context[0];
+    bool isVeboxSubmission   = false;
+
+    if (execFlag == MOS_GPU_NODE_VIDEO || execFlag == MOS_GPU_NODE_VIDEO2)
+    {
+        execFlag = I915_EXEC_DEFAULT;
+    }
+    if (execFlag == MOS_GPU_NODE_VE)
+    {
+        execFlag = I915_EXEC_DEFAULT;
+        isVeboxSubmission = true;
+    }
+
+    while(it != m_secondaryCmdBufs.end())
+    {
+        if(it->second->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_ALONE)
+        {
+            fenceFlag = I915_EXEC_FENCE_OUT;
+            queue = m_i915Context[0];
+
+            ret = mos_gem_bo_context_exec2(it->second->OsResource.bo,
+                                  it->second->OsResource.bo->size,
+                                  queue,
+                                  nullptr,
+                                  0,
+                                  dr4,
+                                  execFlag | fenceFlag,
+                                  &fence);
+
+            osContext->submit_fence = fence;
+        }
+
+        if((it->second->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_MASTER)
+            || (it->second->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_SLAVE))
+        {
+            cmdBos[numBos++] = it->second->OsResource.bo;
+
+            if(it->second->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_FLAGS_LAST_PIPE)
+            {
+                queue = m_i915Context[numBos - 1];
+                MOS_OS_CHK_NULL_RETURN(queue);
+                if(-1 != fence)
+                {
+                    fenceFlag = I915_EXEC_FENCE_IN;
+                }
+
+                ret = mos_gem_bo_context_exec3(cmdBos,
+                                              numBos,
+                                              queue,
+                                              nullptr,
+                                              0,
+                                              dr4,
+                                              execFlag | fenceFlag,
+                                              &fence);
+
+                for(int i = 0; i < numBos; i++)
+                {
+                    cmdBos[i] = nullptr;
+                }
+                numBos = 0;
+
+                if(-1 != fence)
+                {
+                    close(fence);
+                }
+            }
+        }
+
+        it++;
+    }
+
+    return ret;
+}
+
 void GpuContextSpecific::IncrementGpuStatusTag()
 {
     m_GPUStatusTag = m_GPUStatusTag % UINT_MAX + 1;
