@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2015-2018, Intel Corporation
+* Copyright (c) 2015-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -483,7 +483,7 @@ MOS_FORMAT DdiDecodeHEVCG12::GetFormat()
                 {
                     Format = Format_P010;
                 }
-                else if(rtTbl->pCurrentRT->format == Media_Format_P016)
+                else if(rtTbl->pCurrentRT->format == Media_Format_P016 || rtTbl->pCurrentRT->format == Media_Format_P012)
                 {
                     Format = Format_P016;
                 }
@@ -495,7 +495,11 @@ MOS_FORMAT DdiDecodeHEVCG12::GetFormat()
                 {
                     Format = Format_Y210;
                 }
+#if VA_CHECK_VERSION(1, 9, 0)
+                else if(rtTbl->pCurrentRT->format == Media_Format_Y216 || rtTbl->pCurrentRT->format == Media_Format_Y212)
+#else
                 else if(rtTbl->pCurrentRT->format == Media_Format_Y216)
+#endif
                 {
                     Format = Format_Y216;
                 }
@@ -507,7 +511,11 @@ MOS_FORMAT DdiDecodeHEVCG12::GetFormat()
                 {
                     Format = Format_Y410;
                 }
+#if VA_CHECK_VERSION(1, 9, 0)
+                else if(rtTbl->pCurrentRT->format == Media_Format_Y416 || rtTbl->pCurrentRT->format == Media_Format_Y412)
+#else
                 else if(rtTbl->pCurrentRT->format == Media_Format_Y416)
+#endif
                 {
                     Format = Format_Y416;
                 }
@@ -521,7 +529,7 @@ MOS_FORMAT DdiDecodeHEVCG12::GetFormat()
             if (picParams->chroma_format_idc == 1)                 //420
             {
                 Format = Format_P010;
-                if(rtTbl->pCurrentRT->format == Media_Format_P016)
+                if(rtTbl->pCurrentRT->format == Media_Format_P016 || rtTbl->pCurrentRT->format == Media_Format_P012)
                 {
                     Format = Format_P016;
                 }
@@ -529,7 +537,11 @@ MOS_FORMAT DdiDecodeHEVCG12::GetFormat()
             else if (picParams->chroma_format_idc == 2)           //422
             {
                 Format = Format_Y210;
+#if VA_CHECK_VERSION(1, 9, 0)
+                if(rtTbl->pCurrentRT->format == Media_Format_Y216 || rtTbl->pCurrentRT->format == Media_Format_Y212)
+#else
                 if(rtTbl->pCurrentRT->format == Media_Format_Y216)
+#endif
                 {
                     Format = Format_Y216;
                 }
@@ -537,7 +549,11 @@ MOS_FORMAT DdiDecodeHEVCG12::GetFormat()
             else                                                  //444
             {
                 Format = Format_Y410;
+#if VA_CHECK_VERSION(1, 9, 0)
+                if(rtTbl->pCurrentRT->format == Media_Format_Y416 || rtTbl->pCurrentRT->format == Media_Format_Y412)
+#else
                 if(rtTbl->pCurrentRT->format == Media_Format_Y416)
+#endif
                 {
                     Format = Format_Y416;
                 }
@@ -565,7 +581,8 @@ MOS_FORMAT DdiDecodeHEVCG12::GetFormat()
         //420 10bit
         Format = Format_P010;
     }
-    else if (m_ddiDecodeAttr->profile == VAProfileHEVCSccMain444)
+    else if (m_ddiDecodeAttr->profile == VAProfileHEVCSccMain444 ||
+             m_ddiDecodeAttr->profile == VAProfileHEVCSccMain444_10)
     {
         //420/422/444 8bit
         if((picParams->bit_depth_luma_minus8 == 0) &&
@@ -654,8 +671,20 @@ VAStatus DdiDecodeHEVCG12::InitResourceBuffer()
     bufMgr->pSliceData               = nullptr;
 
     bufMgr->ui64BitstreamOrder = 0;
-    bufMgr->dwMaxBsSize        = m_width *
-                          m_height * 3 / 2;
+
+    if(m_width * m_height < CODEC_720P_MAX_PIC_WIDTH * CODEC_720P_MAX_PIC_HEIGHT)
+    {
+        bufMgr->dwMaxBsSize = m_width * m_height * 3 / 2;
+    }
+    else if(m_width * m_height < CODEC_4K_MAX_PIC_WIDTH * CODEC_4K_MAX_PIC_HEIGHT)
+    {
+        bufMgr->dwMaxBsSize = m_width * m_height * 3 / 8;
+    }
+    else
+    {
+        bufMgr->dwMaxBsSize = m_width * m_height * 3 / 16;
+    }
+
     // minimal 10k bytes for some special case. Will refractor this later
     if (bufMgr->dwMaxBsSize < DDI_CODEC_MIN_VALUE_OF_MAX_BS_SIZE)
     {
@@ -802,10 +831,16 @@ VAStatus DdiDecodeHEVCG12::AllocSliceControlBuffer(
     bufMgr     = &(m_ddiDecodeCtx->BufMgr);
     availSize = m_sliceCtrlBufNum - bufMgr->dwNumSliceControl;
 
+    if(buf->uiNumElements < 1 || buf->iSize < 1)
+        return VA_STATUS_ERROR_ALLOCATION_FAILED;
+
     if(m_ddiDecodeCtx->bShortFormatInUse)
     {
         if(availSize < buf->uiNumElements)
         {
+            if (buf->iSize / buf->uiNumElements != sizeof(VASliceParameterBufferBase))
+                return VA_STATUS_ERROR_ALLOCATION_FAILED;
+
             newSize   = sizeof(VASliceParameterBufferBase) * (m_sliceCtrlBufNum - availSize + buf->uiNumElements);
             bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufBaseHEVC = (VASliceParameterBufferBase *)realloc(bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufBaseHEVC, newSize);
             if(bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufBaseHEVC == nullptr)
@@ -824,6 +859,9 @@ VAStatus DdiDecodeHEVCG12::AllocSliceControlBuffer(
         {
             if(availSize < buf->uiNumElements)
             {
+                if (buf->iSize / buf->uiNumElements != sizeof(VASliceParameterBufferHEVC))
+                    return VA_STATUS_ERROR_ALLOCATION_FAILED;
+
                 newSize   = sizeof(VASliceParameterBufferHEVC) * (m_sliceCtrlBufNum - availSize + buf->uiNumElements);
                 bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufHEVC = (VASliceParameterBufferHEVC *)realloc(bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufHEVC, newSize);
                 if(bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufHEVC == nullptr)
@@ -840,6 +878,9 @@ VAStatus DdiDecodeHEVCG12::AllocSliceControlBuffer(
         {
             if(availSize < buf->uiNumElements)
             {
+                if (buf->iSize / buf->uiNumElements != sizeof(VASliceParameterBufferHEVCExtension))
+                    return VA_STATUS_ERROR_ALLOCATION_FAILED;
+
                 newSize   = sizeof(VASliceParameterBufferHEVCExtension) * (m_sliceCtrlBufNum - availSize + buf->uiNumElements);
                 bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufHEVCRext= (VASliceParameterBufferHEVCExtension*)realloc(bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufHEVCRext, newSize);
                 if(bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufHEVCRext== nullptr)
@@ -884,7 +925,8 @@ VAStatus DdiDecodeHEVCG12::CodecHalInit(
     if (m_ddiDecodeAttr->profile == VAProfileHEVCMain10 ||
         m_ddiDecodeAttr->profile == VAProfileHEVCMain422_10 ||
         m_ddiDecodeAttr->profile == VAProfileHEVCMain444_10 ||
-        m_ddiDecodeAttr->profile == VAProfileHEVCSccMain10)
+        m_ddiDecodeAttr->profile == VAProfileHEVCSccMain10 ||
+        m_ddiDecodeAttr->profile == VAProfileHEVCMain444_10)
     {
         m_codechalSettings->lumaChromaDepth |= CODECHAL_LUMA_CHROMA_DEPTH_10_BITS;
     }
@@ -903,18 +945,13 @@ VAStatus DdiDecodeHEVCG12::CodecHalInit(
     
     if(m_ddiDecodeAttr->profile == VAProfileHEVCMain444 ||
        m_ddiDecodeAttr->profile == VAProfileHEVCMain444_10 ||
-       m_ddiDecodeAttr->profile == VAProfileHEVCMain444_12)
+       m_ddiDecodeAttr->profile == VAProfileHEVCMain444_12 ||
+       m_ddiDecodeAttr->profile == VAProfileHEVCSccMain444 ||
+       m_ddiDecodeAttr->profile == VAProfileHEVCSccMain444_10)
     {
         m_codechalSettings->chromaFormat = HCP_CHROMA_FORMAT_YUV444;
     }
 
-    if(m_ddiDecodeAttr->profile == VAProfileHEVCSccMain444)
-    {
-        // Since only one profile definition for SCC, so using maximun bitdepth and chrome id here
-        m_codechalSettings->lumaChromaDepth |= CODECHAL_LUMA_CHROMA_DEPTH_10_BITS;
-        m_codechalSettings->chromaFormat = HCP_CHROMA_FORMAT_YUV444;
-    }
-
     m_ddiDecodeCtx->DecodeParams.m_iqMatrixBuffer = MOS_AllocAndZeroMemory(sizeof(CODECHAL_HEVC_IQ_MATRIX_PARAMS));
     if (m_ddiDecodeCtx->DecodeParams.m_iqMatrixBuffer == nullptr)
     {
@@ -968,11 +1005,11 @@ VAStatus DdiDecodeHEVCG12::CodecHalInit(
 #ifdef _DECODE_PROCESSING_SUPPORTED
     if (m_decProcessingType == VA_DEC_PROCESSING)
     {
-        PCODECHAL_DECODE_PROCESSING_PARAMS procParams = nullptr;
+        DecodeProcessingParams *procParams = nullptr;
         
         m_codechalSettings->downsamplingHinted = true;
         
-        procParams = (PCODECHAL_DECODE_PROCESSING_PARAMS)MOS_AllocAndZeroMemory(sizeof(CODECHAL_DECODE_PROCESSING_PARAMS));
+        procParams = (DecodeProcessingParams *)MOS_AllocAndZeroMemory(sizeof(DecodeProcessingParams));
         if (procParams == nullptr)
         {
             vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
@@ -980,8 +1017,8 @@ VAStatus DdiDecodeHEVCG12::CodecHalInit(
         }
         
         m_ddiDecodeCtx->DecodeParams.m_procParams = procParams;
-        procParams->pOutputSurface = (PMOS_SURFACE)MOS_AllocAndZeroMemory(sizeof(MOS_SURFACE));
-        if (procParams->pOutputSurface == nullptr)
+        procParams->m_outputSurface = (PMOS_SURFACE)MOS_AllocAndZeroMemory(sizeof(MOS_SURFACE));
+        if (procParams->m_outputSurface == nullptr)
         {
             vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
             goto CleanUpandReturn;
@@ -989,13 +1026,6 @@ VAStatus DdiDecodeHEVCG12::CodecHalInit(
     }
 #endif
 
-    m_ddiDecodeCtx->DecodeParams.m_subsetParams = MOS_AllocAndZeroMemory(sizeof(CODEC_HEVC_SUBSET_PARAMS));
-    if (m_ddiDecodeCtx->DecodeParams.m_subsetParams == nullptr)
-    {
-        vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
-        goto CleanUpandReturn;
-    }
-
     vaStatus = CreateCodecHal(mediaCtx,
         ptr,
         &standardInfo);
@@ -1036,8 +1066,8 @@ CleanUpandReturn:
     if (m_ddiDecodeCtx->DecodeParams.m_procParams)
     {
         auto procParams =
-            (PCODECHAL_DECODE_PROCESSING_PARAMS)m_ddiDecodeCtx->DecodeParams.m_procParams;
-        MOS_FreeMemory(procParams->pOutputSurface);
+            (DecodeProcessingParams *)m_ddiDecodeCtx->DecodeParams.m_procParams;
+        MOS_FreeMemory(procParams->m_outputSurface);
         
         MOS_FreeMemory(m_ddiDecodeCtx->DecodeParams.m_procParams);
         m_ddiDecodeCtx->DecodeParams.m_procParams = nullptr;
@@ -1057,7 +1087,8 @@ bool DdiDecodeHEVCG12::IsRextProfile()
         m_ddiDecodeAttr->profile == VAProfileHEVCMain444_12 || \
         m_ddiDecodeAttr->profile == VAProfileHEVCSccMain    || \
         m_ddiDecodeAttr->profile == VAProfileHEVCSccMain10  || \
-        m_ddiDecodeAttr->profile == VAProfileHEVCSccMain444    \
+        m_ddiDecodeAttr->profile == VAProfileHEVCSccMain444 || \
+        m_ddiDecodeAttr->profile == VAProfileHEVCSccMain444_10 \
         );
 }
 
@@ -1066,7 +1097,8 @@ bool DdiDecodeHEVCG12::IsSccProfile()
     return (                                                   \
         m_ddiDecodeAttr->profile == VAProfileHEVCSccMain    || \
         m_ddiDecodeAttr->profile == VAProfileHEVCSccMain10  || \
-        m_ddiDecodeAttr->profile == VAProfileHEVCSccMain444    \
+        m_ddiDecodeAttr->profile == VAProfileHEVCSccMain444 || \
+        m_ddiDecodeAttr->profile == VAProfileHEVCSccMain444_10 \
         );
 }
 
