@@ -37,7 +37,7 @@ static struct LinuxCodecInfo sklCodecInfo =
     .avcDecoding        = 1,
     .mpeg2Decoding      = 1,
     .vp8Decoding        = 1,
-    .vc1Decoding        = 1,
+    .vc1Decoding        = SET_STATUS_BY_FULL_OPEN_SOURCE(1, 0),
     .jpegDecoding       = 1,
     .avcEncoding        = SET_STATUS_BY_FULL_OPEN_SOURCE(1, 0),
     .mpeg2Encoding      = SET_STATUS_BY_FULL_OPEN_SOURCE(1, 0),
@@ -52,7 +52,7 @@ static struct LinuxCodecInfo bxtCodecInfo =
     .avcDecoding        = 1,
     .mpeg2Decoding      = 1,
     .vp8Decoding        = 1,
-    .vc1Decoding        = 1,
+    .vc1Decoding        = SET_STATUS_BY_FULL_OPEN_SOURCE(1, 0),
     .jpegDecoding       = 1,
     .avcEncoding        = SET_STATUS_BY_FULL_OPEN_SOURCE(1, 0),
     .mpeg2Encoding      = 0,
@@ -70,7 +70,7 @@ static struct LinuxCodecInfo kblCodecInfo =
     .avcDecoding        = 1,
     .mpeg2Decoding      = 1,
     .vp8Decoding        = 1,
-    .vc1Decoding        = 1,
+    .vc1Decoding        = SET_STATUS_BY_FULL_OPEN_SOURCE(1, 0),
     .jpegDecoding       = 1,
     .avcEncoding        = SET_STATUS_BY_FULL_OPEN_SOURCE(1, 0),
     .mpeg2Encoding      = SET_STATUS_BY_FULL_OPEN_SOURCE(1, 0),
@@ -91,7 +91,7 @@ static struct LinuxCodecInfo glkCodecInfo =
     .avcDecoding        = 1,
     .mpeg2Decoding      = 1,
     .vp8Decoding        = 1,
-    .vc1Decoding        = 1,
+    .vc1Decoding        = SET_STATUS_BY_FULL_OPEN_SOURCE(1, 0),
     .jpegDecoding       = 1,
     .avcEncoding        = SET_STATUS_BY_FULL_OPEN_SOURCE(1, 0),
     .mpeg2Encoding      = 0,
@@ -103,6 +103,8 @@ static struct LinuxCodecInfo glkCodecInfo =
     .hevc10Decoding     = 1,
     .vp9b10Decoding     = 1,
     .hevc10Encoding     = SET_STATUS_BY_FULL_OPEN_SOURCE(1, 0),
+    .hevc12Encoding     = 0,
+    .vp8Encoding        = SET_STATUS_BY_FULL_OPEN_SOURCE(1, 0),
 };
 
 static bool InitSklMediaSku(struct GfxDeviceInfo *devInfo,
@@ -184,6 +186,8 @@ static bool InitSklMediaSku(struct GfxDeviceInfo *devInfo,
     MEDIA_WR_SKU(skuTable, FtrMemoryCompression, 0);
     MEDIA_WR_SKU(skuTable, FtrHcpDecMemoryCompression, 0);
 
+    MEDIA_WR_SKU(skuTable, FtrVpP010Output, 1);
+
     MEDIA_WR_SKU(skuTable, FtrPerCtxtPreemptionGranularityControl, 1);
 
     MEDIA_WR_SKU(skuTable, FtrTileY, 1);
@@ -215,6 +219,7 @@ static bool InitSklMediaWa(struct GfxDeviceInfo *devInfo,
     MEDIA_WR_WA(waTable, WaHucStreamoutOnlyDisable, 1);
 
     MEDIA_WR_WA(waTable, Wa16KInputHeightNV12Planar420, 1);
+    MEDIA_WR_WA(waTable, WaDisableCodecMmc, 1);
     return true;
 }
 
@@ -251,7 +256,20 @@ static bool InitBxtMediaSku(struct GfxDeviceInfo *devInfo,
 
     MEDIA_WR_SKU(skuTable, FtrEnableMediaKernels, drvInfo->hasHuc);
 
-    MEDIA_WR_SKU(skuTable, FtrGT1, 1);
+    if (devInfo->eGTType == GTTYPE_GT1)
+    {
+        MEDIA_WR_SKU(skuTable, FtrGT1, 1);
+    }
+    else if (devInfo->eGTType == GTTYPE_GT1_5)
+    {
+        MEDIA_WR_SKU(skuTable, FtrGT1_5, 1);
+    }
+    else
+    {
+        /* GT1 is by default */
+        MEDIA_WR_SKU(skuTable, FtrGT1, 1);
+    }
+
     MEDIA_WR_SKU(skuTable, FtrLCIA, 1);
     MEDIA_WR_SKU(skuTable, FtrVERing, drvInfo->hasVebox);
     MEDIA_WR_SKU(skuTable, FtrEDram, devInfo->hasERAM);
@@ -264,6 +282,8 @@ static bool InitBxtMediaSku(struct GfxDeviceInfo *devInfo,
 
     MEDIA_WR_SKU(skuTable, FtrPerCtxtPreemptionGranularityControl, 1);
 
+    MEDIA_WR_SKU(skuTable, FtrVpP010Output, 1);
+
     return true;
 }
 
@@ -297,6 +317,7 @@ static bool InitBxtMediaWa(struct GfxDeviceInfo *devInfo,
     MEDIA_WR_WA(waTable, WaHucStreamoutOnlyDisable, 1);
 
     MEDIA_WR_WA(waTable, Wa16KInputHeightNV12Planar420, 1);
+    MEDIA_WR_WA(waTable, WaDisableCodecMmc, 1);
     return true;
 }
 
@@ -330,6 +351,7 @@ static bool InitKblMediaSku(struct GfxDeviceInfo *devInfo,
         MEDIA_WR_SKU(skuTable, FtrEncodeAVCVdenc, codecInfo->avcVdenc);
         MEDIA_WR_SKU(skuTable, FtrVP9VLDDecoding, codecInfo->vp9Decoding);
         MEDIA_WR_SKU(skuTable, FtrIntelVP9VLDProfile0Decoding8bit420, codecInfo->vp9Decoding);
+        MEDIA_WR_SKU(skuTable, FtrIntelVP9VLDProfile2Decoding10bit420, codecInfo->vp9b10Decoding);
         MEDIA_WR_SKU(skuTable, FtrVP9VLD10bProfile2Decoding, codecInfo->vp9b10Decoding);
         MEDIA_WR_SKU(skuTable, FtrIntelVP9VLDProfile2Decoding, codecInfo->vp9b10Decoding);
 
@@ -351,14 +373,17 @@ static bool InitKblMediaSku(struct GfxDeviceInfo *devInfo,
     else if (devInfo->eGTType == GTTYPE_GT2)
     {
         MEDIA_WR_SKU(skuTable, FtrGT2, 1);
+        MEDIA_WR_SKU(skuTable, FtrHDR, 1);
     }
     else if (devInfo->eGTType == GTTYPE_GT3)
     {
         MEDIA_WR_SKU(skuTable, FtrGT3, 1);
+        MEDIA_WR_SKU(skuTable, FtrHDR, 1);
     }
     else if (devInfo->eGTType == GTTYPE_GT4)
     {
         MEDIA_WR_SKU(skuTable, FtrGT4, 1);
+        MEDIA_WR_SKU(skuTable, FtrHDR, 1);
     }
     else
     {
@@ -423,6 +448,7 @@ static bool InitKblMediaWa(struct GfxDeviceInfo *devInfo,
     MEDIA_WR_WA(waTable, WaHucStreamoutOnlyDisable, 1);
 
     MEDIA_WR_WA(waTable, Wa16KInputHeightNV12Planar420, 1);
+    MEDIA_WR_WA(waTable, WaDisableCodecMmc, 1);
     return true;
 }
 
@@ -458,11 +484,27 @@ static bool InitGlkMediaSku(struct GfxDeviceInfo *devInfo,
         MEDIA_WR_SKU(skuTable, FtrIntelVP9VLDProfile0Decoding8bit420, codecInfo->vp9Decoding);
         MEDIA_WR_SKU(skuTable, FtrVP9VLD10bProfile2Decoding, codecInfo->vp9b10Decoding);
         MEDIA_WR_SKU(skuTable, FtrIntelVP9VLDProfile2Decoding10bit420, codecInfo->vp9b10Decoding);
+
+        /* VP8 enc */
+        MEDIA_WR_SKU(skuTable, FtrEncodeVP8, codecInfo->vp8Encoding);
     }
 
     MEDIA_WR_SKU(skuTable, FtrEnableMediaKernels, drvInfo->hasHuc);
 
-    MEDIA_WR_SKU(skuTable, FtrGT1, 1);
+    if (devInfo->eGTType == GTTYPE_GT1)
+    {
+        MEDIA_WR_SKU(skuTable, FtrGT1, 1);
+    }
+    else if (devInfo->eGTType == GTTYPE_GT1_5)
+    {
+        MEDIA_WR_SKU(skuTable, FtrGT1_5, 1);
+    }
+    else
+    {
+        /* GT1 is by default */
+        MEDIA_WR_SKU(skuTable, FtrGT1, 1);
+    }
+
     MEDIA_WR_SKU(skuTable, FtrLCIA, 1);
     MEDIA_WR_SKU(skuTable, FtrVERing, drvInfo->hasVebox);
     MEDIA_WR_SKU(skuTable, FtrPPGTT, drvInfo->hasPpgtt);
@@ -477,6 +519,8 @@ static bool InitGlkMediaSku(struct GfxDeviceInfo *devInfo,
 
     MEDIA_WR_SKU(skuTable, FtrPerCtxtPreemptionGranularityControl, 1);
 
+    MEDIA_WR_SKU(skuTable, FtrHDR, 1);
+
     return true;
 }
 
@@ -510,6 +554,7 @@ static bool InitGlkMediaWa(struct GfxDeviceInfo *devInfo,
     MEDIA_WR_WA(waTable, WaHucStreamoutOnlyDisable, 1);
 
     MEDIA_WR_WA(waTable, Wa16KInputHeightNV12Planar420, 1);
+    MEDIA_WR_WA(waTable, WaDisableCodecMmc, 1);
     return true;
 }
 
