@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2021, Intel Corporation
+* Copyright (c) 2018-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -195,6 +195,21 @@ VpResourceManager::~VpResourceManager()
         m_allocator.DestroyVpSurface(m_vebox3DLookUpTables);
     }
 
+    if (m_vebox3DLookUpTables2D)
+    {
+        m_allocator.DestroyVpSurface(m_vebox3DLookUpTables2D);
+    }
+
+    if (m_3DLutKernelCoefSurface)
+    {
+        m_allocator.DestroyVpSurface(m_3DLutKernelCoefSurface);
+    }
+
+    if (m_vebox1DLookUpTables)
+    {
+        m_allocator.DestroyVpSurface(m_vebox1DLookUpTables);
+    }
+
     while (!m_intermediaSurfaces.empty())
     {
         VP_SURFACE * surf = m_intermediaSurfaces.back();
@@ -581,6 +596,13 @@ void VpResourceManager::InitSurfaceConfigMap()
     AddSurfaceConfig(true,  true,  false, false, true,  false, false, VEBOX_SURFACE_INPUT,  VEBOX_SURFACE_PAST_REF, VEBOX_SURFACE_FRAME1, VEBOX_SURFACE_FRAME0);
     AddSurfaceConfig(true,  true,  true,  false, false, false, true,  VEBOX_SURFACE_INPUT,  VEBOX_SURFACE_NULL,     VEBOX_SURFACE_FRAME1, VEBOX_SURFACE_NULL);
     AddSurfaceConfig(true,  true,  true,  false, false, false, false, VEBOX_SURFACE_INPUT,  VEBOX_SURFACE_NULL,     VEBOX_SURFACE_FRAME1, VEBOX_SURFACE_NULL);
+    AddSurfaceConfig(true,  false,  false, false, true,  false, true,  VEBOX_SURFACE_INPUT,  VEBOX_SURFACE_PAST_REF, VEBOX_SURFACE_FRAME1, VEBOX_SURFACE_OUTPUT);
+    AddSurfaceConfig(true,  false,  true,  false, true,  false, false, VEBOX_SURFACE_FRAME1, VEBOX_SURFACE_NULL,     VEBOX_SURFACE_NULL,   VEBOX_SURFACE_NULL);
+    AddSurfaceConfig(true,  false,  false, false, false, false, true,  VEBOX_SURFACE_INPUT,  VEBOX_SURFACE_NULL,     VEBOX_SURFACE_OUTPUT, VEBOX_SURFACE_NULL);
+    AddSurfaceConfig(true,  false,  false, false, false, false, false, VEBOX_SURFACE_INPUT,  VEBOX_SURFACE_NULL,     VEBOX_SURFACE_FRAME1, VEBOX_SURFACE_NULL);
+    AddSurfaceConfig(true,  false,  false, false, true,  false, false, VEBOX_SURFACE_INPUT,  VEBOX_SURFACE_PAST_REF, VEBOX_SURFACE_FRAME1, VEBOX_SURFACE_FRAME0);
+    AddSurfaceConfig(true,  false,  true,  false, false, false, true,  VEBOX_SURFACE_INPUT,  VEBOX_SURFACE_NULL,     VEBOX_SURFACE_FRAME1, VEBOX_SURFACE_NULL);
+    AddSurfaceConfig(true,  false,  true,  false, false, false, false, VEBOX_SURFACE_INPUT,  VEBOX_SURFACE_NULL,     VEBOX_SURFACE_FRAME1, VEBOX_SURFACE_NULL);
 }
 
 uint32_t VpResourceManager::GetHistogramSurfaceSize(VP_EXECUTE_CAPS& caps, uint32_t inputWidth, uint32_t inputHeight)
@@ -606,7 +628,11 @@ MOS_STATUS VpResourceManager::GetResourceHint(std::vector<FeatureType> &featureP
     SwFilterSubPipe *inputPipe = executedFilters.GetSwFilterSubPipe(true, index);
 
     // only process Primary surface
-    VP_PUBLIC_CHK_NULL_RETURN(inputPipe);
+    if (inputPipe == nullptr)
+    {
+        VP_PUBLIC_NORMALMESSAGE("No inputPipe, so there is no hint message!");
+        return MOS_STATUS_SUCCESS;
+    }
     for (auto filterID : featurePool)
     {
         SwFilter* feature = (SwFilter*)inputPipe->GetSwFilter(FeatureType(filterID));
@@ -620,24 +646,84 @@ MOS_STATUS VpResourceManager::GetResourceHint(std::vector<FeatureType> &featureP
 
 struct VP_SURFACE_PARAMS
 {
-    uint32_t                width;
-    uint32_t                height;
-    MOS_FORMAT              format;
-    MOS_TILE_TYPE           tileType;
+    uint32_t                width               = 0;
+    uint32_t                height              = 0;
+    MOS_FORMAT              format              = Format_None;
+    MOS_TILE_TYPE           tileType            = MOS_TILE_X;
     MOS_RESOURCE_MMC_MODE   surfCompressionMode = MOS_MMC_DISABLED;
-    bool                    surfCompressible   = false;
-    VPHAL_CSPACE            colorSpace;
-    RECT                    rcSrc;              //!< Source rectangle
-    RECT                    rcDst;              //!< Destination rectangle
-    RECT                    rcMaxSrc;           //!< Max source rectangle
-    VPHAL_SAMPLE_TYPE       sampleType;
+    bool                    surfCompressible    = false;
+    VPHAL_CSPACE            colorSpace          = CSpace_None;
+    RECT                    rcSrc               = {0, 0, 0, 0};  //!< Source rectangle
+    RECT                    rcDst               = {0, 0, 0, 0};  //!< Destination rectangle
+    RECT                    rcMaxSrc            = {0, 0, 0, 0};  //!< Max source rectangle
+    VPHAL_SAMPLE_TYPE       sampleType          = SAMPLE_PROGRESSIVE;
 };
+MOS_STATUS VpResourceManager::Get3DLutOutputColorAndFormat(VPHAL_CSPACE &colorSpace, MOS_FORMAT &format, SwFilterPipe &executedFilters)
+{
+    SwFilterHdr *hdr = dynamic_cast<SwFilterHdr *>(executedFilters.GetSwFilter(true, 0, FeatureType::FeatureTypeHdr));
+    if (hdr)
+    {
+        colorSpace = hdr->GetSwFilterParams().dstColorSpace;
+        format     = hdr->GetSwFilterParams().formatOutput;
+    }
+    else
+    {   // caps.b3DlutOutput =1, in hdr tests hdr flag should not be false.
+        VP_PUBLIC_ASSERTMESSAGE("It is unexcepted for HDR case with caps.b3DlutOutput as true, return INVALID_PARAMETER");
+        VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
+
+    }
+    return MOS_STATUS_SUCCESS;
+}
+MOS_STATUS VpResourceManager::GetIntermediaOutputSurfaceColorAndFormat(VP_EXECUTE_CAPS &caps, SwFilterPipe &executedFilters, MOS_FORMAT &format, VPHAL_CSPACE &colorSpace)
+{
+    VP_SURFACE *inputSurface = executedFilters.GetSurface(true, 0);
+    VP_PUBLIC_CHK_NULL_RETURN(inputSurface);
+    if (caps.bRender)
+    {
+        SwFilterCsc *csc = dynamic_cast<SwFilterCsc *>(executedFilters.GetSwFilter(true, 0, FeatureType::FeatureTypeCscOnRender));
+        if (csc)
+        {
+            format            = csc->GetSwFilterParams().formatOutput;
+            colorSpace        = csc->GetSwFilterParams().output.colorSpace;
+            return MOS_STATUS_SUCCESS;
+        }
+
+    }
+    else if (caps.bSFC)
+    {
+        SwFilterCsc *csc = dynamic_cast<SwFilterCsc *>(executedFilters.GetSwFilter(true, 0, FeatureType::FeatureTypeCscOnSfc));
+        if (csc)
+        {
+            format            = csc->GetSwFilterParams().formatOutput;
+            colorSpace        = csc->GetSwFilterParams().output.colorSpace;
+            return MOS_STATUS_SUCCESS;
+        }
+    }
+    else if (caps.b3DlutOutput)
+    {
+        VP_PUBLIC_CHK_STATUS_RETURN(Get3DLutOutputColorAndFormat(colorSpace, format, executedFilters));
+        return MOS_STATUS_SUCCESS;
+    }
+    else if (caps.bVebox)
+    {
+        SwFilterCsc *csc = dynamic_cast<SwFilterCsc *>(executedFilters.GetSwFilter(true, 0, FeatureType::FeatureTypeCscOnVebox));
+        if (csc)
+        {
+            format            = csc->GetSwFilterParams().formatOutput;
+            colorSpace        = csc->GetSwFilterParams().output.colorSpace;
+            return MOS_STATUS_SUCCESS;
+        }
+    }
+
+    format            = inputSurface->osSurface->Format;
+    colorSpace        = inputSurface->ColorSpace;
+    return MOS_STATUS_SUCCESS;
+}
 
 MOS_STATUS VpResourceManager::GetIntermediaOutputSurfaceParams(VP_EXECUTE_CAPS& caps, VP_SURFACE_PARAMS &params, SwFilterPipe &executedFilters)
 {
     VP_FUNC_CALL();
 
-    SwFilterCsc *csc = dynamic_cast<SwFilterCsc *>(executedFilters.GetSwFilter(true, 0, FeatureType::FeatureTypeCsc));
     SwFilterScaling *scaling = dynamic_cast<SwFilterScaling *>(executedFilters.GetSwFilter(true, 0, FeatureType::FeatureTypeScaling));
     SwFilterRotMir *rotMir = dynamic_cast<SwFilterRotMir *>(executedFilters.GetSwFilter(true, 0, FeatureType::FeatureTypeRotMir));
     SwFilterDeinterlace *di = dynamic_cast<SwFilterDeinterlace *>(executedFilters.GetSwFilter(true, 0, FeatureType::FeatureTypeDi));
@@ -681,16 +767,8 @@ MOS_STATUS VpResourceManager::GetIntermediaOutputSurfaceParams(VP_EXECUTE_CAPS&
         RECT_ROTATE(params.rcMaxSrc, tmp);
     }
 
-    if (csc)
-    {
-        params.format = csc->GetSwFilterParams().formatOutput;
-        params.colorSpace = csc->GetSwFilterParams().output.colorSpace;
-    }
-    else
-    {
-        params.format = inputSurface->osSurface->Format;
-        params.colorSpace = inputSurface->ColorSpace;
-    }
+    VP_PUBLIC_CHK_STATUS_RETURN(GetIntermediaOutputSurfaceColorAndFormat(caps, executedFilters, params.format, params.colorSpace));
+
     params.tileType = MOS_TILE_Y;
     params.surfCompressionMode = caps.bRender ? MOS_MMC_RC : MOS_MMC_MC;
     params.surfCompressible = true;
@@ -831,7 +909,9 @@ VP_SURFACE * VpResourceManager::GetCopyInstOfExtSurface(VP_SURFACE* surf)
     return surface;
 }
 
-MOS_STATUS VpResourceManager::AssignFcResources(VP_EXECUTE_CAPS &caps, std::vector<VP_SURFACE *> &inputSurfaces, VP_SURFACE *outputSurface, RESOURCE_ASSIGNMENT_HINT resHint, VP_SURFACE_SETTING &surfSetting)
+MOS_STATUS VpResourceManager::AssignFcResources(VP_EXECUTE_CAPS &caps, std::vector<VP_SURFACE *> &inputSurfaces, VP_SURFACE *outputSurface,
+    std::vector<VP_SURFACE *> &pastSurfaces, std::vector<VP_SURFACE *> &futureSurfaces,
+    RESOURCE_ASSIGNMENT_HINT resHint, VP_SURFACE_SETTING &surfSetting)
 {
     VP_FUNC_CALL();
 
@@ -847,6 +927,25 @@ MOS_STATUS VpResourceManager::AssignFcResources(VP_EXECUTE_CAPS &caps, std::vect
     for (size_t i = 0; i < inputSurfaces.size(); ++i)
     {
         surfSetting.surfGroup.insert(std::make_pair((SurfaceType)(SurfaceTypeFcInputLayer0 + i), inputSurfaces[i]));
+
+        if (!resHint.isIScalingTypeNone)
+        {
+            // For Interlaced scaling, 2nd field is part of the same frame.
+            // For Field weaving, 2nd field is passed in as a ref.
+            VP_SURFACE *surfField1Dual = nullptr;
+            if (resHint.isFieldWeaving)
+            {
+                surfField1Dual = pastSurfaces[i];
+                VP_PUBLIC_NORMALMESSAGE("Field weaving case. 2nd field is passed in as a ref.");
+            }
+            else
+            {
+                surfField1Dual = GetCopyInstOfExtSurface(inputSurfaces[i]);
+                VP_PUBLIC_NORMALMESSAGE("Interlaced scaling. 2nd field is part of the same frame.");
+            }
+            VP_PUBLIC_CHK_NULL_RETURN(surfField1Dual);
+            surfSetting.surfGroup.insert(std::make_pair((SurfaceType)(SurfaceTypeFcInputLayer0Field1Dual + i), surfField1Dual));
+        }
     }
     surfSetting.surfGroup.insert(std::make_pair(SurfaceTypeFcTarget0, outputSurface));
 
@@ -874,13 +973,18 @@ MOS_STATUS VpResourceManager::AssignFcResources(VP_EXECUTE_CAPS &caps, std::vect
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS VpResourceManager::AssignRenderResource(VP_EXECUTE_CAPS &caps, std::vector<VP_SURFACE *> &inputSurfaces, VP_SURFACE *outputSurface, RESOURCE_ASSIGNMENT_HINT resHint, VP_SURFACE_SETTING &surfSetting)
+MOS_STATUS VpResourceManager::AssignRenderResource(VP_EXECUTE_CAPS &caps, std::vector<VP_SURFACE *> &inputSurfaces, VP_SURFACE *outputSurface,
+    std::vector<VP_SURFACE *> &pastSurfaces, std::vector<VP_SURFACE *> &futureSurfaces, RESOURCE_ASSIGNMENT_HINT resHint, VP_SURFACE_SETTING &surfSetting)
 {
     VP_FUNC_CALL();
 
     if (caps.bComposite)
     {
-        VP_PUBLIC_CHK_STATUS_RETURN(AssignFcResources(caps, inputSurfaces, outputSurface, resHint, surfSetting));
+        VP_PUBLIC_CHK_STATUS_RETURN(AssignFcResources(caps, inputSurfaces, outputSurface, pastSurfaces, futureSurfaces, resHint, surfSetting));
+    }
+    else if (caps.b3DLutCalc)
+    {
+        VP_PUBLIC_CHK_STATUS_RETURN(Assign3DLutKernelResource(caps, resHint, surfSetting));
     }
     else
     {
@@ -910,16 +1014,20 @@ MOS_STATUS VpResourceManager::AssignExecuteResource(std::vector<FeatureType> &fe
 {
     VP_FUNC_CALL();
 
-    std::vector<VP_SURFACE *> inputSurfaces;
+    std::vector<VP_SURFACE *> inputSurfaces, pastSurfaces, futureSurfaces;
     for (uint32_t i = 0; i < executedFilters.GetSurfaceCount(true); ++i)
     {
         VP_SURFACE *inputSurface = GetCopyInstOfExtSurface(executedFilters.GetSurface(true, i));
         VP_PUBLIC_CHK_NULL_RETURN(inputSurface);
         inputSurfaces.push_back(inputSurface);
+
+        VP_SURFACE *pastSurface = GetCopyInstOfExtSurface(executedFilters.GetPastSurface(i));
+        pastSurfaces.push_back(pastSurface ? pastSurface : nullptr);
+
+        VP_SURFACE *futureSurface = GetCopyInstOfExtSurface(executedFilters.GetFutureSurface(i));
+        futureSurfaces.push_back(futureSurface ? futureSurface : nullptr);
     }
     VP_SURFACE                  *outputSurface  = GetCopyInstOfExtSurface(executedFilters.GetSurface(false, 0));
-    VP_SURFACE                  *pastSurface    = GetCopyInstOfExtSurface(executedFilters.GetPastSurface(0));
-    VP_SURFACE                  *futureSurface  = GetCopyInstOfExtSurface(executedFilters.GetFutureSurface(0));
 
     RESOURCE_ASSIGNMENT_HINT    resHint         = {};
 
@@ -933,13 +1041,13 @@ MOS_STATUS VpResourceManager::AssignExecuteResource(std::vector<FeatureType> &fe
     }
 
     VP_PUBLIC_CHK_STATUS_RETURN(AssignExecuteResource(caps, inputSurfaces, outputSurface,
-        pastSurface, futureSurface, resHint, executedFilters.GetSurfacesSetting()));
+        pastSurfaces, futureSurfaces, resHint, executedFilters.GetSurfacesSetting()));
     ++m_currentPipeIndex;
     return MOS_STATUS_SUCCESS;
 }
 
 MOS_STATUS VpResourceManager::AssignExecuteResource(VP_EXECUTE_CAPS& caps, std::vector<VP_SURFACE *> &inputSurfaces, VP_SURFACE *outputSurface,
-    VP_SURFACE *pastSurface, VP_SURFACE *futureSurface, RESOURCE_ASSIGNMENT_HINT resHint, VP_SURFACE_SETTING &surfSetting)
+    std::vector<VP_SURFACE *> &pastSurfaces, std::vector<VP_SURFACE *> &futureSurfaces, RESOURCE_ASSIGNMENT_HINT resHint, VP_SURFACE_SETTING &surfSetting)
 {
     VP_FUNC_CALL();
 
@@ -948,12 +1056,12 @@ MOS_STATUS VpResourceManager::AssignExecuteResource(VP_EXECUTE_CAPS& caps, std::
     if (caps.bVebox || caps.bDnKernelUpdate)
     {
         // Create Vebox Resources
-        VP_PUBLIC_CHK_STATUS_RETURN(AssignVeboxResource(caps, inputSurfaces[0], outputSurface, pastSurface, futureSurface, resHint, surfSetting));
+        VP_PUBLIC_CHK_STATUS_RETURN(AssignVeboxResource(caps, inputSurfaces[0], outputSurface, pastSurfaces[0], futureSurfaces[0], resHint, surfSetting));
     }
 
     if (caps.bRender)
     {
-        VP_PUBLIC_CHK_STATUS_RETURN(AssignRenderResource(caps, inputSurfaces, outputSurface, resHint, surfSetting));
+        VP_PUBLIC_CHK_STATUS_RETURN(AssignRenderResource(caps, inputSurfaces, outputSurface, pastSurfaces, futureSurfaces, resHint, surfSetting));
     }
 
     return MOS_STATUS_SUCCESS;
@@ -1430,13 +1538,30 @@ void VpResourceManager::DestoryVeboxSTMMSurface()
     }
 }
 
-uint32_t VpResourceManager::Get3DLutSize()
+MOS_STATUS VpResourceManager::FillLinearBufferWithEncZero(uint32_t width, uint32_t height)
 {
     VP_FUNC_CALL();
 
+    return MOS_STATUS_SUCCESS;
+}
+
+uint32_t VpResourceManager::Get3DLutSize(uint32_t &lutWidth, uint32_t &lutHeight)
+{
+    VP_FUNC_CALL();
+
+    lutWidth = LUT65_SEG_SIZE * 2;
+    lutHeight = LUT65_SEG_SIZE * LUT65_MUL_SIZE;
+
     return VP_VEBOX_HDR_3DLUT65;
 }
 
+uint32_t VpResourceManager::Get1DLutSize()
+{
+    VP_FUNC_CALL();
+
+    return SHAPE_1K_LOOKUP_SIZE;
+}
+
 Mos_MemPool VpResourceManager::GetHistStatMemType()
 {
     VP_FUNC_CALL();
@@ -1616,7 +1741,7 @@ MOS_STATUS VpResourceManager::AllocateVeboxResource(VP_EXECUTE_CAPS& caps, VP_SU
         false,
         MOS_MMC_DISABLED,
         bAllocated,
-        true,
+        false,
         IsDeferredResourceDestroyNeeded(),
         MOS_HW_RESOURCE_USAGE_VP_INTERNAL_WRITE_FF,
         MOS_TILE_UNSET_GMM,
@@ -1625,7 +1750,11 @@ MOS_STATUS VpResourceManager::AllocateVeboxResource(VP_EXECUTE_CAPS& caps, VP_SU
 
     if (bAllocated)
     {
-        if (MOS_MEMPOOL_DEVICEMEMORY != memTypeHistStat)
+        if (caps.bSecureVebox)
+        {
+            VP_PUBLIC_CHK_STATUS_RETURN(FillLinearBufferWithEncZero(dwWidth, dwHeight));
+        }
+        else if (MOS_MEMPOOL_DEVICEMEMORY != memTypeHistStat)
         {
             // Initialize veboxStatisticsSurface Surface
             VP_PUBLIC_CHK_STATUS_RETURN(m_allocator.OsFillResource(
@@ -1637,13 +1766,14 @@ MOS_STATUS VpResourceManager::AllocateVeboxResource(VP_EXECUTE_CAPS& caps, VP_SU
         }
     }
 
-    if (caps.bHDR3DLUT)
+    VP_PUBLIC_CHK_STATUS_RETURN(Allocate3DLut(caps));
+
+    if (caps.bDV)
     {
-        // HDR
-        dwSize = Get3DLutSize();
+        dwSize = Get1DLutSize();
         VP_PUBLIC_CHK_STATUS_RETURN(m_allocator.ReAllocateSurface(
-            m_vebox3DLookUpTables,
-            "Vebox3DLutTableSurface",
+            m_vebox1DLookUpTables,
+            "Dv1K1DLutTableSurface",
             Format_Buffer,
             MOS_GFXRES_BUFFER,
             MOS_TILE_LINEAR,
@@ -1660,6 +1790,107 @@ MOS_STATUS VpResourceManager::AllocateVeboxResource(VP_EXECUTE_CAPS& caps, VP_SU
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS VpResourceManager::Allocate3DLut(VP_EXECUTE_CAPS& caps)
+{
+    VP_FUNC_CALL();
+    uint32_t                        size = 0;
+    bool                            isAllocated          = false;
+
+    if (caps.bHDR3DLUT)
+    {
+        // HDR
+        uint32_t lutWidth = 0;
+        uint32_t lutHeight = 0;
+        size = Get3DLutSize(lutWidth, lutHeight);
+        VP_PUBLIC_CHK_STATUS_RETURN(m_allocator.ReAllocateSurface(
+            m_vebox3DLookUpTables,
+            "Vebox3DLutTableSurface",
+            Format_Buffer,
+            MOS_GFXRES_BUFFER,
+            MOS_TILE_LINEAR,
+            size,
+            1,
+            false,
+            MOS_MMC_DISABLED,
+            isAllocated,
+            false,
+            IsDeferredResourceDestroyNeeded(),
+            MOS_HW_RESOURCE_USAGE_VP_INTERNAL_READ_WRITE_RENDER));
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS VpResourceManager::AllocateResourceFor3DLutKernel(VP_EXECUTE_CAPS& caps)
+{
+    VP_FUNC_CALL();
+    uint32_t    size = 0;
+    bool        isAllocated = false;
+    uint32_t    lutWidth = 0;
+    uint32_t    lutHeight = 0;
+
+    uint32_t sizeOf3DLut = Get3DLutSize(lutWidth, lutHeight);
+    if (VP_VEBOX_HDR_3DLUT65 != sizeOf3DLut)
+    {
+        VP_PUBLIC_ASSERTMESSAGE("3DLutSize(%x) != VP_VEBOX_HDR_3DLUT65(%x)", sizeOf3DLut, VP_VEBOX_HDR_3DLUT65);
+        VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
+    }
+
+    VP_PUBLIC_CHK_STATUS_RETURN(m_allocator.ReAllocateSurface(
+        m_vebox3DLookUpTables2D,
+        "Vebox3DLutTableSurface2D",
+        Format_A8R8G8B8,
+        MOS_GFXRES_2D,
+        MOS_TILE_Y,
+        lutWidth,
+        lutHeight,
+        false,
+        MOS_MMC_DISABLED,
+        isAllocated,
+        false,
+        IsDeferredResourceDestroyNeeded(),
+        MOS_HW_RESOURCE_USAGE_VP_INTERNAL_READ_WRITE_RENDER));
+
+    if (isAllocated)
+    {
+        VP_PUBLIC_CHK_STATUS_RETURN(Init3DLutSurface2D(m_vebox3DLookUpTables2D));
+    }
+
+    uint32_t coefWidth     = 8;
+    uint32_t coefHeight    = 8;
+
+    VP_PUBLIC_CHK_STATUS_RETURN(m_allocator.ReAllocateSurface(
+        m_3DLutKernelCoefSurface,
+        "3DLutKernelCoefSurface",
+        Format_A8R8G8B8,
+        MOS_GFXRES_2D,
+        MOS_TILE_Y,
+        coefWidth,
+        coefHeight,
+        false,
+        MOS_MMC_DISABLED,
+        isAllocated,
+        false,
+        IsDeferredResourceDestroyNeeded(),
+        MOS_HW_RESOURCE_DEF_MAX,
+        MOS_TILE_UNSET_GMM,
+        MOS_MEMPOOL_SYSTEMMEMORY));
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS VpResourceManager::Assign3DLutKernelResource(VP_EXECUTE_CAPS &caps, RESOURCE_ASSIGNMENT_HINT resHint, VP_SURFACE_SETTING &surfSetting)
+{
+    VP_FUNC_CALL();
+
+    VP_PUBLIC_CHK_STATUS_RETURN(AllocateResourceFor3DLutKernel(caps));
+
+    surfSetting.surfGroup.insert(std::make_pair(SurfaceType3DLut2D, m_vebox3DLookUpTables2D));
+    surfSetting.surfGroup.insert(std::make_pair(SurfaceType3DLutCoef, m_3DLutKernelCoefSurface));
+
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS VpResourceManager::AssignSurface(VP_EXECUTE_CAPS caps, VEBOX_SURFACE_ID &surfaceId, SurfaceType surfaceType, VP_SURFACE *inputSurface, VP_SURFACE *outputSurface, VP_SURFACE *pastSurface, VP_SURFACE *futureSurface, VP_SURFACE_GROUP &surfGroup)
 {
     VP_FUNC_CALL();
@@ -1837,7 +2068,20 @@ MOS_STATUS VpResourceManager::AssignVeboxResource(VP_EXECUTE_CAPS& caps, VP_SURF
     if (VeboxHdr3DlutNeeded(caps))
     {
         // Insert Vebox 3Dlut surface
-        surfGroup.insert(std::make_pair(SurfaceType3dLut, m_vebox3DLookUpTables));
+        surfGroup.insert(std::make_pair(SurfaceType3DLut, m_vebox3DLookUpTables));
+    }
+
+    if (resHint.is3DLut2DNeeded)
+    {
+        VP_PUBLIC_CHK_NULL_RETURN(m_vebox3DLookUpTables2D);
+        // Insert Vebox 3Dlut surface
+        surfGroup.insert(std::make_pair(SurfaceType3DLut2D, m_vebox3DLookUpTables2D));
+    }
+
+    if (Vebox1DlutNeeded(caps))
+    {
+        // Insert DV 1Dlut surface
+        surfGroup.insert(std::make_pair(SurfaceType1k1dLut, m_vebox1DLookUpTables));
     }
 
     // Update previous Dn output flag for next frame to use.
@@ -1955,6 +2199,13 @@ bool VpResourceManager::VeboxHdr3DlutNeeded(VP_EXECUTE_CAPS &caps)
     return caps.bHDR3DLUT;
 }
 
+bool VpResourceManager::Vebox1DlutNeeded(VP_EXECUTE_CAPS &caps)
+{
+    VP_FUNC_CALL();
+
+    return caps.bDV;
+}
+
 // In some case, STMM should not be destroyed even when not being used by current workload to maintain data,
 // e.g. DI second field case.
 // If queryAssignment == true, query whether STMM needed by current workload.
@@ -1973,4 +2224,82 @@ bool VpResourceManager::VeboxSTMMNeeded(VP_EXECUTE_CAPS& caps, bool queryAssignm
     }
 }
 
+MOS_STATUS VpResourceManager::Init3DLutSurface2D(VP_SURFACE *surf)
+{
+    VP_FUNC_CALL();
+    int in_prec         = 16;
+    int max_input_level = ((1 << in_prec) - 1);
+    int R = 0, G = 0, B = 0;
+    int lutIndex = 0;
+    int lutMul   = 128;
+    int lutSeg   = 65;
+
+    uint32_t widthInByte = surf->osSurface->dwWidth * 4;
+    uint32_t pitchInByte = surf->osSurface->dwPitch;
+
+    uint8_t *lockedAddr = (uint8_t *)this->m_allocator.LockResourceForWrite(&surf->osSurface->OsResource);
+    VP_PUBLIC_CHK_NULL_RETURN(lockedAddr);
+
+    uint32_t indexByte = 0;
+    uint32_t indexByteInLine = 0;
+
+    for (int rr = 0; rr < lutSeg; rr++)
+    {
+        for (int gg = 0; gg < lutSeg; gg++)
+        {
+            for (int bb = 0; bb < lutMul; bb++)
+            {
+                uint16_t *lut = (uint16_t *)(lockedAddr + indexByte);
+                //--- convert fixed point to floating point
+
+                if (bb >= lutSeg)
+                {
+                    lut[3] = 0;
+                }
+                else
+                {
+                    if (rr == (lutSeg - 1))
+                        R = max_input_level;
+                    else
+                        R = rr * ((max_input_level + 1) / (lutSeg - 1));
+
+                    if (gg == (lutSeg - 1))
+                        G = max_input_level;
+                    else
+                        G = gg * ((max_input_level + 1) / (lutSeg - 1));
+
+                    if (bb == (lutSeg - 1))
+                        B = max_input_level;
+                    else
+                        B = bb * ((max_input_level + 1) / (lutSeg - 1));
+
+                    lut[0] = (unsigned short)R;
+                    lut[1] = (unsigned short)G;
+                    lut[2] = (unsigned short)B;
+                    lut[3] = 0;
+                }
+
+                indexByte += 8;
+                indexByteInLine += 8;
+
+                if (indexByteInLine >= widthInByte)
+                {
+                    indexByte += pitchInByte - indexByteInLine;
+                    indexByteInLine = 0;
+                }
+            }
+        }
+    }
+
+    // Unlock
+    VP_PUBLIC_CHK_STATUS_RETURN(this->m_allocator.UnLock(&surf->osSurface->OsResource));
+
+    if (indexByte > surf->osSurface->dwSize)
+    {
+        VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+
 };
