@@ -234,21 +234,16 @@ MOS_STATUS VPFeatureManager::CheckFeatures(void * params, bool &bApgFuncSupporte
         return MOS_STATUS_SUCCESS;
     }
 
-    // APG only support single frame input/output
-    if (pvpParams->uSrcCount != 1 ||
-        pvpParams->uDstCount != 1)
+    // Color fill does not need to check src params.
+    if (0 == pvpParams->uSrcCount)
     {
+        bApgFuncSupported = true;
         return MOS_STATUS_SUCCESS;
     }
 
     VP_PUBLIC_CHK_NULL_RETURN(pvpParams->pSrc[0]);
     VP_PUBLIC_CHK_NULL_RETURN(pvpParams->pTarget[0]);
 
-    if (pvpParams->pSrc[0]->SurfType != SURF_IN_PRIMARY)
-    {
-        return MOS_STATUS_SUCCESS;
-    }
-
     // align rectangle of surface
     VP_PUBLIC_CHK_STATUS_RETURN(RectSurfaceAlignment(pvpParams->pSrc[0], pvpParams->pTarget[0]->Format));
     VP_PUBLIC_CHK_STATUS_RETURN(RectSurfaceAlignment(pvpParams->pTarget[0], pvpParams->pTarget[0]->Format));
@@ -262,39 +257,13 @@ MOS_STATUS VPFeatureManager::CheckFeatures(void * params, bool &bApgFuncSupporte
         return MOS_STATUS_SUCCESS;
     }
 
-    // WA: Force NV12 16K to render
-    if (pvpParams->pTarget[0]->Format == Format_NV12 && pvpParams->pTarget[0]->dwHeight > VPHAL_RNDR_16K_HEIGHT_LIMIT)
-    {
-        VPHAL_RENDER_NORMALMESSAGE("Disable VEBOX/SFC for NV12 16k resolution");
-        return MOS_STATUS_SUCCESS;
-    }
-
     if (IsHdrNeeded(pvpParams->pSrc[0], pvpParams->pTarget[0]))
     {
+        VPHAL_RENDER_NORMALMESSAGE("Disable APO Path for HDR cases.");
         return MOS_STATUS_SUCCESS;
     }
 
-    // Check whether VEBOX is available
-    // VTd doesn't support VEBOX
-    if (!MEDIA_IS_SKU(m_hwInterface->m_skuTable, FtrVERing))
-    {
-        return MOS_STATUS_SUCCESS;
-    }
-
-    // Check if the Surface size is greater than 64x16 which is the minimum Width and Height VEBOX can handle
-    if (pvpParams->pSrc[0]->dwWidth < MHW_VEBOX_MIN_WIDTH || pvpParams->pSrc[0]->dwHeight < MHW_VEBOX_MIN_HEIGHT)
-    {
-        return MOS_STATUS_SUCCESS;
-    }
-
-    if (pvpParams->pSrc[0]->pBlendingParams                 ||
-        pvpParams->pSrc[0]->pLumaKeyParams                  ||
-        pvpParams->pConstriction)
-    {
-        return MOS_STATUS_SUCCESS;
-    }
-
-    if (pvpParams->pSrc[0]->bInterlacedScaling && !IsSfcInterlacedScalingSupported())
+    if (pvpParams->pConstriction)
     {
         return MOS_STATUS_SUCCESS;
     }
@@ -303,41 +272,15 @@ MOS_STATUS VPFeatureManager::CheckFeatures(void * params, bool &bApgFuncSupporte
     if (pvpParams->pSrc[0]->pDenoiseParams                       &&
         pvpParams->pSrc[0]->pDenoiseParams->bEnableHVSDenoise)
     {
+        VP_PUBLIC_NORMALMESSAGE("Disable APO Path for HVS.");
         return MOS_STATUS_SUCCESS;
     }
 
-    if (Is2PassesCSCNeeded(pvpParams->pSrc[0], pvpParams->pTarget[0]))
+    // Disable FP16 mode in APO path.
+    bool bFP16 = IS_RGB64_FLOAT_FORMAT(pvpParams->pTarget[0]->Format) || IS_RGB64_FLOAT_FORMAT(pvpParams->pSrc[0]->Format);
+    if (bFP16)
     {
-        return MOS_STATUS_SUCCESS;
-    }
-
-    // Temp removed RGB input with DN/DI/IECP case
-    if ((IS_RGB_FORMAT(pvpParams->pSrc[0]->Format)) &&
-        (pvpParams->pSrc[0]->pColorPipeParams))
-    {
-        return MOS_STATUS_SUCCESS;
-    }
-
-    if (!IsVeboxOutFeasible(pvpParams) &&
-        !IsSfcOutputFeasible(pvpParams))
-    {
-        return MOS_STATUS_SUCCESS;
-    }
-
-    bool bVeboxNeeded = IsVeboxSupported(pvpParams);
-    // If ScalingPreference == VPHAL_SCALING_PREFER_SFC_FOR_VEBOX, use SFC only when VEBOX is required
-    // For GEN12+, IEF has been removed from AVS sampler. Do not change the path if IEF is enabled.
-    if ((pvpParams->pSrc[0]->ScalingPreference == VPHAL_SCALING_PREFER_SFC_FOR_VEBOX) &&
-        (pvpParams->pSrc[0]->pIEFParams == nullptr || (pvpParams->pSrc[0]->pIEFParams && pvpParams->pSrc[0]->pIEFParams->bEnabled == false)) &&
-        (bVeboxNeeded == false))
-    {
-        VP_PUBLIC_NORMALMESSAGE("DDI choose to use SFC only for VEBOX, and since VEBOX is not required, change to Composition.");
-        return MOS_STATUS_SUCCESS;
-    }
-
-    if (pvpParams->pSrc[0]->ScalingPreference == VPHAL_SCALING_PREFER_COMP)
-    {
-        VP_PUBLIC_NORMALMESSAGE("DDI choose to use Composition, change to Composition.");
+        VP_PUBLIC_NORMALMESSAGE("Disable FP16 mode in APO path.");
         return MOS_STATUS_SUCCESS;
     }
 
@@ -1008,10 +951,10 @@ MOS_STATUS VPFeatureManager::RectSurfaceAlignment(
 {
     VP_FUNC_CALL();
 
-    uint16_t   wWidthAlignUnit;
-    uint16_t   wHeightAlignUnit;
-    uint16_t   wWidthAlignUnitForDstRect;
-    uint16_t   wHeightAlignUnitForDstRect;
+    uint16_t   wWidthAlignUnit            = 0;
+    uint16_t   wHeightAlignUnit           = 0;
+    uint16_t   wWidthAlignUnitForDstRect  = 0;
+    uint16_t   wHeightAlignUnitForDstRect = 0;
     MOS_STATUS eStatus;
 
     eStatus = MOS_STATUS_SUCCESS;
