@@ -1,5 +1,5 @@
 ﻿/*
-* Copyright (c) 2018-2021, Intel Corporation
+* Copyright (c) 2018-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -35,6 +35,7 @@
 #include "vp_utils.h"
 #include "sw_filter.h"
 #include "vp_feature_caps.h"
+#include "vp_render_fc_types.h"
 
 namespace vp {
 
@@ -109,6 +110,7 @@ protected:
 
     VpCmdPacket         * m_packet = nullptr;
 
+MEDIA_CLASS_DEFINE_END(VpFilter)
 };
 
 struct _SFC_SCALING_PARAMS
@@ -256,6 +258,18 @@ struct _VEBOX_CSC_PARAMS
     uint32_t                        chromaDownSamplingHorizontalCoef;            // Chroma DownSampling Horizontal Coeff
 };
 
+struct _RENDER_CSC_PARAMS
+{
+    uint32_t                        layer;
+    bool                            bCSCEnabled;                                 // CSC Enabled
+    VPHAL_CSPACE                    inputColorSpcase;                            // Input Color Space
+    VPHAL_CSPACE                    outputColorSpcase;                           // Input Color Space
+    MOS_FORMAT                      inputFormat;                                 // Input Format
+    MOS_FORMAT                      outputFormat;                                // Output Format
+    PVPHAL_ALPHA_PARAMS             alphaParams;                                 // Output Alpha Params
+    uint32_t                        inputChromaSetting;                          // Chroma setting
+};
+
 struct _VEBOX_HDR_PARAMS
 {
     uint32_t                        uiMaxDisplayLum;       //!< Maximum Display Luminance
@@ -264,6 +278,7 @@ struct _VEBOX_HDR_PARAMS
     VPHAL_CSPACE                    srcColorSpace;
     VPHAL_CSPACE                    dstColorSpace;
     MOS_FORMAT                      dstFormat;
+    HDR_STAGE                       stage;
 };
 
 using SFC_SCALING_PARAMS    = _SFC_SCALING_PARAMS;
@@ -298,10 +313,24 @@ struct _VEBOX_UPDATE_PARAMS
     VpKernelID                      kernelId;
 };
 
-using VEBOX_UPDATE_PARAMS      = _VEBOX_UPDATE_PARAMS;
-using PVEBOX_UPDATE_PARAMS     = VEBOX_UPDATE_PARAMS *;
-using VEBOX_HDR_PARAMS      = _VEBOX_HDR_PARAMS;
-using PVEBOX_HDR_PARAMS     = VEBOX_HDR_PARAMS *;
+using VEBOX_UPDATE_PARAMS                 = _VEBOX_UPDATE_PARAMS;
+using PVEBOX_UPDATE_PARAMS                = VEBOX_UPDATE_PARAMS *;
+using VEBOX_HDR_PARAMS                    = _VEBOX_HDR_PARAMS;
+using PVEBOX_HDR_PARAMS                   = VEBOX_HDR_PARAMS *;
+
+struct _RENDER_HDR_3DLUT_CAL_PARAMS
+{
+    uint32_t                        maxDisplayLum;       //!< Maximum Display Luminance
+    uint32_t                        maxContentLevelLum;  //!< Maximum Content Level Luminance
+    VPHAL_HDR_MODE                  hdrMode;
+    VpKernelID                      kernelId;
+    uint32_t                        threadWidth;
+    uint32_t                        threadHeight;
+    KERNEL_ARGS                     kernelArgs;
+};
+
+using RENDER_HDR_3DLUT_CAL_PARAMS  = _RENDER_HDR_3DLUT_CAL_PARAMS;
+using PRENDER_HDR_3DLUT_CAL_PARAMS = RENDER_HDR_3DLUT_CAL_PARAMS *;
 
 struct _STATE_COPY_PARAMS
 {
@@ -409,6 +438,14 @@ struct _RENDER_DI_FMD_PARAMS
 using RENDER_DI_FMD_PARAMS  = _RENDER_DI_FMD_PARAMS;
 using PRENDER_DI_FMD_PARAMS = RENDER_DI_FMD_PARAMS *;
 
+struct _RENDER_FC_PARAMS
+{
+    VpKernelID              kernelId;
+    VP_COMPOSITE_PARAMS     compParams;
+};
+using RENDER_FC_PARAMS  = _RENDER_FC_PARAMS;
+using PRENDER_FC_PARAMS = RENDER_FC_PARAMS *;
+
 class SwFilterPipe;
 class HwFilter;
 class PacketParamFactoryBase;
@@ -428,6 +465,8 @@ public:
 
 private:
     FeatureType m_FeatureType = FeatureTypeInvalid;
+
+MEDIA_CLASS_DEFINE_END(HwFilterParameter)
 };
 
 /////////////////////////////Packet Parameters///////////////////////////////////
@@ -444,6 +483,8 @@ public:
 
 private:
     PacketParamFactoryBase *m_packetParamFactory = nullptr;
+
+MEDIA_CLASS_DEFINE_END(VpPacketParameter)
 };
 
 /////////////////////////////Policy Feature Handler//////////////////////////////
@@ -465,6 +506,8 @@ protected:
     FeatureType m_Type = FeatureTypeInvalid;
     std::vector<HwFilterParameter *> m_Pool;
     VP_HW_CAPS  &m_hwCaps;
+
+MEDIA_CLASS_DEFINE_END(PolicyFeatureHandler)
 };
 
 class PacketParamFactoryBase
@@ -476,6 +519,8 @@ public:
     void ReturnPacketParameter(VpPacketParameter *&p);
 protected:
     std::vector<VpPacketParameter *> m_Pool;
+
+MEDIA_CLASS_DEFINE_END(PacketParamFactoryBase)
 };
 
 template<class T>
@@ -517,6 +562,8 @@ public:
             return p;
         }
     }
+
+MEDIA_CLASS_DEFINE_END(PacketParamFactory)
 };
 
 struct HW_FILTER_PARAM
